//
// Copyright (c) 2011, 2013, Oracle and/or its affiliates. All rights reserved.
// Copyright 2012, 2013 SAP AG. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//
//
// Copyright (c) 2011, 2014, Oracle and/or its affiliates. All rights reserved.
// Copyright (c) 2012, 2017 SAP SE. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_ppc_64.hpp"
#include "adfiles/ad_ppc_64.hpp"
#include "memory/allocation.inline.hpp"
#include "asm/macroAssembler.inline.hpp"
#include "code/compiledIC.hpp"
#include "code/vmreg.hpp"
#include "gc_interface/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/markOop.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "oops/oop.inline2.hpp"
#include "opto/cfgnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/biasedLocking.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "assembler_ppc.inline.hpp"
#include "nativeInst_ppc.hpp"
#include "vmreg_ppc.inline.hpp"

//SourceForm

#line 907 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


// Optimize load-acquire.
//
// Check if acquire is unnecessary due to following operation that does
// acquire anyways.
// Walk the pattern:
//
//      n: Load.acq
//           |
//      MemBarAcquire
//       |         |
//  Proj(ctrl)  Proj(mem)
//       |         |
//   MemBarRelease/Volatile
//
bool followed_by_acquire(const Node *load) {
  assert(load->is_Load(), "So far implemented only for loads.");

  // Find MemBarAcquire.
  const Node *mba = NULL;
  for (DUIterator_Fast imax, i = load->fast_outs(imax); i < imax; i++) {
    const Node *out = load->fast_out(i);
    if (out->Opcode() == Op_MemBarAcquire) {
      if (out->in(0) == load) continue; // Skip control edge, membar should be found via precedence edge.
      mba = out;
      break;
    }
  }
  if (!mba) return false;

  // Find following MemBar node.
  //
  // The following node must be reachable by control AND memory
  // edge to assure no other operations are in between the two nodes.
  //
  // So first get the Proj node, mem_proj, to use it to iterate forward.
  Node *mem_proj = NULL;
  for (DUIterator_Fast imax, i = mba->fast_outs(imax); i < imax; i++) {
    mem_proj = mba->fast_out(i);      // Throw out-of-bounds if proj not found
    assert(mem_proj->is_Proj(), "only projections here");
    ProjNode *proj = mem_proj->as_Proj();
    if (proj->_con == TypeFunc::Memory &&
        !Compile::current()->node_arena()->contains(mem_proj)) // Unmatched old-space only
      break;
  }
  assert(mem_proj->as_Proj()->_con == TypeFunc::Memory, "Graph broken");

  // Search MemBar behind Proj. If there are other memory operations
  // behind the Proj we lost.
  for (DUIterator_Fast jmax, j = mem_proj->fast_outs(jmax); j < jmax; j++) {
    Node *x = mem_proj->fast_out(j);
    // Proj might have an edge to a store or load node which precedes the membar.
    if (x->is_Mem()) return false;

    // On PPC64 release and volatile are implemented by an instruction
    // that also has acquire semantics. I.e. there is no need for an
    // acquire before these.
    int xop = x->Opcode();
    if (xop == Op_MemBarRelease || xop == Op_MemBarVolatile) {
      // Make sure we're not missing Call/Phi/MergeMem by checking
      // control edges. The control edge must directly lead back
      // to the MemBarAcquire
      Node *ctrl_proj = x->in(0);
      if (ctrl_proj->is_Proj() && ctrl_proj->in(0) == mba) {
        return true;
      }
    }
  }

  return false;
}

#define __ _masm.

// Tertiary op of a LoadP or StoreP encoding.
#define REGP_OP true

// ****************************************************************************

// REQUIRED FUNCTIONALITY

// !!!!! Special hack to get all type of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

// PPC port: Removed use of lazy constant construct.

int MachCallStaticJavaNode::ret_addr_offset() {
  // It's only a single branch-and-link instruction.
  return 4;
}

int MachCallDynamicJavaNode::ret_addr_offset() {
  // Offset is 4 with postalloc expanded calls (bl is one instruction). We use
  // postalloc expanded calls if we use inline caches and do not update method data.
  if (UseInlineCaches)
    return 4;

  int vtable_index = this->_vtable_index;
  if (vtable_index < 0) {
    // Must be invalid_vtable_index, not nonvirtual_vtable_index.
    assert(vtable_index == Method::invalid_vtable_index, "correct sentinel value");
    return 12;
  } else {
    assert(!UseInlineCaches, "expect vtable calls only if not using ICs");
    return 24;
  }
}

int MachCallRuntimeNode::ret_addr_offset() {
#if defined(ABI_ELFv2)
  return 28;
#else
  return 40;
#endif
}

//=============================================================================

// condition code conversions

static int cc_to_boint(int cc) {
  return Assembler::bcondCRbiIs0 | (cc & 8);
}

static int cc_to_inverse_boint(int cc) {
  return Assembler::bcondCRbiIs0 | (8-(cc & 8));
}

static int cc_to_biint(int cc, int flags_reg) {
  return (flags_reg << 2) | (cc & 3);
}

//=============================================================================

// Compute padding required for nodes which need alignment. The padding
// is the number of bytes (not instructions) which will be inserted before
// the instruction. The padding must match the size of a NOP instruction.

int string_indexOf_imm1_charNode::compute_padding(int current_offset) const {
  return (3*4-current_offset)&31;
}

int string_indexOf_imm1Node::compute_padding(int current_offset) const {
  return (2*4-current_offset)&31;
}

int string_indexOf_immNode::compute_padding(int current_offset) const {
  return (3*4-current_offset)&31;
}

int string_indexOfNode::compute_padding(int current_offset) const {
  return (1*4-current_offset)&31;
}

int string_compareNode::compute_padding(int current_offset) const {
  return (4*4-current_offset)&31;
}

int string_equals_immNode::compute_padding(int current_offset) const {
  if (opnd_array(3)->constant() < 16) return 0; // Don't insert nops for short version (loop completely unrolled).
  return (2*4-current_offset)&31;
}

int string_equalsNode::compute_padding(int current_offset) const {
  return (7*4-current_offset)&31;
}

int inlineCallClearArrayNode::compute_padding(int current_offset) const {
  return (2*4-current_offset)&31;
}

//=============================================================================

// Indicate if the safepoint node needs the polling page as an input.
bool SafePointNode::needs_polling_address_input() {
  // The address is loaded from thread by a seperate node.
  return true;
}

//=============================================================================

// Emit an interrupt that is caught by the debugger (for debugging compiler).
void emit_break(CodeBuffer &cbuf) {
  MacroAssembler _masm(&cbuf);
  __ illtrap();
}

#ifndef PRODUCT
void MachBreakpointNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("BREAKPOINT");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  emit_break(cbuf);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

//=============================================================================

void emit_nop(CodeBuffer &cbuf) {
  MacroAssembler _masm(&cbuf);
  __ nop();
}

static inline void emit_long(CodeBuffer &cbuf, int value) {
  *((int*)(cbuf.insts_end())) = value;
  cbuf.set_insts_end(cbuf.insts_end() + BytesPerInstWord);
}

//=============================================================================


#line 301 "../generated/adfiles/ad_ppc_64.cpp"


//SourceForm

#line 1157 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


// Emit a trampoline stub for a call to a target which is too far away.
//
// code sequences:
//
// call-site:
//   branch-and-link to <destination> or <trampoline stub>
//
// Related trampoline stub for this call-site in the stub section:
//   load the call target from the constant pool
//   branch via CTR (LR/link still points to the call-site above)

void CallStubImpl::emit_trampoline_stub(MacroAssembler &_masm, int destination_toc_offset, int insts_call_instruction_offset) {
  // Start the stub.
  address stub = __ start_a_stub(Compile::MAX_stubs_size/2);
  if (stub == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return;
  }

  // For java_to_interp stubs we use R11_scratch1 as scratch register
  // and in call trampoline stubs we use R12_scratch2. This way we
  // can distinguish them (see is_NativeCallTrampolineStub_at()).
  Register reg_scratch = R12_scratch2;

  // Create a trampoline stub relocation which relates this trampoline stub
  // with the call instruction at insts_call_instruction_offset in the
  // instructions code-section.
  __ relocate(trampoline_stub_Relocation::spec(__ code()->insts()->start() + insts_call_instruction_offset));
  const int stub_start_offset = __ offset();

  // Now, create the trampoline stub's code:
  // - load the TOC
  // - load the call target from the constant pool
  // - call
  __ calculate_address_from_global_toc(reg_scratch, __ method_toc());
  __ ld_largeoffset_unchecked(reg_scratch, destination_toc_offset, reg_scratch, false);
  __ mtctr(reg_scratch);
  __ bctr();

  const address stub_start_addr = __ addr_at(stub_start_offset);

  // FIXME: Assert that the trampoline stub can be identified and patched.

  // Assert that the encoded destination_toc_offset can be identified and that it is correct.
  assert(destination_toc_offset == NativeCallTrampolineStub_at(stub_start_addr)->destination_toc_offset(),
         "encoded offset into the constant pool must match");
  // Trampoline_stub_size should be good.
  assert((uint)(__ offset() - stub_start_offset) <= trampoline_stub_size, "should be good size");
  assert(is_NativeCallTrampolineStub_at(stub_start_addr), "doesn't look like a trampoline");

  // End the stub.
  __ end_a_stub();
}

//=============================================================================

// Emit an inline branch-and-link call and a related trampoline stub.
//
// code sequences:
//
// call-site:
//   branch-and-link to <destination> or <trampoline stub>
//
// Related trampoline stub for this call-site in the stub section:
//   load the call target from the constant pool
//   branch via CTR (LR/link still points to the call-site above)
//

typedef struct {
  int insts_call_instruction_offset;
  int ret_addr_offset;
} EmitCallOffsets;

// Emit a branch-and-link instruction that branches to a trampoline.
// - Remember the offset of the branch-and-link instruction.
// - Add a relocation at the branch-and-link instruction.
// - Emit a branch-and-link.
// - Remember the return pc offset.
EmitCallOffsets emit_call_with_trampoline_stub(MacroAssembler &_masm, address entry_point, relocInfo::relocType rtype) {
  EmitCallOffsets offsets = { -1, -1 };
  const int start_offset = __ offset();
  offsets.insts_call_instruction_offset = __ offset();

  // No entry point given, use the current pc.
  if (entry_point == NULL) entry_point = __ pc();

  if (!Compile::current()->in_scratch_emit_size()) {
    // Put the entry point as a constant into the constant pool.
    const address entry_point_toc_addr   = __ address_constant(entry_point, RelocationHolder::none);
    const int     entry_point_toc_offset = __ offset_to_method_toc(entry_point_toc_addr);

    // Emit the trampoline stub which will be related to the branch-and-link below.
    CallStubImpl::emit_trampoline_stub(_masm, entry_point_toc_offset, offsets.insts_call_instruction_offset);
    if (ciEnv::current()->failing()) { return offsets; } // Code cache may be full.
    __ relocate(rtype);
  }

  // Note: At this point we do not have the address of the trampoline
  // stub, and the entry point might be too far away for bl, so __ pc()
  // serves as dummy and the bl will be patched later.
  __ bl((address) __ pc());

  offsets.ret_addr_offset = __ offset() - start_offset;

  return offsets;
}

//=============================================================================

// Factory for creating loadConL* nodes for large/small constant pool.

static inline jlong replicate_immF(float con) {
  // Replicate float con 2 times and pack into vector.
  int val = *((int*)&con);
  jlong lval = val;
  lval = (lval << 32) | (lval & 0xFFFFFFFFl);
  return lval;
}

//=============================================================================

const RegMask& MachConstantBaseNode::_out_RegMask = BITS64_CONSTANT_TABLE_BASE_mask();
int Compile::ConstantTable::calculate_table_base_offset() const {
  return 0;  // absolute addressing, no offset
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return true; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  Compile *C = ra_->C;

  iRegPdstOper *op_dst = new (C) iRegPdstOper();
  MachNode *m1 = new (C) loadToc_hiNode();
  MachNode *m2 = new (C) loadToc_loNode();

  m1->add_req(NULL);
  m2->add_req(NULL, m1);
  m1->_opnds[0] = op_dst;
  m2->_opnds[0] = op_dst;
  m2->_opnds[1] = op_dst;
  ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
  ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
  nodes->push(m1);
  nodes->push(m2);
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  // Is postalloc expanded.
  ShouldNotReachHere();
}

uint MachConstantBaseNode::size(PhaseRegAlloc* ra_) const {
  return 0;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print("-- \t// MachConstantBaseNode (empty encoding)");
}
#endif

//=============================================================================

#ifndef PRODUCT
void MachPrologNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;
  const long framesize = C->frame_slots() << LogBytesPerInt;

  st->print("PROLOG\n\t");
  if (C->need_stack_bang(framesize)) {
    st->print("stack_overflow_check\n\t");
  }

  if (!false /* TODO: PPC port C->is_frameless_method()*/) {
    st->print("save return pc\n\t");
    st->print("push frame %ld\n\t", -framesize);
  }
}
#endif

// Macro used instead of the common __ to emulate the pipes of PPC.
// Instead of e.g. __ ld(...) one hase to write ___(ld) ld(...) This enables the
// micro scheduler to cope with "hand written" assembler like in the prolog. Though
// still no scheduling of this code is possible, the micro scheduler is aware of the
// code and can update its internal data. The following mechanism is used to achieve this:
// The micro scheduler calls size() of each compound node during scheduling. size() does a
// dummy emit and only during this dummy emit C->hb_scheduling() is not NULL.
#if 0 // TODO: PPC port
#define ___(op) if (UsePower6SchedulerPPC64 && C->hb_scheduling())                    \
                  C->hb_scheduling()->_pdScheduling->PdEmulatePipe(ppc64Opcode_##op); \
                _masm.
#define ___stop if (UsePower6SchedulerPPC64 && C->hb_scheduling())                    \
                  C->hb_scheduling()->_pdScheduling->PdEmulatePipe(archOpcode_none)
#define ___advance if (UsePower6SchedulerPPC64 && C->hb_scheduling())                 \
                  C->hb_scheduling()->_pdScheduling->advance_offset
#else
#define ___(op) if (UsePower6SchedulerPPC64)                                          \
                  Unimplemented();                                                    \
                _masm.
#define ___stop if (UsePower6SchedulerPPC64)                                          \
                  Unimplemented()
#define ___advance if (UsePower6SchedulerPPC64)                                       \
                  Unimplemented()
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  const long framesize = C->frame_size_in_bytes();
  assert(framesize % (2 * wordSize) == 0, "must preserve 2*wordSize alignment");

  const bool method_is_frameless      = false /* TODO: PPC port C->is_frameless_method()*/;

  const Register return_pc            = R20; // Must match return_addr() in frame section.
  const Register callers_sp           = R21;
  const Register push_frame_temp      = R22;
  const Register toc_temp             = R23;
  assert_different_registers(R11, return_pc, callers_sp, push_frame_temp, toc_temp);

  if (method_is_frameless) {
    // Add nop at beginning of all frameless methods to prevent any
    // oop instructions from getting overwritten by make_not_entrant
    // (patching attempt would fail).
    ___(nop) nop();
  } else {
    // Get return pc.
    ___(mflr) mflr(return_pc);
  }

  // Calls to C2R adapters often do not accept exceptional returns.
  // We require that their callers must bang for them. But be
  // careful, because some VM calls (such as call site linkage) can
  // use several kilobytes of stack. But the stack safety zone should
  // account for that. See bugs 4446381, 4468289, 4497237.

  int bangsize = C->bang_size_in_bytes();
  assert(bangsize >= framesize || bangsize <= 0, "stack bang size incorrect");
  if (C->need_stack_bang(bangsize) && UseStackBanging) {
    // Unfortunately we cannot use the function provided in
    // assembler.cpp as we have to emulate the pipes. So I had to
    // insert the code of generate_stack_overflow_check(), see
    // assembler.cpp for some illuminative comments.
    const int page_size = os::vm_page_size();
    int bang_end = StackShadowPages * page_size;

    // This is how far the previous frame's stack banging extended.
    const int bang_end_safe = bang_end;

    if (bangsize > page_size) {
      bang_end += bangsize;
    }

    int bang_offset = bang_end_safe;

    while (bang_offset <= bang_end) {
      // Need at least one stack bang at end of shadow zone.

      // Again I had to copy code, this time from assembler_ppc.cpp,
      // bang_stack_with_offset - see there for comments.

      // Stack grows down, caller passes positive offset.
      assert(bang_offset > 0, "must bang with positive offset");

      long stdoffset = -bang_offset;

      if (Assembler::is_simm(stdoffset, 16)) {
        // Signed 16 bit offset, a simple std is ok.
        if (UseLoadInstructionsForStackBangingPPC64) {
          ___(ld) ld(R0,  (int)(signed short)stdoffset, R1_SP);
        } else {
          ___(std) std(R0, (int)(signed short)stdoffset, R1_SP);
        }
      } else if (Assembler::is_simm(stdoffset, 31)) {
        // Use largeoffset calculations for addis & ld/std.
        const int hi = MacroAssembler::largeoffset_si16_si16_hi(stdoffset);
        const int lo = MacroAssembler::largeoffset_si16_si16_lo(stdoffset);

        Register tmp = R11;
        ___(addis) addis(tmp, R1_SP, hi);
        if (UseLoadInstructionsForStackBangingPPC64) {
          ___(ld) ld(R0, lo, tmp);
        } else {
          ___(std) std(R0, lo, tmp);
        }
      } else {
        ShouldNotReachHere();
      }

      bang_offset += page_size;
    }
    // R11 trashed
  } // C->need_stack_bang(framesize) && UseStackBanging

  unsigned int bytes = (unsigned int)framesize;
  long offset = Assembler::align_addr(bytes, frame::alignment_in_bytes);
  ciMethod *currMethod = C->method();

  // Optimized version for most common case.
  if (UsePower6SchedulerPPC64 &&
      !method_is_frameless && Assembler::is_simm((int)(-offset), 16) &&
      !(false /* ConstantsALot TODO: PPC port*/)) {
    ___(or) mr(callers_sp, R1_SP);
    ___(std) std(return_pc, _abi(lr), R1_SP);
    ___(stdu) stdu(R1_SP, -offset, R1_SP);
    return;
  }

  if (!method_is_frameless) {
    // Get callers sp.
    ___(or) mr(callers_sp, R1_SP);

    // Push method's frame, modifies SP.
    assert(Assembler::is_uimm(framesize, 32U), "wrong type");
    // The ABI is already accounted for in 'framesize' via the
    // 'out_preserve' area.
    Register tmp = push_frame_temp;
    // Had to insert code of push_frame((unsigned int)framesize, push_frame_temp).
    if (Assembler::is_simm(-offset, 16)) {
      ___(stdu) stdu(R1_SP, -offset, R1_SP);
    } else {
      long x = -offset;
      // Had to insert load_const(tmp, -offset).
      ___(addis)  lis( tmp, (int)((signed short)(((x >> 32) & 0xffff0000) >> 16)));
      ___(ori)    ori( tmp, tmp, ((x >> 32) & 0x0000ffff));
      ___(rldicr) sldi(tmp, tmp, 32);
      ___(oris)   oris(tmp, tmp, (x & 0xffff0000) >> 16);
      ___(ori)    ori( tmp, tmp, (x & 0x0000ffff));

      ___(stdux) stdux(R1_SP, R1_SP, tmp);
    }
  }
#if 0 // TODO: PPC port
  // For testing large constant pools, emit a lot of constants to constant pool.
  // "Randomize" const_size.
  if (ConstantsALot) {
    const int num_consts = const_size();
    for (int i = 0; i < num_consts; i++) {
      __ long_constant(0xB0B5B00BBABE);
    }
  }
#endif
  if (!method_is_frameless) {
    // Save return pc.
    ___(std) std(return_pc, _abi(lr), callers_sp);
  }
}
#undef ___
#undef ___stop
#undef ___advance

uint MachPrologNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. determine dynamically.
  return MachNode::size(ra_);
}

int MachPrologNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 reloc entry for load_const(toc).
}

//=============================================================================

#ifndef PRODUCT
void MachEpilogNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  Compile* C = ra_->C;

  st->print("EPILOG\n\t");
  st->print("restore return pc\n\t");
  st->print("pop frame\n\t");

  if (do_polling() && C->is_method_compilation()) {
    st->print("touch polling page\n\t");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  MacroAssembler _masm(&cbuf);

  const long framesize = ((long)C->frame_slots()) << LogBytesPerInt;
  assert(framesize >= 0, "negative frame-size?");

  const bool method_needs_polling = do_polling() && C->is_method_compilation();
  const bool method_is_frameless  = false /* TODO: PPC port C->is_frameless_method()*/;
  const Register return_pc        = R11;
  const Register polling_page     = R12;

  if (!method_is_frameless) {
    // Restore return pc relative to callers' sp.
    __ ld(return_pc, ((int)framesize) + _abi(lr), R1_SP);
  }

  if (method_needs_polling) {
    if (LoadPollAddressFromThread) {
      // TODO: PPC port __ ld(polling_page, in_bytes(JavaThread::poll_address_offset()), R16_thread);
      Unimplemented();
    } else {
      __ load_const_optimized(polling_page, (long)(address) os::get_polling_page()); // TODO: PPC port: get_standard_polling_page()
    }
  }

  if (!method_is_frameless) {
    // Move return pc to LR.
    __ mtlr(return_pc);
    // Pop frame (fixed frame-size).
    __ addi(R1_SP, R1_SP, (int)framesize);
  }

  if (method_needs_polling) {
    // We need to mark the code position where the load from the safepoint
    // polling page was emitted as relocInfo::poll_return_type here.
    __ relocate(relocInfo::poll_return_type);
    __ load_from_polling_page(polling_page);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  // Return number of relocatable values contained in this instruction.
  return 1; // 1 for load_from_polling_page.
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

// This method seems to be obsolete. It is declared in machnode.hpp
// and defined in all *.ad files, but it is never called. Should we
// get rid of it?
int MachEpilogNode::safepoint_offset() const {
  assert(do_polling(), "no return for this epilog node");
  return 0;
}

#if 0 // TODO: PPC port
void MachLoadPollAddrLateNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  MacroAssembler _masm(&cbuf);
  if (LoadPollAddressFromThread) {
    _masm.ld(R11, in_bytes(JavaThread::poll_address_offset()), R16_thread);
  } else {
    _masm.nop();
  }
}

uint MachLoadPollAddrLateNode::size(PhaseRegAlloc* ra_) const {
  if (LoadPollAddressFromThread) {
    return 4;
  } else {
    return 4;
  }
}

#ifndef PRODUCT
void MachLoadPollAddrLateNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  st->print_cr(" LD R11, PollAddressOffset, R16_thread \t// LoadPollAddressFromThread");
}
#endif

const RegMask &MachLoadPollAddrLateNode::out_RegMask() const {
  return RSCRATCH1_BITS64_REG_mask();
}
#endif // PPC port

// =============================================================================

// Figure out which register class each belongs in: rc_int, rc_float or
// rc_stack.
enum RC { rc_bad, rc_int, rc_float, rc_stack };

static enum RC rc_class(OptoReg::Name reg) {
  // Return the register class for the given register. The given register
  // reg is a <register>_num value, which is an index into the MachRegisterNumbers
  // enumeration in adGlobals_ppc64.hpp.

  if (reg == OptoReg::Bad) return rc_bad;

  // We have 64 integer register halves, starting at index 0.
  if (reg < 64) return rc_int;

  // We have 64 floating-point register halves, starting at index 64.
  if (reg < 64+64) return rc_float;

  // Between float regs & stack are the flags regs.
  assert(OptoReg::is_stack(reg), "blow up if spilling flags");

  return rc_stack;
}

static int ld_st_helper(CodeBuffer *cbuf, const char *op_str, uint opcode, int reg, int offset,
                        bool do_print, Compile* C, outputStream *st) {

  assert(opcode == Assembler::LD_OPCODE   ||
         opcode == Assembler::STD_OPCODE  ||
         opcode == Assembler::LWZ_OPCODE  ||
         opcode == Assembler::STW_OPCODE  ||
         opcode == Assembler::LFD_OPCODE  ||
         opcode == Assembler::STFD_OPCODE ||
         opcode == Assembler::LFS_OPCODE  ||
         opcode == Assembler::STFS_OPCODE,
         "opcode not supported");

  if (cbuf) {
    int d =
      (Assembler::LD_OPCODE == opcode || Assembler::STD_OPCODE == opcode) ?
        Assembler::ds(offset+0 /* TODO: PPC port C->frame_slots_sp_bias_in_bytes()*/)
      : Assembler::d1(offset+0 /* TODO: PPC port C->frame_slots_sp_bias_in_bytes()*/); // Makes no difference in opt build.
    emit_long(*cbuf, opcode | Assembler::rt(Matcher::_regEncode[reg]) | d | Assembler::ra(R1_SP));
  }
#ifndef PRODUCT
  else if (do_print) {
    st->print("%-7s %s, [R1_SP + #%d+%d] \t// spill copy",
              op_str,
              Matcher::regName[reg],
              offset, 0 /* TODO: PPC port C->frame_slots_sp_bias_in_bytes()*/);
  }
#endif
  return 4; // size
}

uint MachSpillCopyNode::implementation(CodeBuffer *cbuf, PhaseRegAlloc *ra_, bool do_size, outputStream *st) const {
  Compile* C = ra_->C;

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(this);
  OptoReg::Name dst_lo = ra_->get_reg_first(this);

  enum RC src_hi_rc = rc_class(src_hi);
  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_hi_rc = rc_class(dst_hi);
  enum RC dst_lo_rc = rc_class(dst_lo);

  assert(src_lo != OptoReg::Bad && dst_lo != OptoReg::Bad, "must move at least 1 register");
  if (src_hi != OptoReg::Bad)
    assert((src_lo&1)==0 && src_lo+1==src_hi &&
           (dst_lo&1)==0 && dst_lo+1==dst_hi,
           "expected aligned-adjacent pairs");
  // Generate spill code!
  int size = 0;

  if (src_lo == dst_lo && src_hi == dst_hi)
    return size;            // Self copy, no move.

  // --------------------------------------
  // Memory->Memory Spill. Use R0 to hold the value.
  if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
    int src_offset = ra_->reg2offset(src_lo);
    int dst_offset = ra_->reg2offset(dst_lo);
    if (src_hi != OptoReg::Bad) {
      assert(src_hi_rc==rc_stack && dst_hi_rc==rc_stack,
             "expected same type of move for high parts");
      size += ld_st_helper(cbuf, "LD  ", Assembler::LD_OPCODE,  R0_num, src_offset, !do_size, C, st);
      if (!cbuf && !do_size) st->print("\n\t");
      size += ld_st_helper(cbuf, "STD ", Assembler::STD_OPCODE, R0_num, dst_offset, !do_size, C, st);
    } else {
      size += ld_st_helper(cbuf, "LWZ ", Assembler::LWZ_OPCODE, R0_num, src_offset, !do_size, C, st);
      if (!cbuf && !do_size) st->print("\n\t");
      size += ld_st_helper(cbuf, "STW ", Assembler::STW_OPCODE, R0_num, dst_offset, !do_size, C, st);
    }
    return size;
  }

  // --------------------------------------
  // Check for float->int copy; requires a trip through memory.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_int) {
    Unimplemented();
  }

  // --------------------------------------
  // Check for integer reg-reg copy.
  if (src_lo_rc == rc_int && dst_lo_rc == rc_int) {
      Register Rsrc = as_Register(Matcher::_regEncode[src_lo]);
      Register Rdst = as_Register(Matcher::_regEncode[dst_lo]);
      size = (Rsrc != Rdst) ? 4 : 0;

      if (cbuf) {
        MacroAssembler _masm(cbuf);
        if (size) {
          __ mr(Rdst, Rsrc);
        }
      }
#ifndef PRODUCT
      else if (!do_size) {
        if (size) {
          st->print("%-7s %s, %s \t// spill copy", "MR", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
        } else {
          st->print("%-7s %s, %s \t// spill copy", "MR-NOP", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
        }
      }
#endif
      return size;
  }

  // Check for integer store.
  if (src_lo_rc == rc_int && dst_lo_rc == rc_stack) {
    int dst_offset = ra_->reg2offset(dst_lo);
    if (src_hi != OptoReg::Bad) {
      assert(src_hi_rc==rc_int && dst_hi_rc==rc_stack,
             "expected same type of move for high parts");
      size += ld_st_helper(cbuf, "STD ", Assembler::STD_OPCODE, src_lo, dst_offset, !do_size, C, st);
    } else {
      size += ld_st_helper(cbuf, "STW ", Assembler::STW_OPCODE, src_lo, dst_offset, !do_size, C, st);
    }
    return size;
  }

  // Check for integer load.
  if (dst_lo_rc == rc_int && src_lo_rc == rc_stack) {
    int src_offset = ra_->reg2offset(src_lo);
    if (src_hi != OptoReg::Bad) {
      assert(dst_hi_rc==rc_int && src_hi_rc==rc_stack,
             "expected same type of move for high parts");
      size += ld_st_helper(cbuf, "LD  ", Assembler::LD_OPCODE, dst_lo, src_offset, !do_size, C, st);
    } else {
      size += ld_st_helper(cbuf, "LWZ ", Assembler::LWZ_OPCODE, dst_lo, src_offset, !do_size, C, st);
    }
    return size;
  }

  // Check for float reg-reg copy.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
    if (cbuf) {
      MacroAssembler _masm(cbuf);
      FloatRegister Rsrc = as_FloatRegister(Matcher::_regEncode[src_lo]);
      FloatRegister Rdst = as_FloatRegister(Matcher::_regEncode[dst_lo]);
      __ fmr(Rdst, Rsrc);
    }
#ifndef PRODUCT
    else if (!do_size) {
      st->print("%-7s %s, %s \t// spill copy", "FMR", Matcher::regName[dst_lo], Matcher::regName[src_lo]);
    }
#endif
    return 4;
  }

  // Check for float store.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
    int dst_offset = ra_->reg2offset(dst_lo);
    if (src_hi != OptoReg::Bad) {
      assert(src_hi_rc==rc_float && dst_hi_rc==rc_stack,
             "expected same type of move for high parts");
      size += ld_st_helper(cbuf, "STFD", Assembler::STFD_OPCODE, src_lo, dst_offset, !do_size, C, st);
    } else {
      size += ld_st_helper(cbuf, "STFS", Assembler::STFS_OPCODE, src_lo, dst_offset, !do_size, C, st);
    }
    return size;
  }

  // Check for float load.
  if (dst_lo_rc == rc_float && src_lo_rc == rc_stack) {
    int src_offset = ra_->reg2offset(src_lo);
    if (src_hi != OptoReg::Bad) {
      assert(dst_hi_rc==rc_float && src_hi_rc==rc_stack,
             "expected same type of move for high parts");
      size += ld_st_helper(cbuf, "LFD ", Assembler::LFD_OPCODE, dst_lo, src_offset, !do_size, C, st);
    } else {
      size += ld_st_helper(cbuf, "LFS ", Assembler::LFS_OPCODE, dst_lo, src_offset, !do_size, C, st);
    }
    return size;
  }

  // --------------------------------------------------------------------
  // Check for hi bits still needing moving. Only happens for misaligned
  // arguments to native calls.
  if (src_hi == dst_hi)
    return size;               // Self copy; no move.

  assert(src_hi_rc != rc_bad && dst_hi_rc != rc_bad, "src_hi & dst_hi cannot be Bad");
  ShouldNotReachHere(); // Unimplemented
  return 0;
}

#ifndef PRODUCT
void MachSpillCopyNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  if (!ra_)
    st->print("N%d = SpillCopy(N%d)", _idx, in(1)->_idx);
  else
    implementation(NULL, ra_, false, st);
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation(&cbuf, ra_, false, NULL);
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return implementation(NULL, ra_, true, NULL);
}

#if 0 // TODO: PPC port
ArchOpcode MachSpillCopyNode_archOpcode(MachSpillCopyNode *n, PhaseRegAlloc *ra_) {
#ifndef PRODUCT
  if (ra_->node_regs_max_index() == 0) return archOpcode_undefined;
#endif
  assert(ra_->node_regs_max_index() != 0, "");

  // Get registers to move.
  OptoReg::Name src_hi = ra_->get_reg_second(n->in(1));
  OptoReg::Name src_lo = ra_->get_reg_first(n->in(1));
  OptoReg::Name dst_hi = ra_->get_reg_second(n);
  OptoReg::Name dst_lo = ra_->get_reg_first(n);

  enum RC src_lo_rc = rc_class(src_lo);
  enum RC dst_lo_rc = rc_class(dst_lo);

  if (src_lo == dst_lo && src_hi == dst_hi)
    return ppc64Opcode_none;            // Self copy, no move.

  // --------------------------------------
  // Memory->Memory Spill. Use R0 to hold the value.
  if (src_lo_rc == rc_stack && dst_lo_rc == rc_stack) {
    return ppc64Opcode_compound;
  }

  // --------------------------------------
  // Check for float->int copy; requires a trip through memory.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_int) {
    Unimplemented();
  }

  // --------------------------------------
  // Check for integer reg-reg copy.
  if (src_lo_rc == rc_int && dst_lo_rc == rc_int) {
    Register Rsrc = as_Register(Matcher::_regEncode[src_lo]);
    Register Rdst = as_Register(Matcher::_regEncode[dst_lo]);
    if (Rsrc == Rdst) {
      return ppc64Opcode_none;
    } else {
      return ppc64Opcode_or;
    }
  }

  // Check for integer store.
  if (src_lo_rc == rc_int && dst_lo_rc == rc_stack) {
    if (src_hi != OptoReg::Bad) {
      return ppc64Opcode_std;
    } else {
      return ppc64Opcode_stw;
    }
  }

  // Check for integer load.
  if (dst_lo_rc == rc_int && src_lo_rc == rc_stack) {
    if (src_hi != OptoReg::Bad) {
      return ppc64Opcode_ld;
    } else {
      return ppc64Opcode_lwz;
    }
  }

  // Check for float reg-reg copy.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_float) {
    return ppc64Opcode_fmr;
  }

  // Check for float store.
  if (src_lo_rc == rc_float && dst_lo_rc == rc_stack) {
    if (src_hi != OptoReg::Bad) {
      return ppc64Opcode_stfd;
    } else {
      return ppc64Opcode_stfs;
    }
  }

  // Check for float load.
  if (dst_lo_rc == rc_float && src_lo_rc == rc_stack) {
    if (src_hi != OptoReg::Bad) {
      return ppc64Opcode_lfd;
    } else {
      return ppc64Opcode_lfs;
    }
  }

  // --------------------------------------------------------------------
  // Check for hi bits still needing moving. Only happens for misaligned
  // arguments to native calls.
  if (src_hi == dst_hi) {
    return ppc64Opcode_none;               // Self copy; no move.
  }

  ShouldNotReachHere();
  return ppc64Opcode_undefined;
}
#endif // PPC port

#ifndef PRODUCT
void MachNopNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print("NOP \t// %d nops to pad for loops.", _count);
}
#endif

void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *) const {
  MacroAssembler _masm(&cbuf);
  // _count contains the number of nops needed for padding.
  for (int i = 0; i < _count; i++) {
    __ nop();
  }
}

uint MachNopNode::size(PhaseRegAlloc *ra_) const {
  return _count * 4;
}

#ifndef PRODUCT
void BoxLockNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  char reg_str[128];
  ra_->dump_register(this, reg_str);
  st->print("ADDI    %s, SP, %d \t// box node", reg_str, offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  MacroAssembler _masm(&cbuf);

  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg    = ra_->get_encode(this);

  if (Assembler::is_simm(offset, 16)) {
    __ addi(as_Register(reg), R1, offset);
  } else {
    ShouldNotReachHere();
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_).
  return 4;
}

#ifndef PRODUCT
void MachUEPNode::format(PhaseRegAlloc *ra_, outputStream *st) const {
  st->print_cr("---- MachUEPNode ----");
  st->print_cr("...");
}
#endif

void MachUEPNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  // This is the unverified entry point.
  MacroAssembler _masm(&cbuf);

  // Inline_cache contains a klass.
  Register ic_klass       = as_Register(Matcher::inline_cache_reg_encode());
  Register receiver_klass = R12_scratch2;  // tmp

  assert_different_registers(ic_klass, receiver_klass, R11_scratch1, R3_ARG1);
  assert(R11_scratch1 == R11, "need prologue scratch register");

  // Check for NULL argument if we don't have implicit null checks.
  if (!ImplicitNullChecks || !os::zero_page_read_protected()) {
    if (TrapBasedNullChecks) {
      __ trap_null_check(R3_ARG1);
    } else {
      Label valid;
      __ cmpdi(CCR0, R3_ARG1, 0);
      __ bne_predict_taken(CCR0, valid);
      // We have a null argument, branch to ic_miss_stub.
      __ b64_patchable((address)SharedRuntime::get_ic_miss_stub(),
                           relocInfo::runtime_call_type);
      __ bind(valid);
    }
  }
  // Assume argument is not NULL, load klass from receiver.
  __ load_klass(receiver_klass, R3_ARG1);

  if (TrapBasedICMissChecks) {
    __ trap_ic_miss_check(receiver_klass, ic_klass);
  } else {
    Label valid;
    __ cmpd(CCR0, receiver_klass, ic_klass);
    __ beq_predict_taken(CCR0, valid);
    // We have an unexpected klass, branch to ic_miss_stub.
    __ b64_patchable((address)SharedRuntime::get_ic_miss_stub(),
                         relocInfo::runtime_call_type);
    __ bind(valid);
  }

  // Argument is valid and klass is as expected, continue.
}

#if 0 // TODO: PPC port
// Optimize UEP code on z (save a load_const() call in main path).
int MachUEPNode::ep_offset() {
  return 0;
}
#endif

uint MachUEPNode::size(PhaseRegAlloc *ra_) const {
  // Variable size. Determine dynamically.
  return MachNode::size(ra_);
}

//=============================================================================


#line 1210 "../generated/adfiles/ad_ppc_64.cpp"


//SourceForm

#line 2084 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


int HandlerImpl::emit_exception_handler(CodeBuffer &cbuf) {
  MacroAssembler _masm(&cbuf);

  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) return 0; // CodeBuffer::expand failed

  int offset = __ offset();
  __ b64_patchable((address)OptoRuntime::exception_blob()->content_begin(),
                       relocInfo::runtime_call_type);
  assert(__ offset() - offset == (int)size_exception_handler(), "must be fixed size");
  __ end_a_stub();

  return offset;
}

// The deopt_handler is like the exception handler, but it calls to
// the deoptimization blob instead of jumping to the exception blob.
int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf) {
  MacroAssembler _masm(&cbuf);

  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) return 0; // CodeBuffer::expand failed

  int offset = __ offset();
  __ bl64_patchable((address)SharedRuntime::deopt_blob()->unpack(),
                        relocInfo::runtime_call_type);
  assert(__ offset() - offset == (int) size_deopt_handler(), "must be fixed size");
  __ end_a_stub();

  return offset;
}

//=============================================================================

// Use a frame slots bias for frameless methods if accessing the stack.
static int frame_slots_bias(int reg_enc, PhaseRegAlloc* ra_) {
  if (as_Register(reg_enc) == R1_SP) {
    return 0; // TODO: PPC port ra_->C->frame_slots_sp_bias_in_bytes();
  }
  return 0;
}

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  switch (opcode) {
  case Op_SqrtD:
    return VM_Version::has_fsqrt();
  case Op_CountLeadingZerosI:
  case Op_CountLeadingZerosL:
  case Op_CountTrailingZerosI:
  case Op_CountTrailingZerosL:
    if (!UseCountLeadingZerosInstructionsPPC64)
      return false;
    break;

  case Op_PopCountI:
  case Op_PopCountL:
    return (UsePopCountInstruction && VM_Version::has_popcntw());

  case Op_StrComp:
    return SpecialStringCompareTo;
  case Op_StrEquals:
    return SpecialStringEquals;
  case Op_StrIndexOf:
    return SpecialStringIndexOf;
  }

  return true;  // Per default match rules are supported.
}

int Matcher::regnum_to_fpu_offset(int regnum) {
  // No user for this method?
  Unimplemented();
  return 999;
}

const bool Matcher::convL2FSupported(void) {
  // fcfids can do the conversion (>= Power7).
  // fcfid + frsp showed rounding problem when result should be 0x3f800001.
  return VM_Version::has_fcfids(); // False means that conversion is done by runtime call.
}

// Vector width in bytes.
const int Matcher::vector_width_in_bytes(BasicType bt) {
  assert(MaxVectorSize == 8, "");
  return 8;
}

// Vector ideal reg.
const int Matcher::vector_ideal_reg(int size) {
  assert(MaxVectorSize == 8 && size == 8, "");
  return Op_RegL;
}

const int Matcher::vector_shift_count_ideal_reg(int size) {
  fatal("vector shift is not supported");
  return Node::NotAMachineReg;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  assert(is_java_primitive(bt), "only primitive type vectors");
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}

const int Matcher::min_vector_size(const BasicType bt) {
  return max_vector_size(bt); // Same as max.
}

// PPC doesn't support misaligned vectors store/load.
const bool Matcher::misaligned_vectors_ok() {
  return false;
}

// PPC AES support not yet implemented
const bool Matcher::pass_original_key_for_aes() {
  return false;
}

// RETURNS: whether this branch offset is short enough that a short
// branch can be used.
//
// If the platform does not provide any short branch variants, then
// this method should return `false' for offset 0.
//
// `Compile::Fill_buffer' will decide on basis of this information
// whether to do the pass `Compile::Shorten_branches' at all.
//
// And `Compile::Shorten_branches' will decide on basis of this
// information whether to replace particular branch sites by short
// ones.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // Is the offset within the range of a ppc64 pc relative branch?
  bool b;

  const int safety_zone = 3 * BytesPerInstWord;
  b = Assembler::is_simm((offset<0 ? offset-safety_zone : offset+safety_zone),
                         29 - 16 + 1 + 2);
  return b;
}

const bool Matcher::isSimpleConstant64(jlong value) {
  // Probably always true, even if a temp register is required.
  return true;
}
/* TODO: PPC port
// Make a new machine dependent decode node (with its operands).
MachTypeNode *Matcher::make_decode_node(Compile *C) {
  assert(Universe::narrow_oop_base() == NULL && Universe::narrow_oop_shift() == 0,
         "This method is only implemented for unscaled cOops mode so far");
  MachTypeNode *decode = new (C) decodeN_unscaledNode();
  decode->set_opnd_array(0, new (C) iRegPdstOper());
  decode->set_opnd_array(1, new (C) iRegNsrcOper());
  return decode;
}
*/
// Threshold size for cleararray.
const int Matcher::init_array_short_size = 8 * BytesPerLong;

// false => size gets scaled to BytesPerLong, ok.
const bool Matcher::init_array_count_is_in_bytes = false;

// Use conditional move (CMOVL) on Power7.
const int Matcher::long_cmove_cost() { return 0; } // this only makes long cmoves more expensive than int cmoves

// Suppress CMOVF. Conditional move available (sort of) on PPC64 only from P7 onwards. Not exploited yet.
// fsel doesn't accept a condition register as input, so this would be slightly different.
const int Matcher::float_cmove_cost() { return ConditionalMoveLimit; }

// Power6 requires postalloc expand (see block.cpp for description of postalloc expand).
const bool Matcher::require_postalloc_expand = true;

// Should the Matcher clone shifts on addressing modes, expecting them to
// be subsumed into complex addressing expressions or compute them into
// registers? True for Intel but false for most RISCs.
const bool Matcher::clone_shift_expressions = false;

// Do we need to mask the count passed to shift instructions or does
// the cpu only look at the lower 5/6 bits anyway?
// PowerPC requires masked shift counts.
const bool Matcher::need_masked_shift_count = true;

// This affects two different things:
//  - how Decode nodes are matched
//  - how ImplicitNullCheck opportunities are recognized
// If true, the matcher will try to remove all Decodes and match them
// (as operands) into nodes. NullChecks are not prepared to deal with
// Decodes by final_graph_reshaping().
// If false, final_graph_reshaping() forces the decode behind the Cmp
// for a NullCheck. The matcher matches the Decode node into a register.
// Implicit_null_check optimization moves the Decode along with the
// memory operation back up before the NullCheck.
bool Matcher::narrow_oop_use_complex_address() {
  // TODO: PPC port if (MatchDecodeNodes) return true;
  return false;
}

bool Matcher::narrow_klass_use_complex_address() {
  NOT_LP64(ShouldNotCallThis());
  assert(UseCompressedClassPointers, "only for compressed klass code");
  // TODO: PPC port if (MatchDecodeNodes) return true;
  return false;
}

// Is it better to copy float constants, or load them directly from memory?
// Intel can load a float constant from a direct address, requiring no
// extra registers. Most RISCs will have to materialize an address into a
// register first, so they would do better to copy the constant from stack.
const bool Matcher::rematerialize_float_constants = false;

// If CPU can load and store mis-aligned doubles directly then no fixup is
// needed. Else we split the double into 2 integer pieces and move it
// piece-by-piece. Only happens when passing doubles into C code as the
// Java calling convention forces doubles to be aligned.
const bool Matcher::misaligned_doubles_ok = true;

void Matcher::pd_implicit_null_fixup(MachNode *node, uint idx) {
 Unimplemented();
}

// Advertise here if the CPU requires explicit rounding operations
// to implement the UseStrictFP mode.
const bool Matcher::strict_fp_requires_explicit_rounding = false;

// Do floats take an entire double register or just half?
//
// A float occupies a ppc64 double register. For the allocator, a
// ppc64 double register appears as a pair of float registers.
bool Matcher::float_in_double() { return true; }

// Do ints take an entire long register or just half?
// The relevant question is how the int is callee-saved:
// the whole long is written but de-opt'ing will have to extract
// the relevant 32 bits.
const bool Matcher::int_in_long = true;

// Constants for c2c and c calling conventions.

const MachRegisterNumbers iarg_reg[8] = {
  R3_num, R4_num, R5_num, R6_num,
  R7_num, R8_num, R9_num, R10_num
};

const MachRegisterNumbers farg_reg[13] = {
  F1_num, F2_num, F3_num, F4_num,
  F5_num, F6_num, F7_num, F8_num,
  F9_num, F10_num, F11_num, F12_num,
  F13_num
};

const int num_iarg_registers = sizeof(iarg_reg) / sizeof(iarg_reg[0]);

const int num_farg_registers = sizeof(farg_reg) / sizeof(farg_reg[0]);

// Return whether or not this register is ever used as an argument. This
// function is used on startup to build the trampoline stubs in generateOptoStub.
// Registers not mentioned will be killed by the VM call in the trampoline, and
// arguments in those registers not be available to the callee.
bool Matcher::can_be_java_arg(int reg) {
  // We return true for all registers contained in iarg_reg[] and
  // farg_reg[] and their virtual halves.
  // We must include the virtual halves in order to get STDs and LDs
  // instead of STWs and LWs in the trampoline stubs.

  if (   reg == R3_num  || reg == R3_H_num
      || reg == R4_num  || reg == R4_H_num
      || reg == R5_num  || reg == R5_H_num
      || reg == R6_num  || reg == R6_H_num
      || reg == R7_num  || reg == R7_H_num
      || reg == R8_num  || reg == R8_H_num
      || reg == R9_num  || reg == R9_H_num
      || reg == R10_num || reg == R10_H_num)
    return true;

  if (   reg == F1_num  || reg == F1_H_num
      || reg == F2_num  || reg == F2_H_num
      || reg == F3_num  || reg == F3_H_num
      || reg == F4_num  || reg == F4_H_num
      || reg == F5_num  || reg == F5_H_num
      || reg == F6_num  || reg == F6_H_num
      || reg == F7_num  || reg == F7_H_num
      || reg == F8_num  || reg == F8_H_num
      || reg == F9_num  || reg == F9_H_num
      || reg == F10_num || reg == F10_H_num
      || reg == F11_num || reg == F11_H_num
      || reg == F12_num || reg == F12_H_num
      || reg == F13_num || reg == F13_H_num)
    return true;

  return false;
}

bool Matcher::is_spillable_arg(int reg) {
  return can_be_java_arg(reg);
}

bool Matcher::use_asm_for_ldiv_by_con(jlong divisor) {
  return false;
}

// Register for DIVI projection of divmodI.
RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI.
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL.
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL.
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return RegMask();
}


#line 1549 "../generated/adfiles/ad_ppc_64.cpp"


//SourceForm

#line 2589 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


typedef struct {
  loadConL_hiNode *_large_hi;
  loadConL_loNode *_large_lo;
  loadConLNode    *_small;
  MachNode        *_last;
} loadConLNodesTuple;

loadConLNodesTuple loadConLNodesTuple_create(Compile *C, PhaseRegAlloc *ra_, Node *toc, immLOper *immSrc,
                                             OptoReg::Name reg_second, OptoReg::Name reg_first) {
  loadConLNodesTuple nodes;

  const bool large_constant_pool = true; // TODO: PPC port C->cfg()->_consts_size > 4000;
  if (large_constant_pool) {
    // Create new nodes.
    loadConL_hiNode *m1 = new (C) loadConL_hiNode();
    loadConL_loNode *m2 = new (C) loadConL_loNode();

    // inputs for new nodes
    m1->add_req(NULL, toc);
    m2->add_req(NULL, m1);

    // operands for new nodes
    m1->_opnds[0] = new (C) iRegLdstOper(); // dst
    m1->_opnds[1] = immSrc;                 // src
    m1->_opnds[2] = new (C) iRegPdstOper(); // toc
    m2->_opnds[0] = new (C) iRegLdstOper(); // dst
    m2->_opnds[1] = immSrc;                 // src
    m2->_opnds[2] = new (C) iRegLdstOper(); // base

    // Initialize ins_attrib TOC fields.
    m1->_const_toc_offset = -1;
    m2->_const_toc_offset_hi_node = m1;

    // Initialize ins_attrib instruction offset.
    m1->_cbuf_insts_offset = -1;

    // register allocation for new nodes
    ra_->set_pair(m1->_idx, reg_second, reg_first);
    ra_->set_pair(m2->_idx, reg_second, reg_first);

    // Create result.
    nodes._large_hi = m1;
    nodes._large_lo = m2;
    nodes._small = NULL;
    nodes._last = nodes._large_lo;
    assert(m2->bottom_type()->isa_long(), "must be long");
  } else {
    loadConLNode *m2 = new (C) loadConLNode();

    // inputs for new nodes
    m2->add_req(NULL, toc);

    // operands for new nodes
    m2->_opnds[0] = new (C) iRegLdstOper(); // dst
    m2->_opnds[1] = immSrc;                 // src
    m2->_opnds[2] = new (C) iRegPdstOper(); // toc

    // Initialize ins_attrib instruction offset.
    m2->_cbuf_insts_offset = -1;

    // register allocation for new nodes
    ra_->set_pair(m2->_idx, reg_second, reg_first);

    // Create result.
    nodes._large_hi = NULL;
    nodes._large_lo = NULL;
    nodes._small = m2;
    nodes._last = nodes._small;
    assert(m2->bottom_type()->isa_long(), "must be long");
  }

  return nodes;
}


#line 1632 "../generated/adfiles/ad_ppc_64.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( DEFAULT_COST_LOW == 30, "Expect (30) to equal 30");
  assert( DEFAULT_COST == 100, "Expect (100) to equal 100");
  assert( HUGE_COST == 1000000, "Expect (1000000) to equal 1000000");
  assert( MEMORY_REF_COST_LOW == 200, "Expect (DEFAULT_COST * 2) to equal 200");
  assert( MEMORY_REF_COST == 300, "Expect (DEFAULT_COST * 3) to equal 300");
  assert( BRANCH_COST == 900, "Expect (DEFAULT_COST * 9) to equal 900");
  assert( CALL_COST == 1300, "Expect (DEFAULT_COST * 13) to equal 1300");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R14
  'C', // R14_H
  'C', // R15
  'C', // R15_H
  'C', // R17
  'C', // R17_H
  'C', // R18
  'C', // R18_H
  'C', // R19
  'C', // R19_H
  'C', // R20
  'C', // R20_H
  'C', // R21
  'C', // R21_H
  'C', // R22
  'C', // R22_H
  'C', // R23
  'C', // R23_H
  'C', // R24
  'C', // R24_H
  'C', // R25
  'C', // R25_H
  'C', // R26
  'C', // R26_H
  'C', // R27
  'C', // R27_H
  'C', // R28
  'C', // R28_H
  'C', // R29
  'C', // R29_H
  'C', // R30
  'C', // R30_H
  'C', // R31
  'C', // R31_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R10
  'C', // R10_H
  'C', // R9
  'C', // R9_H
  'C', // R8
  'C', // R8_H
  'C', // R7
  'C', // R7_H
  'C', // R6
  'C', // R6_H
  'C', // R5
  'C', // R5_H
  'C', // R4
  'C', // R4_H
  'C', // R3
  'C', // R3_H
  'C', // R16
  'C', // R16_H
  'N', // R13
  'N', // R13_H
  'C', // R2
  'C', // R2_H
  'N', // R1
  'N', // R1_H
  'C', // R0
  'C', // R0_H
  'C', // F0
  'C', // F0_H
  'C', // F13
  'C', // F13_H
  'C', // F12
  'C', // F12_H
  'C', // F11
  'C', // F11_H
  'C', // F10
  'C', // F10_H
  'C', // F9
  'C', // F9_H
  'C', // F8
  'C', // F8_H
  'C', // F7
  'C', // F7_H
  'C', // F6
  'C', // F6_H
  'C', // F5
  'C', // F5_H
  'C', // F4
  'C', // F4_H
  'C', // F3
  'C', // F3_H
  'C', // F2
  'C', // F2_H
  'C', // F1
  'C', // F1_H
  'C', // F14
  'C', // F14_H
  'C', // F15
  'C', // F15_H
  'C', // F16
  'C', // F16_H
  'C', // F17
  'C', // F17_H
  'C', // F18
  'C', // F18_H
  'C', // F19
  'C', // F19_H
  'C', // F20
  'C', // F20_H
  'C', // F21
  'C', // F21_H
  'C', // F22
  'C', // F22_H
  'C', // F23
  'C', // F23_H
  'C', // F24
  'C', // F24_H
  'C', // F25
  'C', // F25_H
  'C', // F26
  'C', // F26_H
  'C', // F27
  'C', // F27_H
  'C', // F28
  'C', // F28_H
  'C', // F29
  'C', // F29_H
  'C', // F30
  'C', // F30_H
  'C', // F31
  'C', // F31_H
  'C', // CCR0
  'C', // CCR1
  'C', // CCR2
  'C', // CCR3
  'C', // CCR4
  'C', // CCR5
  'C', // CCR6
  'C', // CCR7
  'C', // SR_XER
  'C', // SR_LR
  'C', // SR_CTR
  'C', // SR_VRSAVE
  'C', // SR_SPEFSCR
  'C' // no trailing comma // SR_PPR
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'E', // R14
  'E', // R14_H
  'E', // R15
  'E', // R15_H
  'E', // R17
  'E', // R17_H
  'E', // R18
  'E', // R18_H
  'E', // R19
  'E', // R19_H
  'E', // R20
  'E', // R20_H
  'E', // R21
  'E', // R21_H
  'E', // R22
  'E', // R22_H
  'E', // R23
  'E', // R23_H
  'E', // R24
  'E', // R24_H
  'E', // R25
  'E', // R25_H
  'E', // R26
  'E', // R26_H
  'E', // R27
  'E', // R27_H
  'E', // R28
  'E', // R28_H
  'E', // R29
  'E', // R29_H
  'E', // R30
  'E', // R30_H
  'E', // R31
  'E', // R31_H
  'C', // R11
  'C', // R11_H
  'C', // R12
  'C', // R12_H
  'C', // R10
  'C', // R10_H
  'C', // R9
  'C', // R9_H
  'C', // R8
  'C', // R8_H
  'C', // R7
  'C', // R7_H
  'C', // R6
  'C', // R6_H
  'C', // R5
  'C', // R5_H
  'C', // R4
  'C', // R4_H
  'C', // R3
  'C', // R3_H
  'E', // R16
  'E', // R16_H
  'N', // R13
  'N', // R13_H
  'C', // R2
  'C', // R2_H
  'N', // R1
  'N', // R1_H
  'C', // R0
  'C', // R0_H
  'C', // F0
  'C', // F0_H
  'C', // F13
  'C', // F13_H
  'C', // F12
  'C', // F12_H
  'C', // F11
  'C', // F11_H
  'C', // F10
  'C', // F10_H
  'C', // F9
  'C', // F9_H
  'C', // F8
  'C', // F8_H
  'C', // F7
  'C', // F7_H
  'C', // F6
  'C', // F6_H
  'C', // F5
  'C', // F5_H
  'C', // F4
  'C', // F4_H
  'C', // F3
  'C', // F3_H
  'C', // F2
  'C', // F2_H
  'C', // F1
  'C', // F1_H
  'E', // F14
  'E', // F14_H
  'E', // F15
  'E', // F15_H
  'E', // F16
  'E', // F16_H
  'E', // F17
  'E', // F17_H
  'E', // F18
  'E', // F18_H
  'E', // F19
  'E', // F19_H
  'E', // F20
  'E', // F20_H
  'E', // F21
  'E', // F21_H
  'E', // F22
  'E', // F22_H
  'E', // F23
  'E', // F23_H
  'E', // F24
  'E', // F24_H
  'E', // F25
  'E', // F25_H
  'E', // F26
  'E', // F26_H
  'E', // F27
  'E', // F27_H
  'E', // F28
  'E', // F28_H
  'E', // F29
  'E', // F29_H
  'E', // F30
  'E', // F30_H
  'E', // F31
  'E', // F31_H
  'C', // CCR0
  'C', // CCR1
  'C', // CCR2
  'C', // CCR3
  'C', // CCR4
  'C', // CCR5
  'C', // CCR6
  'C', // CCR7
  'C', // SR_XER
  'C', // SR_LR
  'C', // SR_CTR
  'C', // SR_VRSAVE
  'C', // SR_SPEFSCR
  'C' // no trailing comma // SR_PPR
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegFlags,
  Op_RegP,
  Op_RegP,
  Op_RegP,
  Op_RegP,
  Op_RegP,
  Op_RegP // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immI_rule,
  /*    9 */  immI8_rule,
  /*   10 */  immI16_rule,
  /*   11 */  immIhi16_rule,
  /*   12 */  immInegpow2_rule,
  /*   13 */  immIpow2minus1_rule,
  /*   14 */  immIpowerOf2_rule,
  /*   15 */  uimmI5_rule,
  /*   16 */  uimmI6_rule,
  /*   17 */  uimmI6_ge32_rule,
  /*   18 */  uimmI15_rule,
  /*   19 */  uimmI16_rule,
  /*   20 */  immI_0_rule,
  /*   21 */  immI_1_rule,
  /*   22 */  immI_minus1_rule,
  /*   23 */  immI_16_rule,
  /*   24 */  immI_24_rule,
  /*   25 */  immN_rule,
  /*   26 */  immN_0_rule,
  /*   27 */  immNKlass_rule,
  /*   28 */  immNKlass_NM_rule,
  /*   29 */  immP_rule,
  /*   30 */  immP_NM_rule,
  /*   31 */  immP_0_rule,
  /*   32 */  immP_0or1_rule,
  /*   33 */  immL_rule,
  /*   34 */  immL16_rule,
  /*   35 */  immL16Alg4_rule,
  /*   36 */  immL32hi16_rule,
  /*   37 */  immL32_rule,
  /*   38 */  immLhighest16_rule,
  /*   39 */  immLnegpow2_rule,
  /*   40 */  immLpow2minus1_rule,
  /*   41 */  immL_0_rule,
  /*   42 */  immL_minus1_rule,
  /*   43 */  immL_32bits_rule,
  /*   44 */  uimmL16_rule,
  /*   45 */  immF_rule,
  /*   46 */  immF_0_rule,
  /*   47 */  immD_rule,
  /*   48 */  iRegIdst_rule,
  /*   49 */  iRegIsrc_rule,
  /*   50 */  rscratch1RegI_rule,
  /*   51 */  rscratch2RegI_rule,
  /*   52 */  rarg1RegI_rule,
  /*   53 */  rarg2RegI_rule,
  /*   54 */  rarg3RegI_rule,
  /*   55 */  rarg4RegI_rule,
  /*   56 */  rarg1RegL_rule,
  /*   57 */  rarg2RegL_rule,
  /*   58 */  rarg3RegL_rule,
  /*   59 */  rarg4RegL_rule,
  /*   60 */  iRegPdst_rule,
  /*   61 */  iRegPdstNoScratch_rule,
  /*   62 */  iRegPsrc_rule,
  /*   63 */  threadRegP_rule,
  /*   64 */  rscratch1RegP_rule,
  /*   65 */  rscratch2RegP_rule,
  /*   66 */  rarg1RegP_rule,
  /*   67 */  rarg2RegP_rule,
  /*   68 */  rarg3RegP_rule,
  /*   69 */  rarg4RegP_rule,
  /*   70 */  iRegNsrc_rule,
  /*   71 */  iRegNdst_rule,
  /*   72 */  iRegLdst_rule,
  /*   73 */  iRegLsrc_rule,
  /*   74 */  iRegL2Isrc_rule,
  /*   75 */  rscratch1RegL_rule,
  /*   76 */  rscratch2RegL_rule,
  /*   77 */  flagsReg_rule,
  /*   78 */  flagsRegCR0_rule,
  /*   79 */  flagsRegCR1_rule,
  /*   80 */  flagsRegCR6_rule,
  /*   81 */  regCTR_rule,
  /*   82 */  regD_rule,
  /*   83 */  regF_rule,
  /*   84 */  inline_cache_regP_rule,
  /*   85 */  compiler_method_oop_regP_rule,
  /*   86 */  interpreter_method_oop_regP_rule,
  /*   87 */  iRegP2N_rule,
  /*   88 */  iRegN2P_rule,
  /*   89 */  indirect_rule,
  /*   90 */  indOffset16_rule,
  /*   91 */  indOffset16Alg4_rule,
  /*   92 */  indirectNarrow_rule,
  /*   93 */  indOffset16Narrow_rule,
  /*   94 */  indOffset16NarrowAlg4_rule,
  /*   95 */  stackSlotI_rule,
  /*   96 */  stackSlotL_rule,
  /*   97 */  stackSlotP_rule,
  /*   98 */  stackSlotF_rule,
  /*   99 */  stackSlotD_rule,
  /*  100 */  cmpOp_rule,
  // last operand
  /*  101 */  memory_rule,
  /*  102 */  memoryAlg4_rule,
  /*  103 */  indirectMemory_rule,
  /*  104 */  iRegIsrc_iRegL2Isrc_rule,
  /*  105 */  iRegN_P2N_rule,
  /*  106 */  iRegP_N2P_rule,
  // last operand class
  /*  107 */  _DecodeN_iRegNsrc__rule,
  /*  108 */  _DecodeNKlass_iRegNsrc__rule,
  /*  109 */  _LoadUB_memory__rule,
  /*  110 */  _LoadUS_memory__rule,
  /*  111 */  _LoadI_memory__rule,
  /*  112 */  _ConvI2L__LoadI_memory___rule,
  /*  113 */  _LoadI_memoryAlg4__rule,
  /*  114 */  _LoadN_memory__rule,
  /*  115 */  _LoadP_memoryAlg4__rule,
  /*  116 */  _AddP_indirectMemory_iRegLsrc_rule,
  /*  117 */  _ConvL2I_iRegLsrc__rule,
  /*  118 */  _Binary_flagsReg_iRegPsrc_rule,
  /*  119 */  _CastP2X__DecodeN_iRegNsrc___rule,
  /*  120 */  _Binary_iRegLsrc_iRegPdst_rule,
  /*  121 */  _Binary_iRegLsrc_iRegPsrc_rule,
  /*  122 */  _Binary_iRegLsrc_iRegNsrc_rule,
  /*  123 */  _Binary_cmpOp_flagsReg_rule,
  /*  124 */  _Binary_iRegIdst_iRegIsrc_rule,
  /*  125 */  _Binary_iRegIdst_immI16_rule,
  /*  126 */  _Binary_iRegLdst_iRegLsrc_rule,
  /*  127 */  _Binary_iRegLdst_immL16_rule,
  /*  128 */  _Binary_iRegNdst_iRegNsrc_rule,
  /*  129 */  _Binary_iRegNdst_immN_0_rule,
  /*  130 */  _Binary_iRegPdst_iRegPsrc_rule,
  /*  131 */  _Binary_iRegPdst_iRegP_N2P_rule,
  /*  132 */  _Binary_iRegPdst_immP_0_rule,
  /*  133 */  _Binary_regF_regF_rule,
  /*  134 */  _Binary_regD_regD_rule,
  /*  135 */  _Binary_iRegLsrc_iRegLsrc_rule,
  /*  136 */  _Binary_iRegPsrc_iRegPsrc_rule,
  /*  137 */  _Binary_iRegIsrc_iRegIsrc_rule,
  /*  138 */  _Binary_iRegNsrc_iRegNsrc_rule,
  /*  139 */  _AddI_iRegIsrc_iRegIsrc_rule,
  /*  140 */  _AddI__AddI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  141 */  _AddI_iRegIsrc__AddI_iRegIsrc_iRegIsrc_rule,
  /*  142 */  _AddL_iRegLsrc_iRegLsrc_rule,
  /*  143 */  _AddL__AddL_iRegLsrc_iRegLsrc_iRegLsrc_rule,
  /*  144 */  _AddL_iRegLsrc__AddL_iRegLsrc_iRegLsrc_rule,
  /*  145 */  _SubL_iRegLsrc_iRegLsrc_rule,
  /*  146 */  _SubL_immL_0_iRegLsrc_rule,
  /*  147 */  _AndI_iRegIsrc_immInegpow2_rule,
  /*  148 */  _RShiftI_iRegIsrc_uimmI5_rule,
  /*  149 */  _AndI__RShiftI_iRegIsrc_uimmI5_immInegpow2_rule,
  /*  150 */  _ConvI2L_iRegIsrc__rule,
  /*  151 */  _RShiftL_iRegLsrc_immI_rule,
  /*  152 */  _URShiftL_iRegLsrc_immI_rule,
  /*  153 */  _CastP2X_iRegP_N2P__rule,
  /*  154 */  _URShiftI_iRegIsrc_immI_rule,
  /*  155 */  _LShiftI_iRegIsrc_immI8_rule,
  /*  156 */  _URShiftI_iRegIsrc_immI8_rule,
  /*  157 */  _AbsF_regF__rule,
  /*  158 */  _AbsD_regD__rule,
  /*  159 */  _ConvF2D_regF__rule,
  /*  160 */  _SqrtD__ConvF2D_regF___rule,
  /*  161 */  _AndL_iRegLsrc_immLpow2minus1_rule,
  /*  162 */  _OrI_iRegIsrc_iRegIsrc_rule,
  /*  163 */  _OrI__OrI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  164 */  _OrI_iRegIsrc__OrI_iRegIsrc_iRegIsrc_rule,
  /*  165 */  _OrL_iRegLsrc_iRegLsrc_rule,
  /*  166 */  _XorI_iRegIsrc_iRegIsrc_rule,
  /*  167 */  _XorI__XorI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  168 */  _XorI_iRegIsrc__XorI_iRegIsrc_iRegIsrc_rule,
  /*  169 */  _XorL_iRegLsrc_iRegLsrc_rule,
  /*  170 */  _XorI_iRegIsrc_immI_minus1_rule,
  /*  171 */  _Conv2B_iRegIsrc__rule,
  /*  172 */  _AndI_iRegIsrc_immIpowerOf2_rule,
  /*  173 */  _Conv2B_iRegP_N2P__rule,
  /*  174 */  _LShiftI_iRegIsrc_immI_24_rule,
  /*  175 */  _LShiftI_iRegIsrc_immI_16_rule,
  /*  176 */  _AndI_iRegIsrc_uimmI16_rule,
  /*  177 */  _AndL_iRegLsrc_iRegLsrc_rule,
  /*  178 */  _AndL_iRegLsrc_uimmL16_rule,
  /*  179 */  _CmpU_iRegIsrc_uimmI15_rule,
  /*  180 */  _CmpU_iRegIsrc_iRegIsrc_rule,
  /*  181 */  _CmpN_iRegNsrc_immN_0_rule,
  /*  182 */  _CmpP_iRegP_N2P_immP_0_rule,
  /*  183 */  _CastP2X_iRegPsrc__rule,
  /*  184 */  _AndL__CastP2X_iRegPsrc__immLnegpow2_rule,
  /*  185 */  _Binary_iRegPsrc_iRegIsrc_rule,
  /*  186 */  _AddP_immP_immL_rule,
  /*  187 */  _Binary__AddP_immP_immL_immI_1_rule,
  /*  188 */  _Binary_rscratch2RegP_immI_1_rule,
  /*  189 */  _Binary_iRegPsrc_rscratch1RegI_rule,
  /*  190 */  _Binary_iRegPsrc_uimmI15_rule,
  /*  191 */  _Binary_iRegPsrc_rscratch2RegI_rule,
  /*  192 */  _Binary_rarg1RegP_rarg3RegI_rule,
  /*  193 */  _Binary_rarg2RegP_rarg4RegI_rule,
  // last internally defined operand
  /*  194 */  stackSlotI_rule,
  /*  195 */  stackSlotL_rule,
  /*  196 */  iRegIdst_rule,
  /*  197 */  iRegIdst_rule,
  /*  198 */  iRegIdst_rule,
  /*  199 */  iRegLdst_rule,
  /*  200 */  iRegLdst_rule,
  /*  201 */  iRegLdst_rule,
  /*  202 */  iRegLdst_rule,
  /*  203 */  iRegLdst_rule,
  /*  204 */  iRegNdst_rule,
  /*  205 */  iRegNdst_rule,
  /*  206 */  iRegNdst_rule,
  /*  207 */  iRegNdst_rule,
  /*  208 */  iRegNdst_rule,
  /*  209 */  iRegNdst_rule,
  /*  210 */  iRegPdst_rule,
  /*  211 */  iRegPdst_rule,
  /*  212 */  iRegPdst_rule,
  /*  213 */  iRegPdst_rule,
  /*  214 */  regF_rule,
  /*  215 */  regD_rule,
  /*  216 */  iRegIdst_rule,
  /*  217 */  iRegLdst_rule,
  /*  218 */  0,
  /*  219 */  iRegLdst_rule,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  flagsReg_rule,
  /*  224 */  flagsReg_rule,
  /*  225 */  0,
  /*  226 */  iRegIdst_rule,
  /*  227 */  0,
  /*  228 */  0,
  /*  229 */  regF_rule,
  /*  230 */  regD_rule,
  /*  231 */  regF_rule,
  /*  232 */  regD_rule,
  /*  233 */  regF_rule,
  /*  234 */  regD_rule,
  /*  235 */  regD_rule,
  /*  236 */  regF_rule,
  /*  237 */  iRegIdst_rule,
  /*  238 */  regF_rule,
  /*  239 */  iRegLdst_rule,
  /*  240 */  regD_rule,
  /*  241 */  0,
  /*  242 */  iRegPdst_rule,
  /*  243 */  iRegLdst_rule,
  /*  244 */  iRegPdst_rule,
  /*  245 */  iRegIdst_rule,
  /*  246 */  iRegPdst_rule,
  /*  247 */  iRegIdst_rule,
  /*  248 */  iRegIdst_rule,
  /*  249 */  0,
  /*  250 */  0,
  /*  251 */  0,
  /*  252 */  0,
  /*  253 */  0,
  /*  254 */  0,
  /*  255 */  flagsReg_rule,
  /*  256 */  flagsReg_rule,
  /*  257 */  flagsRegCR0_rule,
  /*  258 */  flagsReg_rule,
  /*  259 */  flagsReg_rule,
  /*  260 */  flagsReg_rule,
  /*  261 */  flagsReg_rule,
  /*  262 */  flagsRegCR0_rule,
  /*  263 */  flagsRegCR0_rule,
  /*  264 */  0,
  /*  265 */  0,
  /*  266 */  flagsReg_rule,
  /*  267 */  flagsReg_rule,
  /*  268 */  flagsReg_rule,
  /*  269 */  flagsReg_rule,
  /*  270 */  flagsReg_rule,
  /*  271 */  flagsReg_rule,
  /*  272 */  flagsReg_rule,
  /*  273 */  0,
  /*  274 */  0,
  /*  275 */  flagsReg_rule,
  /*  276 */  0,
  /*  277 */  flagsReg_rule,
  /*  278 */  flagsReg_rule,
  /*  279 */  flagsReg_rule,
  /*  280 */  iRegIdst_rule,
  /*  281 */  iRegIdst_rule,
  /*  282 */  iRegIdst_rule,
  /*  283 */  iRegIdst_rule,
  /*  284 */  0,
  /*  285 */  iRegIdst_rule,
  /*  286 */  iRegIdst_rule,
  /*  287 */  0,
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  threadRegP_rule,
  /*  292 */  iRegIdst_rule,
  /*  293 */  iRegIdst_rule,
  /*  294 */  iRegIdst_rule,
  /*  295 */  iRegIdst_rule,
  /*  296 */  iRegIdst_rule,
  /*  297 */  iRegIdst_rule,
  /*  298 */  iRegIdst_rule,
  /*  299 */  iRegIdst_rule,
  /*  300 */  iRegIdst_rule,
  /*  301 */  iRegIdst_rule,
  /*  302 */  iRegLdst_rule,
  /*  303 */  iRegLdst_rule,
  /*  304 */  iRegIdst_rule,
  /*  305 */  iRegIdst_rule,
  /*  306 */  iRegIdst_rule,
  /*  307 */  iRegIdst_rule,
  /*  308 */  iRegLdst_rule,
  /*  309 */  iRegLdst_rule,
  /*  310 */  iRegIdst_rule,
  /*  311 */  iRegIdst_rule,
  /*  312 */  iRegLdst_rule,
  /*  313 */  iRegLdst_rule,
  /*  314 */  iRegLdst_rule,
  /*  315 */  iRegLdst_rule,
  /*  316 */  iRegLdst_rule,
  /*  317 */  iRegLdst_rule,
  /*  318 */  iRegLdst_rule,
  /*  319 */  iRegIdst_rule,
  /*  320 */  iRegNdst_rule,
  /*  321 */  iRegNdst_rule,
  /*  322 */  iRegPdst_rule,
  /*  323 */  iRegPdst_rule,
  /*  324 */  iRegPdst_rule,
  /*  325 */  iRegNdst_rule,
  /*  326 */  iRegPdst_rule,
  /*  327 */  regF_rule,
  /*  328 */  regF_rule,
  /*  329 */  regD_rule,
  /*  330 */  regD_rule,
  /*  331 */  regD_rule,
  /*  332 */  0,
  /*  333 */  0,
  /*  334 */  0,
  /*  335 */  0,
  /*  336 */  0,
  /*  337 */  0,
  /*  338 */  0,
  /*  339 */  0,
  /*  340 */  0,
  /*  341 */  0,
  /*  342 */  0,
  /*  343 */  0,
  /*  344 */  Universe_rule,
  /*  345 */  Universe_rule,
  /*  346 */  Universe_rule,
  /*  347 */  Universe_rule,
  /*  348 */  Universe_rule,
  /*  349 */  Universe_rule,
  /*  350 */  Universe_rule,
  /*  351 */  Universe_rule,
  /*  352 */  Universe_rule,
  /*  353 */  Universe_rule,
  /*  354 */  Universe_rule,
  /*  355 */  Universe_rule,
  /*  356 */  Universe_rule,
  /*  357 */  Universe_rule,
  /*  358 */  Universe_rule,
  /*  359 */  Universe_rule,
  /*  360 */  Universe_rule,
  /*  361 */  Universe_rule,
  /*  362 */  Universe_rule,
  /*  363 */  Universe_rule,
  /*  364 */  Universe_rule,
  /*  365 */  Universe_rule,
  /*  366 */  iRegNdst_rule,
  /*  367 */  iRegPdst_rule,
  /*  368 */  iRegNdst_rule,
  /*  369 */  iRegNdst_rule,
  /*  370 */  iRegNdst_rule,
  /*  371 */  iRegNdst_rule,
  /*  372 */  iRegNdst_rule,
  /*  373 */  iRegNdst_rule,
  /*  374 */  iRegNdst_rule,
  /*  375 */  iRegPdst_rule,
  /*  376 */  iRegPdst_rule,
  /*  377 */  iRegPdst_rule,
  /*  378 */  iRegPdst_rule,
  /*  379 */  iRegPdst_rule,
  /*  380 */  iRegPdst_rule,
  /*  381 */  iRegPdst_rule,
  /*  382 */  iRegPdst_rule,
  /*  383 */  iRegIdst_rule,
  /*  384 */  iRegNdst_rule,
  /*  385 */  iRegPdst_rule,
  /*  386 */  iRegNdst_rule,
  /*  387 */  iRegNdst_rule,
  /*  388 */  iRegNdst_rule,
  /*  389 */  iRegPdst_rule,
  /*  390 */  iRegPdst_rule,
  /*  391 */  iRegPdst_rule,
  /*  392 */  iRegPdst_rule,
  /*  393 */  Universe_rule,
  /*  394 */  Universe_rule,
  /*  395 */  Universe_rule,
  /*  396 */  Universe_rule,
  /*  397 */  Universe_rule,
  /*  398 */  Universe_rule,
  /*  399 */  Universe_rule,
  /*  400 */  Universe_rule,
  /*  401 */  Universe_rule,
  /*  402 */  iRegIdst_rule,
  /*  403 */  iRegIdst_rule,
  /*  404 */  iRegIdst_rule,
  /*  405 */  iRegLdst_rule,
  /*  406 */  iRegLdst_rule,
  /*  407 */  iRegLdst_rule,
  /*  408 */  iRegNdst_rule,
  /*  409 */  iRegNdst_rule,
  /*  410 */  iRegNdst_rule,
  /*  411 */  iRegPdst_rule,
  /*  412 */  iRegPdst_rule,
  /*  413 */  iRegPdst_rule,
  /*  414 */  regF_rule,
  /*  415 */  regD_rule,
  /*  416 */  iRegPdst_rule,
  /*  417 */  iRegIdst_rule,
  /*  418 */  iRegIdst_rule,
  /*  419 */  iRegIdst_rule,
  /*  420 */  iRegIdst_rule,
  /*  421 */  iRegIdst_rule,
  /*  422 */  iRegLdst_rule,
  /*  423 */  iRegIdst_rule,
  /*  424 */  iRegLdst_rule,
  /*  425 */  iRegPdst_rule,
  /*  426 */  iRegNdst_rule,
  /*  427 */  iRegIdst_rule,
  /*  428 */  0,
  /*  429 */  iRegIdst_rule,
  /*  430 */  iRegIdst_rule,
  /*  431 */  iRegIdst_rule,
  /*  432 */  iRegIdst_rule,
  /*  433 */  iRegIdst_rule,
  /*  434 */  iRegIdst_rule,
  /*  435 */  iRegLdst_rule,
  /*  436 */  0,
  /*  437 */  iRegLdst_rule,
  /*  438 */  iRegLdst_rule,
  /*  439 */  iRegLdst_rule,
  /*  440 */  iRegLdst_rule,
  /*  441 */  iRegIdst_rule,
  /*  442 */  iRegLdst_rule,
  /*  443 */  iRegLdst_rule,
  /*  444 */  iRegPdst_rule,
  /*  445 */  iRegPdst_rule,
  /*  446 */  iRegPdst_rule,
  /*  447 */  iRegIdst_rule,
  /*  448 */  iRegIdst_rule,
  /*  449 */  iRegIdst_rule,
  /*  450 */  iRegIdst_rule,
  /*  451 */  iRegLdst_rule,
  /*  452 */  iRegIdst_rule,
  /*  453 */  iRegLdst_rule,
  /*  454 */  iRegLdst_rule,
  /*  455 */  iRegIdst_rule,
  /*  456 */  iRegIdst_rule,
  /*  457 */  iRegIdst_rule,
  /*  458 */  iRegLdst_rule,
  /*  459 */  iRegLdst_rule,
  /*  460 */  iRegLdst_rule,
  /*  461 */  iRegIdst_rule,
  /*  462 */  iRegIdst_rule,
  /*  463 */  0,
  /*  464 */  iRegIdst_rule,
  /*  465 */  iRegLdst_rule,
  /*  466 */  iRegLdst_rule,
  /*  467 */  0,
  /*  468 */  iRegLdst_rule,
  /*  469 */  iRegIdst_rule,
  /*  470 */  iRegLdst_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  iRegIdst_rule,
  /*  474 */  iRegIdst_rule,
  /*  475 */  iRegIdst_rule,
  /*  476 */  iRegIdst_rule,
  /*  477 */  0,
  /*  478 */  iRegLdst_rule,
  /*  479 */  iRegLdst_rule,
  /*  480 */  iRegLdst_rule,
  /*  481 */  iRegLdst_rule,
  /*  482 */  0,
  /*  483 */  iRegIdst_rule,
  /*  484 */  iRegIdst_rule,
  /*  485 */  0,
  /*  486 */  iRegLdst_rule,
  /*  487 */  iRegLdst_rule,
  /*  488 */  iRegIdst_rule,
  /*  489 */  0,
  /*  490 */  iRegIdst_rule,
  /*  491 */  iRegIdst_rule,
  /*  492 */  0,
  /*  493 */  iRegLdst_rule,
  /*  494 */  iRegLdst_rule,
  /*  495 */  iRegIdst_rule,
  /*  496 */  iRegLdst_rule,
  /*  497 */  iRegIdst_rule,
  /*  498 */  iRegLdst_rule,
  /*  499 */  iRegIdst_rule,
  /*  500 */  iRegIdst_rule,
  /*  501 */  iRegIdst_rule,
  /*  502 */  iRegIdst_rule,
  /*  503 */  iRegIdst_rule,
  /*  504 */  regF_rule,
  /*  505 */  regD_rule,
  /*  506 */  regF_rule,
  /*  507 */  regD_rule,
  /*  508 */  regF_rule,
  /*  509 */  regD_rule,
  /*  510 */  regF_rule,
  /*  511 */  regD_rule,
  /*  512 */  regD_rule,
  /*  513 */  regF_rule,
  /*  514 */  iRegIdst_rule,
  /*  515 */  iRegIdst_rule,
  /*  516 */  iRegIdst_rule,
  /*  517 */  iRegIdst_rule,
  /*  518 */  iRegIdst_rule,
  /*  519 */  iRegIdst_rule,
  /*  520 */  iRegLdst_rule,
  /*  521 */  iRegLdst_rule,
  /*  522 */  iRegLdst_rule,
  /*  523 */  iRegLdst_rule,
  /*  524 */  iRegIdst_rule,
  /*  525 */  iRegIdst_rule,
  /*  526 */  0,
  /*  527 */  iRegIdst_rule,
  /*  528 */  iRegIdst_rule,
  /*  529 */  iRegIdst_rule,
  /*  530 */  iRegIdst_rule,
  /*  531 */  iRegIdst_rule,
  /*  532 */  iRegLdst_rule,
  /*  533 */  iRegIdst_rule,
  /*  534 */  iRegLdst_rule,
  /*  535 */  iRegIdst_rule,
  /*  536 */  0,
  /*  537 */  iRegIdst_rule,
  /*  538 */  iRegIdst_rule,
  /*  539 */  iRegIdst_rule,
  /*  540 */  iRegIdst_rule,
  /*  541 */  iRegIdst_rule,
  /*  542 */  iRegLdst_rule,
  /*  543 */  iRegIdst_rule,
  /*  544 */  iRegLdst_rule,
  /*  545 */  iRegIdst_rule,
  /*  546 */  iRegLdst_rule,
  /*  547 */  iRegIdst_rule,
  /*  548 */  iRegIdst_rule,
  /*  549 */  0,
  /*  550 */  stackSlotI_rule,
  /*  551 */  stackSlotF_rule,
  /*  552 */  0,
  /*  553 */  stackSlotL_rule,
  /*  554 */  stackSlotD_rule,
  /*  555 */  iRegIdst_rule,
  /*  556 */  iRegIdst_rule,
  /*  557 */  iRegIdst_rule,
  /*  558 */  iRegIdst_rule,
  /*  559 */  iRegIdst_rule,
  /*  560 */  iRegIdst_rule,
  /*  561 */  iRegIdst_rule,
  /*  562 */  iRegIdst_rule,
  /*  563 */  iRegIdst_rule,
  /*  564 */  iRegIdst_rule,
  /*  565 */  iRegIdst_rule,
  /*  566 */  iRegLdst_rule,
  /*  567 */  iRegIdst_rule,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  iRegIdst_rule,
  /*  571 */  iRegIdst_rule,
  /*  572 */  iRegLdst_rule,
  /*  573 */  iRegLdst_rule,
  /*  574 */  iRegLdst_rule,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  iRegLdst_rule,
  /*  578 */  iRegLdst_rule,
  /*  579 */  regF_rule,
  /*  580 */  regF_rule,
  /*  581 */  regF_rule,
  /*  582 */  regF_rule,
  /*  583 */  regD_rule,
  /*  584 */  regD_rule,
  /*  585 */  regD_rule,
  /*  586 */  iRegIdst_rule,
  /*  587 */  Universe_rule,
  /*  588 */  Universe_rule,
  /*  589 */  Universe_rule,
  /*  590 */  Universe_rule,
  /*  591 */  Universe_rule,
  /*  592 */  iRegIdst_rule,
  /*  593 */  iRegIdst_rule,
  /*  594 */  Universe_rule,
  /*  595 */  Universe_rule,
  /*  596 */  Universe_rule,
  /*  597 */  Universe_rule,
  /*  598 */  Universe_rule,
  /*  599 */  Universe_rule,
  /*  600 */  Universe_rule,
  /*  601 */  iRegPdst_rule,
  /*  602 */  iRegPdst_rule,
  /*  603 */  iRegLdst_rule,
  /*  604 */  Universe_rule,
  /*  605 */  iRegIdst_rule,
  /*  606 */  iRegIdst_rule,
  /*  607 */  iRegIdst_rule,
  /*  608 */  iRegIdst_rule,
  /*  609 */  iRegIdst_rule,
  /*  610 */  iRegIdst_rule,
  /*  611 */  iRegIdst_rule,
  /*  612 */  iRegIdst_rule,
  /*  613 */  iRegIdst_rule,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  iRegIdst_rule,
  /*  617 */  iRegLdst_rule,
  /*  618 */  iRegLdst_rule,
  /*  619 */  iRegLdst_rule,
  /*  620 */  iRegLdst_rule,
  /*  621 */  iRegLdst_rule,
  /*  622 */  iRegLdst_rule,
  /*  623 */  iRegLdst_rule,
  /*  624 */  iRegLdst_rule,
  /*  625 */  iRegLdst_rule,
  /*  626 */  iRegLdst_rule,
  /*  627 */  iRegLdst_rule,
  /*  628 */  iRegLdst_rule,
  /*  629 */  Universe_rule,
  /*  630 */  Universe_rule,
  /*  631 */  Universe_rule,
  /*  632 */  Universe_rule,
  /*  633 */  Universe_rule,
  /*  634 */  Universe_rule,
  /*  635 */  Universe_rule,
  /*  636 */  Universe_rule,
  /*  637 */  Universe_rule,
  /*  638 */  Universe_rule,
  /*  639 */  Universe_rule,
  /*  640 */  Universe_rule,
  /*  641 */  Universe_rule,
  /*  642 */  Universe_rule,
  /*  643 */  rarg1RegP_rule,
  /*  644 */  Universe_rule,
  /*  645 */  Universe_rule,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  0,
  /*  652 */  0,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  iRegLsrc_rule,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  iRegPsrc_rule,
  /*   88 */  iRegNsrc_rule,
  /*   89 */  0,
  /*   90 */  iRegPsrc_rule,
  /*   91 */  iRegPsrc_rule,
  /*   92 */  iRegNsrc_rule,
  /*   93 */  _DecodeN_iRegNsrc__rule,
  /*   94 */  _DecodeN_iRegNsrc__rule,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  // last operand
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  // last operand class
  /*  107 */  iRegNsrc_rule,
  /*  108 */  iRegNsrc_rule,
  /*  109 */  memory_rule,
  /*  110 */  memory_rule,
  /*  111 */  memory_rule,
  /*  112 */  _LoadI_memory__rule,
  /*  113 */  memoryAlg4_rule,
  /*  114 */  memory_rule,
  /*  115 */  memoryAlg4_rule,
  /*  116 */  indirectMemory_rule,
  /*  117 */  iRegLsrc_rule,
  /*  118 */  flagsReg_rule,
  /*  119 */  _DecodeN_iRegNsrc__rule,
  /*  120 */  iRegLsrc_rule,
  /*  121 */  iRegLsrc_rule,
  /*  122 */  iRegLsrc_rule,
  /*  123 */  cmpOp_rule,
  /*  124 */  iRegIdst_rule,
  /*  125 */  iRegIdst_rule,
  /*  126 */  iRegLdst_rule,
  /*  127 */  iRegLdst_rule,
  /*  128 */  iRegNdst_rule,
  /*  129 */  iRegNdst_rule,
  /*  130 */  iRegPdst_rule,
  /*  131 */  iRegPdst_rule,
  /*  132 */  iRegPdst_rule,
  /*  133 */  regF_rule,
  /*  134 */  regD_rule,
  /*  135 */  iRegLsrc_rule,
  /*  136 */  iRegPsrc_rule,
  /*  137 */  iRegIsrc_rule,
  /*  138 */  iRegNsrc_rule,
  /*  139 */  iRegIsrc_rule,
  /*  140 */  _AddI_iRegIsrc_iRegIsrc_rule,
  /*  141 */  iRegIsrc_rule,
  /*  142 */  iRegLsrc_rule,
  /*  143 */  _AddL_iRegLsrc_iRegLsrc_rule,
  /*  144 */  iRegLsrc_rule,
  /*  145 */  iRegLsrc_rule,
  /*  146 */  immL_0_rule,
  /*  147 */  iRegIsrc_rule,
  /*  148 */  iRegIsrc_rule,
  /*  149 */  _RShiftI_iRegIsrc_uimmI5_rule,
  /*  150 */  iRegIsrc_rule,
  /*  151 */  iRegLsrc_rule,
  /*  152 */  iRegLsrc_rule,
  /*  153 */  iRegP_N2P_rule,
  /*  154 */  iRegIsrc_rule,
  /*  155 */  iRegIsrc_rule,
  /*  156 */  iRegIsrc_rule,
  /*  157 */  regF_rule,
  /*  158 */  regD_rule,
  /*  159 */  regF_rule,
  /*  160 */  _ConvF2D_regF__rule,
  /*  161 */  iRegLsrc_rule,
  /*  162 */  iRegIsrc_rule,
  /*  163 */  _OrI_iRegIsrc_iRegIsrc_rule,
  /*  164 */  iRegIsrc_rule,
  /*  165 */  iRegLsrc_rule,
  /*  166 */  iRegIsrc_rule,
  /*  167 */  _XorI_iRegIsrc_iRegIsrc_rule,
  /*  168 */  iRegIsrc_rule,
  /*  169 */  iRegLsrc_rule,
  /*  170 */  iRegIsrc_rule,
  /*  171 */  iRegIsrc_rule,
  /*  172 */  iRegIsrc_rule,
  /*  173 */  iRegP_N2P_rule,
  /*  174 */  iRegIsrc_rule,
  /*  175 */  iRegIsrc_rule,
  /*  176 */  iRegIsrc_rule,
  /*  177 */  iRegLsrc_rule,
  /*  178 */  iRegLsrc_rule,
  /*  179 */  iRegIsrc_rule,
  /*  180 */  iRegIsrc_rule,
  /*  181 */  iRegNsrc_rule,
  /*  182 */  iRegP_N2P_rule,
  /*  183 */  iRegPsrc_rule,
  /*  184 */  _CastP2X_iRegPsrc__rule,
  /*  185 */  iRegPsrc_rule,
  /*  186 */  immP_rule,
  /*  187 */  _AddP_immP_immL_rule,
  /*  188 */  rscratch2RegP_rule,
  /*  189 */  iRegPsrc_rule,
  /*  190 */  iRegPsrc_rule,
  /*  191 */  iRegPsrc_rule,
  /*  192 */  rarg1RegP_rule,
  /*  193 */  rarg2RegP_rule,
  // last internally defined operand
  /*  194 */  iRegIsrc_rule,
  /*  195 */  iRegLsrc_rule,
  /*  196 */  immI16_rule,
  /*  197 */  immIhi16_rule,
  /*  198 */  immI_rule,
  /*  199 */  immL16_rule,
  /*  200 */  immL32hi16_rule,
  /*  201 */  immL32_rule,
  /*  202 */  immLhighest16_rule,
  /*  203 */  immL_rule,
  /*  204 */  immN_0_rule,
  /*  205 */  immN_rule,
  /*  206 */  immNKlass_NM_rule,
  /*  207 */  immNKlass_NM_rule,
  /*  208 */  immNKlass_NM_rule,
  /*  209 */  immNKlass_rule,
  /*  210 */  immP_0or1_rule,
  /*  211 */  immP_NM_rule,
  /*  212 */  immP_NM_rule,
  /*  213 */  immP_rule,
  /*  214 */  immF_rule,
  /*  215 */  immD_rule,
  /*  216 */  stackSlotI_rule,
  /*  217 */  stackSlotL_rule,
  /*  218 */  0,
  /*  219 */  _LoadP_memoryAlg4__rule,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  indirect_rule,
  /*  224 */  indirect_rule,
  /*  225 */  0,
  /*  226 */  iRegIsrc_rule,
  /*  227 */  0,
  /*  228 */  0,
  /*  229 */  regF_rule,
  /*  230 */  regD_rule,
  /*  231 */  regF_rule,
  /*  232 */  regD_rule,
  /*  233 */  _AbsF_regF__rule,
  /*  234 */  _AbsD_regD__rule,
  /*  235 */  regD_rule,
  /*  236 */  regF_rule,
  /*  237 */  stackSlotF_rule,
  /*  238 */  stackSlotI_rule,
  /*  239 */  stackSlotD_rule,
  /*  240 */  stackSlotL_rule,
  /*  241 */  0,
  /*  242 */  iRegLsrc_rule,
  /*  243 */  iRegP_N2P_rule,
  /*  244 */  iRegPdst_rule,
  /*  245 */  iRegIdst_rule,
  /*  246 */  iRegPdst_rule,
  /*  247 */  iRegIsrc_rule,
  /*  248 */  iRegP_N2P_rule,
  /*  249 */  0,
  /*  250 */  0,
  /*  251 */  0,
  /*  252 */  0,
  /*  253 */  0,
  /*  254 */  0,
  /*  255 */  iRegIsrc_rule,
  /*  256 */  iRegIsrc_rule,
  /*  257 */  _AndI_iRegIsrc_uimmI16_rule,
  /*  258 */  iRegLsrc_rule,
  /*  259 */  iRegLsrc_rule,
  /*  260 */  iRegLsrc_rule,
  /*  261 */  iRegLsrc_rule,
  /*  262 */  _AndL_iRegLsrc_iRegLsrc_rule,
  /*  263 */  _AndL_iRegLsrc_uimmL16_rule,
  /*  264 */  0,
  /*  265 */  0,
  /*  266 */  iRegIsrc_rule,
  /*  267 */  iRegIsrc_rule,
  /*  268 */  iRegNsrc_rule,
  /*  269 */  iRegNsrc_rule,
  /*  270 */  iRegP_N2P_rule,
  /*  271 */  iRegP_N2P_rule,
  /*  272 */  iRegPsrc_rule,
  /*  273 */  0,
  /*  274 */  0,
  /*  275 */  regF_rule,
  /*  276 */  0,
  /*  277 */  regD_rule,
  /*  278 */  iRegPdst_rule,
  /*  279 */  iRegPdst_rule,
  /*  280 */  iRegIsrc_rule,
  /*  281 */  iRegLsrc_rule,
  /*  282 */  iRegIsrc_rule,
  /*  283 */  iRegLsrc_rule,
  /*  284 */  0,
  /*  285 */  iRegIsrc_rule,
  /*  286 */  iRegLsrc_rule,
  /*  287 */  0,
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  indirectMemory_rule,
  /*  293 */  indirectMemory_rule,
  /*  294 */  indirectMemory_rule,
  /*  295 */  indirectMemory_rule,
  /*  296 */  indOffset16_rule,
  /*  297 */  indOffset16_rule,
  /*  298 */  indOffset16_rule,
  /*  299 */  indOffset16_rule,
  /*  300 */  memory_rule,
  /*  301 */  memory_rule,
  /*  302 */  _LoadUB_memory__rule,
  /*  303 */  _LoadUB_memory__rule,
  /*  304 */  memory_rule,
  /*  305 */  memory_rule,
  /*  306 */  memory_rule,
  /*  307 */  memory_rule,
  /*  308 */  _LoadUS_memory__rule,
  /*  309 */  _LoadUS_memory__rule,
  /*  310 */  memory_rule,
  /*  311 */  memory_rule,
  /*  312 */  _ConvI2L__LoadI_memory___rule,
  /*  313 */  _LoadI_memoryAlg4__rule,
  /*  314 */  _LoadI_memoryAlg4__rule,
  /*  315 */  memoryAlg4_rule,
  /*  316 */  memoryAlg4_rule,
  /*  317 */  memoryAlg4_rule,
  /*  318 */  memoryAlg4_rule,
  /*  319 */  memory_rule,
  /*  320 */  memory_rule,
  /*  321 */  memory_rule,
  /*  322 */  _LoadN_memory__rule,
  /*  323 */  memoryAlg4_rule,
  /*  324 */  memoryAlg4_rule,
  /*  325 */  memory_rule,
  /*  326 */  memoryAlg4_rule,
  /*  327 */  memory_rule,
  /*  328 */  memory_rule,
  /*  329 */  memory_rule,
  /*  330 */  memory_rule,
  /*  331 */  memory_rule,
  /*  332 */  0,
  /*  333 */  0,
  /*  334 */  0,
  /*  335 */  0,
  /*  336 */  0,
  /*  337 */  0,
  /*  338 */  0,
  /*  339 */  0,
  /*  340 */  0,
  /*  341 */  0,
  /*  342 */  0,
  /*  343 */  0,
  /*  344 */  _AddP_indirectMemory_iRegLsrc_rule,
  /*  345 */  indirectMemory_rule,
  /*  346 */  _AddP_indirectMemory_iRegLsrc_rule,
  /*  347 */  indirectMemory_rule,
  /*  348 */  _AddP_indirectMemory_iRegLsrc_rule,
  /*  349 */  indirectMemory_rule,
  /*  350 */  _AddP_indirectMemory_iRegLsrc_rule,
  /*  351 */  indirectMemory_rule,
  /*  352 */  memory_rule,
  /*  353 */  memory_rule,
  /*  354 */  memory_rule,
  /*  355 */  memory_rule,
  /*  356 */  memoryAlg4_rule,
  /*  357 */  memoryAlg4_rule,
  /*  358 */  memory_rule,
  /*  359 */  memory_rule,
  /*  360 */  memoryAlg4_rule,
  /*  361 */  memory_rule,
  /*  362 */  memory_rule,
  /*  363 */  memory_rule,
  /*  364 */  memory_rule,
  /*  365 */  memory_rule,
  /*  366 */  iRegNsrc_rule,
  /*  367 */  iRegPdst_rule,
  /*  368 */  _Binary_flagsReg_iRegPsrc_rule,
  /*  369 */  _Binary_flagsReg_iRegPsrc_rule,
  /*  370 */  iRegPsrc_rule,
  /*  371 */  iRegPsrc_rule,
  /*  372 */  iRegPsrc_rule,
  /*  373 */  iRegPsrc_rule,
  /*  374 */  iRegPsrc_rule,
  /*  375 */  iRegPsrc_rule,
  /*  376 */  iRegPdst_rule,
  /*  377 */  _Binary_flagsReg_iRegPsrc_rule,
  /*  378 */  _Binary_flagsReg_iRegPsrc_rule,
  /*  379 */  iRegNsrc_rule,
  /*  380 */  iRegNsrc_rule,
  /*  381 */  iRegNsrc_rule,
  /*  382 */  iRegNsrc_rule,
  /*  383 */  _CastP2X__DecodeN_iRegNsrc___rule,
  /*  384 */  iRegNsrc_rule,
  /*  385 */  _Binary_iRegLsrc_iRegPdst_rule,
  /*  386 */  iRegPsrc_rule,
  /*  387 */  _Binary_iRegLsrc_iRegPsrc_rule,
  /*  388 */  iRegPsrc_rule,
  /*  389 */  iRegPsrc_rule,
  /*  390 */  _Binary_iRegLsrc_iRegPdst_rule,
  /*  391 */  _Binary_iRegLsrc_iRegNsrc_rule,
  /*  392 */  iRegNsrc_rule,
  /*  393 */  0,
  /*  394 */  0,
  /*  395 */  0,
  /*  396 */  0,
  /*  397 */  0,
  /*  398 */  0,
  /*  399 */  0,
  /*  400 */  0,
  /*  401 */  0,
  /*  402 */  _Binary_cmpOp_flagsReg_rule,
  /*  403 */  _Binary_cmpOp_flagsReg_rule,
  /*  404 */  _Binary_cmpOp_flagsReg_rule,
  /*  405 */  _Binary_cmpOp_flagsReg_rule,
  /*  406 */  _Binary_cmpOp_flagsReg_rule,
  /*  407 */  _Binary_cmpOp_flagsReg_rule,
  /*  408 */  _Binary_cmpOp_flagsReg_rule,
  /*  409 */  _Binary_cmpOp_flagsReg_rule,
  /*  410 */  _Binary_cmpOp_flagsReg_rule,
  /*  411 */  _Binary_cmpOp_flagsReg_rule,
  /*  412 */  _Binary_cmpOp_flagsReg_rule,
  /*  413 */  _Binary_cmpOp_flagsReg_rule,
  /*  414 */  _Binary_cmpOp_flagsReg_rule,
  /*  415 */  _Binary_cmpOp_flagsReg_rule,
  /*  416 */  memory_rule,
  /*  417 */  iRegPdst_rule,
  /*  418 */  iRegPdst_rule,
  /*  419 */  iRegPdst_rule,
  /*  420 */  iRegPdst_rule,
  /*  421 */  iRegPdst_rule,
  /*  422 */  iRegPdst_rule,
  /*  423 */  iRegPdst_rule,
  /*  424 */  iRegPdst_rule,
  /*  425 */  iRegPdst_rule,
  /*  426 */  iRegPdst_rule,
  /*  427 */  iRegIsrc_iRegL2Isrc_rule,
  /*  428 */  0,
  /*  429 */  _AddI__AddI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  430 */  iRegIsrc_rule,
  /*  431 */  _AddI_iRegIsrc__AddI_iRegIsrc_iRegIsrc_rule,
  /*  432 */  iRegIsrc_rule,
  /*  433 */  iRegIsrc_rule,
  /*  434 */  iRegIsrc_rule,
  /*  435 */  iRegLsrc_rule,
  /*  436 */  0,
  /*  437 */  _AddL__AddL_iRegLsrc_iRegLsrc_iRegLsrc_rule,
  /*  438 */  iRegLsrc_rule,
  /*  439 */  _AddL_iRegLsrc__AddL_iRegLsrc_iRegLsrc_rule,
  /*  440 */  iRegLsrc_rule,
  /*  441 */  _AddL_iRegLsrc_iRegLsrc_rule,
  /*  442 */  iRegLsrc_rule,
  /*  443 */  iRegLsrc_rule,
  /*  444 */  iRegP_N2P_rule,
  /*  445 */  iRegP_N2P_rule,
  /*  446 */  iRegP_N2P_rule,
  /*  447 */  iRegIsrc_rule,
  /*  448 */  iRegIsrc_rule,
  /*  449 */  immI16_rule,
  /*  450 */  immI_0_rule,
  /*  451 */  iRegLsrc_rule,
  /*  452 */  _SubL_iRegLsrc_iRegLsrc_rule,
  /*  453 */  iRegLsrc_rule,
  /*  454 */  immL_0_rule,
  /*  455 */  _SubL_immL_0_iRegLsrc_rule,
  /*  456 */  iRegIsrc_rule,
  /*  457 */  iRegIsrc_rule,
  /*  458 */  iRegLsrc_rule,
  /*  459 */  iRegLsrc_rule,
  /*  460 */  iRegLsrc_rule,
  /*  461 */  iRegIsrc_rule,
  /*  462 */  iRegIsrc_rule,
  /*  463 */  0,
  /*  464 */  iRegIsrc_rule,
  /*  465 */  iRegLsrc_rule,
  /*  466 */  iRegLsrc_rule,
  /*  467 */  0,
  /*  468 */  iRegLsrc_rule,
  /*  469 */  iRegIsrc_rule,
  /*  470 */  iRegLsrc_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  iRegIsrc_rule,
  /*  474 */  iRegIsrc_rule,
  /*  475 */  _AndI_iRegIsrc_immInegpow2_rule,
  /*  476 */  _AndI__RShiftI_iRegIsrc_uimmI5_immInegpow2_rule,
  /*  477 */  0,
  /*  478 */  iRegLsrc_rule,
  /*  479 */  iRegLsrc_rule,
  /*  480 */  _ConvI2L_iRegIsrc__rule,
  /*  481 */  _ConvI2L_iRegIsrc__rule,
  /*  482 */  0,
  /*  483 */  iRegIsrc_rule,
  /*  484 */  iRegIsrc_rule,
  /*  485 */  0,
  /*  486 */  iRegLsrc_rule,
  /*  487 */  iRegLsrc_rule,
  /*  488 */  _RShiftL_iRegLsrc_immI_rule,
  /*  489 */  0,
  /*  490 */  iRegIsrc_rule,
  /*  491 */  iRegIsrc_rule,
  /*  492 */  0,
  /*  493 */  iRegLsrc_rule,
  /*  494 */  iRegLsrc_rule,
  /*  495 */  _URShiftL_iRegLsrc_immI_rule,
  /*  496 */  _CastP2X_iRegP_N2P__rule,
  /*  497 */  _URShiftI_iRegIsrc_immI_rule,
  /*  498 */  _URShiftL_iRegLsrc_immI_rule,
  /*  499 */  _ConvI2L_iRegIsrc__rule,
  /*  500 */  _LShiftI_iRegIsrc_immI8_rule,
  /*  501 */  _URShiftI_iRegIsrc_immI8_rule,
  /*  502 */  _URShiftI_iRegIsrc_immI8_rule,
  /*  503 */  _LShiftI_iRegIsrc_immI8_rule,
  /*  504 */  regF_rule,
  /*  505 */  regD_rule,
  /*  506 */  regF_rule,
  /*  507 */  regD_rule,
  /*  508 */  regF_rule,
  /*  509 */  regD_rule,
  /*  510 */  regF_rule,
  /*  511 */  regD_rule,
  /*  512 */  regD_rule,
  /*  513 */  _SqrtD__ConvF2D_regF___rule,
  /*  514 */  iRegIsrc_rule,
  /*  515 */  iRegIsrc_rule,
  /*  516 */  iRegIsrc_rule,
  /*  517 */  iRegIsrc_rule,
  /*  518 */  iRegIsrc_rule,
  /*  519 */  iRegIsrc_rule,
  /*  520 */  iRegLsrc_rule,
  /*  521 */  iRegLsrc_rule,
  /*  522 */  iRegLsrc_rule,
  /*  523 */  iRegLsrc_rule,
  /*  524 */  _AndL_iRegLsrc_immLpow2minus1_rule,
  /*  525 */  iRegIsrc_rule,
  /*  526 */  0,
  /*  527 */  _OrI__OrI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  528 */  iRegIsrc_rule,
  /*  529 */  _OrI_iRegIsrc__OrI_iRegIsrc_iRegIsrc_rule,
  /*  530 */  iRegIsrc_rule,
  /*  531 */  iRegIsrc_rule,
  /*  532 */  iRegLsrc_rule,
  /*  533 */  _OrL_iRegLsrc_iRegLsrc_rule,
  /*  534 */  iRegLsrc_rule,
  /*  535 */  iRegIsrc_rule,
  /*  536 */  0,
  /*  537 */  _XorI__XorI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  538 */  iRegIsrc_rule,
  /*  539 */  _XorI_iRegIsrc__XorI_iRegIsrc_iRegIsrc_rule,
  /*  540 */  iRegIsrc_rule,
  /*  541 */  iRegIsrc_rule,
  /*  542 */  iRegLsrc_rule,
  /*  543 */  _XorL_iRegLsrc_iRegLsrc_rule,
  /*  544 */  iRegLsrc_rule,
  /*  545 */  iRegIsrc_rule,
  /*  546 */  iRegLsrc_rule,
  /*  547 */  _XorI_iRegIsrc_immI_minus1_rule,
  /*  548 */  iRegIsrc_rule,
  /*  549 */  0,
  /*  550 */  regF_rule,
  /*  551 */  iRegIsrc_rule,
  /*  552 */  0,
  /*  553 */  regD_rule,
  /*  554 */  iRegLsrc_rule,
  /*  555 */  iRegIsrc_rule,
  /*  556 */  _Conv2B_iRegIsrc__rule,
  /*  557 */  _Conv2B_iRegIsrc__rule,
  /*  558 */  _AndI_iRegIsrc_immIpowerOf2_rule,
  /*  559 */  iRegP_N2P_rule,
  /*  560 */  _Conv2B_iRegP_N2P__rule,
  /*  561 */  _Conv2B_iRegP_N2P__rule,
  /*  562 */  iRegIsrc_rule,
  /*  563 */  iRegIsrc_rule,
  /*  564 */  _LShiftI_iRegIsrc_immI_24_rule,
  /*  565 */  _LShiftI_iRegIsrc_immI_16_rule,
  /*  566 */  _ConvL2I_iRegLsrc__rule,
  /*  567 */  iRegLsrc_rule,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  regD_rule,
  /*  571 */  regF_rule,
  /*  572 */  iRegIsrc_rule,
  /*  573 */  _ConvI2L_iRegIsrc__rule,
  /*  574 */  iRegLsrc_rule,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  regF_rule,
  /*  578 */  regD_rule,
  /*  579 */  regD_rule,
  /*  580 */  iRegIsrc_rule,
  /*  581 */  iRegIsrc_rule,
  /*  582 */  iRegLsrc_rule,
  /*  583 */  iRegIsrc_rule,
  /*  584 */  stackSlotL_rule,
  /*  585 */  regF_rule,
  /*  586 */  iRegLsrc_rule,
  /*  587 */  cmpOp_rule,
  /*  588 */  cmpOp_rule,
  /*  589 */  cmpOp_rule,
  /*  590 */  cmpOp_rule,
  /*  591 */  cmpOp_rule,
  /*  592 */  regF_rule,
  /*  593 */  regD_rule,
  /*  594 */  0,
  /*  595 */  cmpOp_rule,
  /*  596 */  cmpOp_rule,
  /*  597 */  cmpOp_rule,
  /*  598 */  cmpOp_rule,
  /*  599 */  cmpOp_rule,
  /*  600 */  cmpOp_rule,
  /*  601 */  iRegP_N2P_rule,
  /*  602 */  _AndL__CastP2X_iRegPsrc__immLnegpow2_rule,
  /*  603 */  _CastP2X_iRegPsrc__rule,
  /*  604 */  rarg1RegL_rule,
  /*  605 */  _Binary_iRegPsrc_iRegIsrc_rule,
  /*  606 */  _Binary_iRegPsrc_iRegIsrc_rule,
  /*  607 */  _Binary_iRegPsrc_rscratch1RegI_rule,
  /*  608 */  _Binary_iRegPsrc_rscratch1RegI_rule,
  /*  609 */  _Binary_iRegPsrc_iRegPsrc_rule,
  /*  610 */  _Binary_iRegPsrc_iRegPsrc_rule,
  /*  611 */  _Binary_rarg1RegP_rarg3RegI_rule,
  /*  612 */  iRegIsrc_rule,
  /*  613 */  iRegIsrc_rule,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  iRegIsrc_rule,
  /*  617 */  iRegIsrc_rule,
  /*  618 */  immI_0_rule,
  /*  619 */  immI_minus1_rule,
  /*  620 */  iRegIsrc_rule,
  /*  621 */  immI_0_rule,
  /*  622 */  immI_minus1_rule,
  /*  623 */  iRegIsrc_rule,
  /*  624 */  immI_0_rule,
  /*  625 */  immI_minus1_rule,
  /*  626 */  regF_rule,
  /*  627 */  immF_rule,
  /*  628 */  immF_0_rule,
  /*  629 */  iRegPdst_rule,
  /*  630 */  rscratch2RegP_rule,
  /*  631 */  0,
  /*  632 */  0,
  /*  633 */  0,
  /*  634 */  0,
  /*  635 */  0,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  iRegPdstNoScratch_rule,
  /*  641 */  0,
  /*  642 */  iRegPdstNoScratch_rule,
  /*  643 */  0,
  /*  644 */  0,
  /*  645 */  0,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  0,
  /*  652 */  0,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  immL16_rule,
  /*   91 */  immL16Alg4_rule,
  /*   92 */  0,
  /*   93 */  immL16_rule,
  /*   94 */  immL16Alg4_rule,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  // last operand
  /*  101 */  0,
  /*  102 */  0,
  /*  103 */  0,
  /*  104 */  0,
  /*  105 */  0,
  /*  106 */  0,
  // last operand class
  /*  107 */  0,
  /*  108 */  0,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  iRegLsrc_rule,
  /*  117 */  0,
  /*  118 */  iRegPsrc_rule,
  /*  119 */  0,
  /*  120 */  iRegPdst_rule,
  /*  121 */  iRegPsrc_rule,
  /*  122 */  iRegNsrc_rule,
  /*  123 */  flagsReg_rule,
  /*  124 */  iRegIsrc_rule,
  /*  125 */  immI16_rule,
  /*  126 */  iRegLsrc_rule,
  /*  127 */  immL16_rule,
  /*  128 */  iRegNsrc_rule,
  /*  129 */  immN_0_rule,
  /*  130 */  iRegPsrc_rule,
  /*  131 */  iRegP_N2P_rule,
  /*  132 */  immP_0_rule,
  /*  133 */  regF_rule,
  /*  134 */  regD_rule,
  /*  135 */  iRegLsrc_rule,
  /*  136 */  iRegPsrc_rule,
  /*  137 */  iRegIsrc_rule,
  /*  138 */  iRegNsrc_rule,
  /*  139 */  iRegIsrc_rule,
  /*  140 */  iRegIsrc_rule,
  /*  141 */  _AddI_iRegIsrc_iRegIsrc_rule,
  /*  142 */  iRegLsrc_rule,
  /*  143 */  iRegLsrc_rule,
  /*  144 */  _AddL_iRegLsrc_iRegLsrc_rule,
  /*  145 */  iRegLsrc_rule,
  /*  146 */  iRegLsrc_rule,
  /*  147 */  immInegpow2_rule,
  /*  148 */  uimmI5_rule,
  /*  149 */  immInegpow2_rule,
  /*  150 */  0,
  /*  151 */  immI_rule,
  /*  152 */  immI_rule,
  /*  153 */  0,
  /*  154 */  immI_rule,
  /*  155 */  immI8_rule,
  /*  156 */  immI8_rule,
  /*  157 */  0,
  /*  158 */  0,
  /*  159 */  0,
  /*  160 */  0,
  /*  161 */  immLpow2minus1_rule,
  /*  162 */  iRegIsrc_rule,
  /*  163 */  iRegIsrc_rule,
  /*  164 */  _OrI_iRegIsrc_iRegIsrc_rule,
  /*  165 */  iRegLsrc_rule,
  /*  166 */  iRegIsrc_rule,
  /*  167 */  iRegIsrc_rule,
  /*  168 */  _XorI_iRegIsrc_iRegIsrc_rule,
  /*  169 */  iRegLsrc_rule,
  /*  170 */  immI_minus1_rule,
  /*  171 */  0,
  /*  172 */  immIpowerOf2_rule,
  /*  173 */  0,
  /*  174 */  immI_24_rule,
  /*  175 */  immI_16_rule,
  /*  176 */  uimmI16_rule,
  /*  177 */  iRegLsrc_rule,
  /*  178 */  uimmL16_rule,
  /*  179 */  uimmI15_rule,
  /*  180 */  iRegIsrc_rule,
  /*  181 */  immN_0_rule,
  /*  182 */  immP_0_rule,
  /*  183 */  0,
  /*  184 */  immLnegpow2_rule,
  /*  185 */  iRegIsrc_rule,
  /*  186 */  immL_rule,
  /*  187 */  immI_1_rule,
  /*  188 */  immI_1_rule,
  /*  189 */  rscratch1RegI_rule,
  /*  190 */  uimmI15_rule,
  /*  191 */  rscratch2RegI_rule,
  /*  192 */  rarg3RegI_rule,
  /*  193 */  rarg4RegI_rule,
  // last internally defined operand
  /*  194 */  0,
  /*  195 */  0,
  /*  196 */  0,
  /*  197 */  0,
  /*  198 */  0,
  /*  199 */  0,
  /*  200 */  0,
  /*  201 */  0,
  /*  202 */  0,
  /*  203 */  0,
  /*  204 */  0,
  /*  205 */  0,
  /*  206 */  0,
  /*  207 */  0,
  /*  208 */  0,
  /*  209 */  0,
  /*  210 */  0,
  /*  211 */  0,
  /*  212 */  0,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  0,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  _Binary_iRegLsrc_iRegLsrc_rule,
  /*  224 */  _Binary_iRegPsrc_iRegPsrc_rule,
  /*  225 */  0,
  /*  226 */  0,
  /*  227 */  0,
  /*  228 */  0,
  /*  229 */  0,
  /*  230 */  0,
  /*  231 */  0,
  /*  232 */  0,
  /*  233 */  0,
  /*  234 */  0,
  /*  235 */  0,
  /*  236 */  0,
  /*  237 */  0,
  /*  238 */  0,
  /*  239 */  0,
  /*  240 */  0,
  /*  241 */  0,
  /*  242 */  0,
  /*  243 */  0,
  /*  244 */  0,
  /*  245 */  0,
  /*  246 */  0,
  /*  247 */  0,
  /*  248 */  0,
  /*  249 */  0,
  /*  250 */  0,
  /*  251 */  0,
  /*  252 */  0,
  /*  253 */  0,
  /*  254 */  0,
  /*  255 */  iRegIsrc_rule,
  /*  256 */  immI16_rule,
  /*  257 */  immI_0_rule,
  /*  258 */  iRegLsrc_rule,
  /*  259 */  immL16_rule,
  /*  260 */  iRegLsrc_rule,
  /*  261 */  uimmL16_rule,
  /*  262 */  immL_0_rule,
  /*  263 */  immL_0_rule,
  /*  264 */  0,
  /*  265 */  0,
  /*  266 */  iRegIsrc_rule,
  /*  267 */  uimmI16_rule,
  /*  268 */  iRegNsrc_rule,
  /*  269 */  immN_0_rule,
  /*  270 */  iRegP_N2P_rule,
  /*  271 */  immP_0or1_rule,
  /*  272 */  immL16_rule,
  /*  273 */  0,
  /*  274 */  0,
  /*  275 */  regF_rule,
  /*  276 */  0,
  /*  277 */  regD_rule,
  /*  278 */  iRegPdst_rule,
  /*  279 */  iRegPdst_rule,
  /*  280 */  0,
  /*  281 */  0,
  /*  282 */  0,
  /*  283 */  0,
  /*  284 */  0,
  /*  285 */  0,
  /*  286 */  0,
  /*  287 */  0,
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  0,
  /*  293 */  0,
  /*  294 */  0,
  /*  295 */  0,
  /*  296 */  0,
  /*  297 */  0,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  0,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  0,
  /*  304 */  0,
  /*  305 */  0,
  /*  306 */  0,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  immL_32bits_rule,
  /*  313 */  0,
  /*  314 */  0,
  /*  315 */  0,
  /*  316 */  0,
  /*  317 */  0,
  /*  318 */  0,
  /*  319 */  0,
  /*  320 */  0,
  /*  321 */  0,
  /*  322 */  0,
  /*  323 */  0,
  /*  324 */  0,
  /*  325 */  0,
  /*  326 */  0,
  /*  327 */  0,
  /*  328 */  0,
  /*  329 */  0,
  /*  330 */  0,
  /*  331 */  0,
  /*  332 */  0,
  /*  333 */  0,
  /*  334 */  0,
  /*  335 */  0,
  /*  336 */  0,
  /*  337 */  0,
  /*  338 */  0,
  /*  339 */  0,
  /*  340 */  0,
  /*  341 */  0,
  /*  342 */  0,
  /*  343 */  0,
  /*  344 */  0,
  /*  345 */  0,
  /*  346 */  0,
  /*  347 */  0,
  /*  348 */  0,
  /*  349 */  0,
  /*  350 */  0,
  /*  351 */  0,
  /*  352 */  iRegIsrc_rule,
  /*  353 */  iRegIsrc_rule,
  /*  354 */  iRegIsrc_rule,
  /*  355 */  _ConvL2I_iRegLsrc__rule,
  /*  356 */  iRegLsrc_rule,
  /*  357 */  iRegLsrc_rule,
  /*  358 */  iRegN_P2N_rule,
  /*  359 */  iRegN_P2N_rule,
  /*  360 */  iRegPsrc_rule,
  /*  361 */  regF_rule,
  /*  362 */  regD_rule,
  /*  363 */  iRegLdst_rule,
  /*  364 */  immI_0_rule,
  /*  365 */  immI_0_rule,
  /*  366 */  0,
  /*  367 */  0,
  /*  368 */  0,
  /*  369 */  0,
  /*  370 */  0,
  /*  371 */  0,
  /*  372 */  0,
  /*  373 */  0,
  /*  374 */  0,
  /*  375 */  0,
  /*  376 */  0,
  /*  377 */  0,
  /*  378 */  0,
  /*  379 */  0,
  /*  380 */  0,
  /*  381 */  0,
  /*  382 */  0,
  /*  383 */  0,
  /*  384 */  0,
  /*  385 */  0,
  /*  386 */  0,
  /*  387 */  0,
  /*  388 */  0,
  /*  389 */  0,
  /*  390 */  0,
  /*  391 */  0,
  /*  392 */  0,
  /*  393 */  0,
  /*  394 */  0,
  /*  395 */  0,
  /*  396 */  0,
  /*  397 */  0,
  /*  398 */  0,
  /*  399 */  0,
  /*  400 */  0,
  /*  401 */  0,
  /*  402 */  _Binary_iRegIdst_iRegIsrc_rule,
  /*  403 */  _Binary_iRegIdst_iRegIsrc_rule,
  /*  404 */  _Binary_iRegIdst_immI16_rule,
  /*  405 */  _Binary_iRegLdst_iRegLsrc_rule,
  /*  406 */  _Binary_iRegLdst_iRegLsrc_rule,
  /*  407 */  _Binary_iRegLdst_immL16_rule,
  /*  408 */  _Binary_iRegNdst_iRegNsrc_rule,
  /*  409 */  _Binary_iRegNdst_iRegNsrc_rule,
  /*  410 */  _Binary_iRegNdst_immN_0_rule,
  /*  411 */  _Binary_iRegPdst_iRegPsrc_rule,
  /*  412 */  _Binary_iRegPdst_iRegP_N2P_rule,
  /*  413 */  _Binary_iRegPdst_immP_0_rule,
  /*  414 */  _Binary_regF_regF_rule,
  /*  415 */  _Binary_regD_regD_rule,
  /*  416 */  0,
  /*  417 */  _Binary_iRegIsrc_iRegIsrc_rule,
  /*  418 */  _Binary_iRegNsrc_iRegNsrc_rule,
  /*  419 */  _Binary_iRegLsrc_iRegLsrc_rule,
  /*  420 */  _Binary_iRegPsrc_iRegPsrc_rule,
  /*  421 */  iRegIsrc_rule,
  /*  422 */  iRegLsrc_rule,
  /*  423 */  iRegIsrc_rule,
  /*  424 */  iRegLsrc_rule,
  /*  425 */  iRegPsrc_rule,
  /*  426 */  iRegNsrc_rule,
  /*  427 */  iRegIsrc_iRegL2Isrc_rule,
  /*  428 */  0,
  /*  429 */  iRegIsrc_rule,
  /*  430 */  _AddI__AddI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  431 */  iRegIsrc_rule,
  /*  432 */  _AddI_iRegIsrc__AddI_iRegIsrc_iRegIsrc_rule,
  /*  433 */  immI16_rule,
  /*  434 */  immIhi16_rule,
  /*  435 */  iRegLsrc_rule,
  /*  436 */  0,
  /*  437 */  iRegLsrc_rule,
  /*  438 */  _AddL__AddL_iRegLsrc_iRegLsrc_iRegLsrc_rule,
  /*  439 */  iRegLsrc_rule,
  /*  440 */  _AddL_iRegLsrc__AddL_iRegLsrc_iRegLsrc_rule,
  /*  441 */  0,
  /*  442 */  immL16_rule,
  /*  443 */  immL32hi16_rule,
  /*  444 */  iRegLsrc_rule,
  /*  445 */  immL16_rule,
  /*  446 */  immL32hi16_rule,
  /*  447 */  iRegIsrc_rule,
  /*  448 */  immI16_rule,
  /*  449 */  iRegIsrc_rule,
  /*  450 */  iRegIsrc_rule,
  /*  451 */  iRegLsrc_rule,
  /*  452 */  0,
  /*  453 */  immL16_rule,
  /*  454 */  iRegLsrc_rule,
  /*  455 */  0,
  /*  456 */  iRegIsrc_rule,
  /*  457 */  immI16_rule,
  /*  458 */  iRegLsrc_rule,
  /*  459 */  iRegLsrc_rule,
  /*  460 */  immL16_rule,
  /*  461 */  immI_minus1_rule,
  /*  462 */  iRegIsrc_rule,
  /*  463 */  0,
  /*  464 */  iRegIsrc_rule,
  /*  465 */  immL_minus1_rule,
  /*  466 */  iRegLsrc_rule,
  /*  467 */  0,
  /*  468 */  iRegLsrc_rule,
  /*  469 */  iRegIsrc_rule,
  /*  470 */  iRegLsrc_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  iRegIsrc_rule,
  /*  474 */  immI_rule,
  /*  475 */  uimmI5_rule,
  /*  476 */  uimmI5_rule,
  /*  477 */  0,
  /*  478 */  iRegIsrc_rule,
  /*  479 */  immI_rule,
  /*  480 */  uimmI6_ge32_rule,
  /*  481 */  uimmI6_rule,
  /*  482 */  0,
  /*  483 */  iRegIsrc_rule,
  /*  484 */  immI_rule,
  /*  485 */  0,
  /*  486 */  iRegIsrc_rule,
  /*  487 */  immI_rule,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  iRegIsrc_rule,
  /*  491 */  immI_rule,
  /*  492 */  0,
  /*  493 */  iRegIsrc_rule,
  /*  494 */  immI_rule,
  /*  495 */  0,
  /*  496 */  uimmI6_rule,
  /*  497 */  immIpow2minus1_rule,
  /*  498 */  immLpow2minus1_rule,
  /*  499 */  0,
  /*  500 */  _URShiftI_iRegIsrc_immI8_rule,
  /*  501 */  _LShiftI_iRegIsrc_immI8_rule,
  /*  502 */  _LShiftI_iRegIsrc_immI8_rule,
  /*  503 */  _URShiftI_iRegIsrc_immI8_rule,
  /*  504 */  regF_rule,
  /*  505 */  regD_rule,
  /*  506 */  regF_rule,
  /*  507 */  regD_rule,
  /*  508 */  regF_rule,
  /*  509 */  regD_rule,
  /*  510 */  regF_rule,
  /*  511 */  regD_rule,
  /*  512 */  0,
  /*  513 */  0,
  /*  514 */  iRegIsrc_rule,
  /*  515 */  immIhi16_rule,
  /*  516 */  uimmI16_rule,
  /*  517 */  immInegpow2_rule,
  /*  518 */  immIpow2minus1_rule,
  /*  519 */  immIpowerOf2_rule,
  /*  520 */  iRegLsrc_rule,
  /*  521 */  uimmL16_rule,
  /*  522 */  immLnegpow2_rule,
  /*  523 */  immLpow2minus1_rule,
  /*  524 */  0,
  /*  525 */  iRegIsrc_rule,
  /*  526 */  0,
  /*  527 */  iRegIsrc_rule,
  /*  528 */  _OrI__OrI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  529 */  iRegIsrc_rule,
  /*  530 */  _OrI_iRegIsrc__OrI_iRegIsrc_iRegIsrc_rule,
  /*  531 */  uimmI16_rule,
  /*  532 */  iRegLsrc_rule,
  /*  533 */  0,
  /*  534 */  uimmL16_rule,
  /*  535 */  iRegIsrc_rule,
  /*  536 */  0,
  /*  537 */  iRegIsrc_rule,
  /*  538 */  _XorI__XorI_iRegIsrc_iRegIsrc_iRegIsrc_rule,
  /*  539 */  iRegIsrc_rule,
  /*  540 */  _XorI_iRegIsrc__XorI_iRegIsrc_iRegIsrc_rule,
  /*  541 */  uimmI16_rule,
  /*  542 */  iRegLsrc_rule,
  /*  543 */  0,
  /*  544 */  uimmL16_rule,
  /*  545 */  immI_minus1_rule,
  /*  546 */  immL_minus1_rule,
  /*  547 */  iRegIsrc_rule,
  /*  548 */  _XorI_iRegIsrc_immI_minus1_rule,
  /*  549 */  0,
  /*  550 */  0,
  /*  551 */  0,
  /*  552 */  0,
  /*  553 */  0,
  /*  554 */  0,
  /*  555 */  0,
  /*  556 */  immI_1_rule,
  /*  557 */  immI_1_rule,
  /*  558 */  0,
  /*  559 */  0,
  /*  560 */  immI_1_rule,
  /*  561 */  immI_1_rule,
  /*  562 */  iRegIsrc_rule,
  /*  563 */  immI_0_rule,
  /*  564 */  immI_24_rule,
  /*  565 */  immI_16_rule,
  /*  566 */  0,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  immL_32bits_rule,
  /*  574 */  immL_32bits_rule,
  /*  575 */  0,
  /*  576 */  0,
  /*  577 */  0,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  iRegLsrc_rule,
  /*  587 */  _CmpU_iRegIsrc_uimmI15_rule,
  /*  588 */  _CmpU_iRegIsrc_iRegIsrc_rule,
  /*  589 */  _CmpU_iRegIsrc_uimmI15_rule,
  /*  590 */  _CmpN_iRegNsrc_immN_0_rule,
  /*  591 */  _CmpP_iRegP_N2P_immP_0_rule,
  /*  592 */  regF_rule,
  /*  593 */  regD_rule,
  /*  594 */  0,
  /*  595 */  flagsReg_rule,
  /*  596 */  flagsReg_rule,
  /*  597 */  flagsReg_rule,
  /*  598 */  flagsReg_rule,
  /*  599 */  flagsReg_rule,
  /*  600 */  flagsReg_rule,
  /*  601 */  iRegP_N2P_rule,
  /*  602 */  0,
  /*  603 */  _CastP2X_iRegPsrc__rule,
  /*  604 */  rarg2RegP_rule,
  /*  605 */  _Binary__AddP_immP_immL_immI_1_rule,
  /*  606 */  _Binary_rscratch2RegP_immI_1_rule,
  /*  607 */  _Binary_iRegPsrc_uimmI15_rule,
  /*  608 */  _Binary_iRegPsrc_rscratch2RegI_rule,
  /*  609 */  uimmI15_rule,
  /*  610 */  iRegIsrc_rule,
  /*  611 */  _Binary_rarg2RegP_rarg4RegI_rule,
  /*  612 */  iRegIsrc_rule,
  /*  613 */  iRegIsrc_rule,
  /*  614 */  0,
  /*  615 */  0,
  /*  616 */  0,
  /*  617 */  0,
  /*  618 */  0,
  /*  619 */  0,
  /*  620 */  0,
  /*  621 */  0,
  /*  622 */  0,
  /*  623 */  0,
  /*  624 */  0,
  /*  625 */  0,
  /*  626 */  0,
  /*  627 */  0,
  /*  628 */  0,
  /*  629 */  0,
  /*  630 */  0,
  /*  631 */  0,
  /*  632 */  0,
  /*  633 */  0,
  /*  634 */  0,
  /*  635 */  0,
  /*  636 */  0,
  /*  637 */  0,
  /*  638 */  0,
  /*  639 */  0,
  /*  640 */  inline_cache_regP_rule,
  /*  641 */  0,
  /*  642 */  rarg1RegP_rule,
  /*  643 */  0,
  /*  644 */  0,
  /*  645 */  0,
  /*  646 */  0,
  /*  647 */  0,
  /*  648 */  0,
  /*  649 */  0,
  /*  650 */  0,
  /*  651 */  0,
  /*  652 */  0,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMI",
  /*    9 */  "IMMI8",
  /*   10 */  "IMMI16",
  /*   11 */  "IMMIHI16",
  /*   12 */  "IMMINEGPOW2",
  /*   13 */  "IMMIPOW2MINUS1",
  /*   14 */  "IMMIPOWEROF2",
  /*   15 */  "UIMMI5",
  /*   16 */  "UIMMI6",
  /*   17 */  "UIMMI6_GE32",
  /*   18 */  "UIMMI15",
  /*   19 */  "UIMMI16",
  /*   20 */  "IMMI_0",
  /*   21 */  "IMMI_1",
  /*   22 */  "IMMI_MINUS1",
  /*   23 */  "IMMI_16",
  /*   24 */  "IMMI_24",
  /*   25 */  "IMMN",
  /*   26 */  "IMMN_0",
  /*   27 */  "IMMNKLASS",
  /*   28 */  "IMMNKLASS_NM",
  /*   29 */  "IMMP",
  /*   30 */  "IMMP_NM",
  /*   31 */  "IMMP_0",
  /*   32 */  "IMMP_0OR1",
  /*   33 */  "IMML",
  /*   34 */  "IMML16",
  /*   35 */  "IMML16ALG4",
  /*   36 */  "IMML32HI16",
  /*   37 */  "IMML32",
  /*   38 */  "IMMLHIGHEST16",
  /*   39 */  "IMMLNEGPOW2",
  /*   40 */  "IMMLPOW2MINUS1",
  /*   41 */  "IMML_0",
  /*   42 */  "IMML_MINUS1",
  /*   43 */  "IMML_32BITS",
  /*   44 */  "UIMML16",
  /*   45 */  "IMMF",
  /*   46 */  "IMMF_0",
  /*   47 */  "IMMD",
  /*   48 */  "IREGIDST",
  /*   49 */  "IREGISRC",
  /*   50 */  "RSCRATCH1REGI",
  /*   51 */  "RSCRATCH2REGI",
  /*   52 */  "RARG1REGI",
  /*   53 */  "RARG2REGI",
  /*   54 */  "RARG3REGI",
  /*   55 */  "RARG4REGI",
  /*   56 */  "RARG1REGL",
  /*   57 */  "RARG2REGL",
  /*   58 */  "RARG3REGL",
  /*   59 */  "RARG4REGL",
  /*   60 */  "IREGPDST",
  /*   61 */  "IREGPDSTNOSCRATCH",
  /*   62 */  "IREGPSRC",
  /*   63 */  "THREADREGP",
  /*   64 */  "RSCRATCH1REGP",
  /*   65 */  "RSCRATCH2REGP",
  /*   66 */  "RARG1REGP",
  /*   67 */  "RARG2REGP",
  /*   68 */  "RARG3REGP",
  /*   69 */  "RARG4REGP",
  /*   70 */  "IREGNSRC",
  /*   71 */  "IREGNDST",
  /*   72 */  "IREGLDST",
  /*   73 */  "IREGLSRC",
  /*   74 */  "IREGL2ISRC",
  /*   75 */  "RSCRATCH1REGL",
  /*   76 */  "RSCRATCH2REGL",
  /*   77 */  "FLAGSREG",
  /*   78 */  "FLAGSREGCR0",
  /*   79 */  "FLAGSREGCR1",
  /*   80 */  "FLAGSREGCR6",
  /*   81 */  "REGCTR",
  /*   82 */  "REGD",
  /*   83 */  "REGF",
  /*   84 */  "INLINE_CACHE_REGP",
  /*   85 */  "COMPILER_METHOD_OOP_REGP",
  /*   86 */  "INTERPRETER_METHOD_OOP_REGP",
  /*   87 */  "IREGP2N",
  /*   88 */  "IREGN2P",
  /*   89 */  "INDIRECT",
  /*   90 */  "INDOFFSET16",
  /*   91 */  "INDOFFSET16ALG4",
  /*   92 */  "INDIRECTNARROW",
  /*   93 */  "INDOFFSET16NARROW",
  /*   94 */  "INDOFFSET16NARROWALG4",
  /*   95 */  "STACKSLOTI",
  /*   96 */  "STACKSLOTL",
  /*   97 */  "STACKSLOTP",
  /*   98 */  "STACKSLOTF",
  /*   99 */  "STACKSLOTD",
  /*  100 */  "CMPOP",
  // last operand
  /*  101 */  "MEMORY",
  /*  102 */  "MEMORYALG4",
  /*  103 */  "INDIRECTMEMORY",
  /*  104 */  "IREGISRC_IREGL2ISRC",
  /*  105 */  "IREGN_P2N",
  /*  106 */  "IREGP_N2P",
  // last operand class
  /*  107 */  "_DecodeN_iRegNsrc_",
  /*  108 */  "_DecodeNKlass_iRegNsrc_",
  /*  109 */  "_LoadUB_memory_",
  /*  110 */  "_LoadUS_memory_",
  /*  111 */  "_LoadI_memory_",
  /*  112 */  "_ConvI2L__LoadI_memory__",
  /*  113 */  "_LoadI_memoryAlg4_",
  /*  114 */  "_LoadN_memory_",
  /*  115 */  "_LoadP_memoryAlg4_",
  /*  116 */  "_AddP_indirectMemory_iRegLsrc",
  /*  117 */  "_ConvL2I_iRegLsrc_",
  /*  118 */  "_Binary_flagsReg_iRegPsrc",
  /*  119 */  "_CastP2X__DecodeN_iRegNsrc__",
  /*  120 */  "_Binary_iRegLsrc_iRegPdst",
  /*  121 */  "_Binary_iRegLsrc_iRegPsrc",
  /*  122 */  "_Binary_iRegLsrc_iRegNsrc",
  /*  123 */  "_Binary_cmpOp_flagsReg",
  /*  124 */  "_Binary_iRegIdst_iRegIsrc",
  /*  125 */  "_Binary_iRegIdst_immI16",
  /*  126 */  "_Binary_iRegLdst_iRegLsrc",
  /*  127 */  "_Binary_iRegLdst_immL16",
  /*  128 */  "_Binary_iRegNdst_iRegNsrc",
  /*  129 */  "_Binary_iRegNdst_immN_0",
  /*  130 */  "_Binary_iRegPdst_iRegPsrc",
  /*  131 */  "_Binary_iRegPdst_iRegP_N2P",
  /*  132 */  "_Binary_iRegPdst_immP_0",
  /*  133 */  "_Binary_regF_regF",
  /*  134 */  "_Binary_regD_regD",
  /*  135 */  "_Binary_iRegLsrc_iRegLsrc",
  /*  136 */  "_Binary_iRegPsrc_iRegPsrc",
  /*  137 */  "_Binary_iRegIsrc_iRegIsrc",
  /*  138 */  "_Binary_iRegNsrc_iRegNsrc",
  /*  139 */  "_AddI_iRegIsrc_iRegIsrc",
  /*  140 */  "_AddI__AddI_iRegIsrc_iRegIsrc_iRegIsrc",
  /*  141 */  "_AddI_iRegIsrc__AddI_iRegIsrc_iRegIsrc",
  /*  142 */  "_AddL_iRegLsrc_iRegLsrc",
  /*  143 */  "_AddL__AddL_iRegLsrc_iRegLsrc_iRegLsrc",
  /*  144 */  "_AddL_iRegLsrc__AddL_iRegLsrc_iRegLsrc",
  /*  145 */  "_SubL_iRegLsrc_iRegLsrc",
  /*  146 */  "_SubL_immL_0_iRegLsrc",
  /*  147 */  "_AndI_iRegIsrc_immInegpow2",
  /*  148 */  "_RShiftI_iRegIsrc_uimmI5",
  /*  149 */  "_AndI__RShiftI_iRegIsrc_uimmI5_immInegpow2",
  /*  150 */  "_ConvI2L_iRegIsrc_",
  /*  151 */  "_RShiftL_iRegLsrc_immI",
  /*  152 */  "_URShiftL_iRegLsrc_immI",
  /*  153 */  "_CastP2X_iRegP_N2P_",
  /*  154 */  "_URShiftI_iRegIsrc_immI",
  /*  155 */  "_LShiftI_iRegIsrc_immI8",
  /*  156 */  "_URShiftI_iRegIsrc_immI8",
  /*  157 */  "_AbsF_regF_",
  /*  158 */  "_AbsD_regD_",
  /*  159 */  "_ConvF2D_regF_",
  /*  160 */  "_SqrtD__ConvF2D_regF__",
  /*  161 */  "_AndL_iRegLsrc_immLpow2minus1",
  /*  162 */  "_OrI_iRegIsrc_iRegIsrc",
  /*  163 */  "_OrI__OrI_iRegIsrc_iRegIsrc_iRegIsrc",
  /*  164 */  "_OrI_iRegIsrc__OrI_iRegIsrc_iRegIsrc",
  /*  165 */  "_OrL_iRegLsrc_iRegLsrc",
  /*  166 */  "_XorI_iRegIsrc_iRegIsrc",
  /*  167 */  "_XorI__XorI_iRegIsrc_iRegIsrc_iRegIsrc",
  /*  168 */  "_XorI_iRegIsrc__XorI_iRegIsrc_iRegIsrc",
  /*  169 */  "_XorL_iRegLsrc_iRegLsrc",
  /*  170 */  "_XorI_iRegIsrc_immI_minus1",
  /*  171 */  "_Conv2B_iRegIsrc_",
  /*  172 */  "_AndI_iRegIsrc_immIpowerOf2",
  /*  173 */  "_Conv2B_iRegP_N2P_",
  /*  174 */  "_LShiftI_iRegIsrc_immI_24",
  /*  175 */  "_LShiftI_iRegIsrc_immI_16",
  /*  176 */  "_AndI_iRegIsrc_uimmI16",
  /*  177 */  "_AndL_iRegLsrc_iRegLsrc",
  /*  178 */  "_AndL_iRegLsrc_uimmL16",
  /*  179 */  "_CmpU_iRegIsrc_uimmI15",
  /*  180 */  "_CmpU_iRegIsrc_iRegIsrc",
  /*  181 */  "_CmpN_iRegNsrc_immN_0",
  /*  182 */  "_CmpP_iRegP_N2P_immP_0",
  /*  183 */  "_CastP2X_iRegPsrc_",
  /*  184 */  "_AndL__CastP2X_iRegPsrc__immLnegpow2",
  /*  185 */  "_Binary_iRegPsrc_iRegIsrc",
  /*  186 */  "_AddP_immP_immL",
  /*  187 */  "_Binary__AddP_immP_immL_immI_1",
  /*  188 */  "_Binary_rscratch2RegP_immI_1",
  /*  189 */  "_Binary_iRegPsrc_rscratch1RegI",
  /*  190 */  "_Binary_iRegPsrc_uimmI15",
  /*  191 */  "_Binary_iRegPsrc_rscratch2RegI",
  /*  192 */  "_Binary_rarg1RegP_rarg3RegI",
  /*  193 */  "_Binary_rarg2RegP_rarg4RegI",
  // last internally defined operand
  /*  194 */  "regI_to_stkI",
  /*  195 */  "regL_to_stkL",
  /*  196 */  "loadConI16",
  /*  197 */  "loadConIhi16",
  /*  198 */  "loadConI_Ex",
  /*  199 */  "loadConL16",
  /*  200 */  "loadConL32hi16",
  /*  201 */  "loadConL32_Ex",
  /*  202 */  "loadConLhighest16_Ex",
  /*  203 */  "loadConL_Ex",
  /*  204 */  "loadConN0",
  /*  205 */  "loadConN_Ex",
  /*  206 */  "loadConNKlass_hi",
  /*  207 */  "loadConNKlass_mask",
  /*  208 */  "loadConNKlass_lo",
  /*  209 */  "loadConNKlass_Ex",
  /*  210 */  "loadConP0or1",
  /*  211 */  "loadConP",
  /*  212 */  "loadConP_lo",
  /*  213 */  "loadConP_Ex",
  /*  214 */  "loadConF_Ex",
  /*  215 */  "loadConD_Ex",
  /*  216 */  "stkI_to_regI",
  /*  217 */  "stkL_to_regL",
  /*  218 */  "convB2I_reg_2",
  /*  219 */  "loadP2X",
  /*  220 */  "loadToc_lo",
  /*  221 */  "loadConN_hi",
  /*  222 */  "clearMs32b",
  /*  223 */  "storeLConditional_regP_regL_regL",
  /*  224 */  "storePConditional_regP_regP_regP",
  /*  225 */  "signmask32I_regI",
  /*  226 */  "absI_reg_Ex",
  /*  227 */  "signmask64I_regL",
  /*  228 */  "signmask64L_regL",
  /*  229 */  "absF_reg",
  /*  230 */  "absD_reg",
  /*  231 */  "negF_reg",
  /*  232 */  "negD_reg",
  /*  233 */  "negF_absF_reg",
  /*  234 */  "negD_absD_reg",
  /*  235 */  "roundDouble_nop",
  /*  236 */  "roundFloat_nop",
  /*  237 */  "moveF2I_stack_reg",
  /*  238 */  "moveI2F_stack_reg",
  /*  239 */  "moveD2L_stack_reg",
  /*  240 */  "moveL2D_stack_reg",
  /*  241 */  "moveReg",
  /*  242 */  "castX2P",
  /*  243 */  "castP2X",
  /*  244 */  "castPP",
  /*  245 */  "castII",
  /*  246 */  "checkCastPP",
  /*  247 */  "convI2Bool_reg__cntlz_Ex",
  /*  248 */  "convP2Bool_reg__cntlz_Ex",
  /*  249 */  "convD2IRaw_regD",
  /*  250 */  "convF2IRaw_regF",
  /*  251 */  "convF2LRaw_regF",
  /*  252 */  "convD2LRaw_regD",
  /*  253 */  "convL2DRaw_regD",
  /*  254 */  "convL2FRaw_regF",
  /*  255 */  "cmpI_reg_reg",
  /*  256 */  "cmpI_reg_imm16",
  /*  257 */  "testI_reg_imm",
  /*  258 */  "cmpL_reg_reg",
  /*  259 */  "cmpL_reg_imm16",
  /*  260 */  "cmpUL_reg_reg",
  /*  261 */  "cmpUL_reg_imm16",
  /*  262 */  "testL_reg_reg",
  /*  263 */  "testL_reg_imm",
  /*  264 */  "cmovI_conIvalueMinus1_conIvalue1",
  /*  265 */  "cmovI_conIvalueMinus1_conIvalue0_conIvalue1_Ex",
  /*  266 */  "compU_reg_reg",
  /*  267 */  "compU_reg_uimm16",
  /*  268 */  "cmpN_reg_reg",
  /*  269 */  "cmpN_reg_imm0",
  /*  270 */  "cmpP_reg_reg",
  /*  271 */  "cmpP_reg_null",
  /*  272 */  "cmpP_reg_imm16",
  /*  273 */  "cmpFUnordered_reg_reg",
  /*  274 */  "cmov_bns_less",
  /*  275 */  "cmpF_reg_reg_Ex",
  /*  276 */  "cmpDUnordered_reg_reg",
  /*  277 */  "cmpD_reg_reg_Ex",
  /*  278 */  "cmpFastLock",
  /*  279 */  "cmpFastUnlock",
  /*  280 */  "popCountI",
  /*  281 */  "popCountL",
  /*  282 */  "countLeadingZerosI",
  /*  283 */  "countLeadingZerosL",
  /*  284 */  "countLeadingZerosP",
  /*  285 */  "countTrailingZerosI_Ex",
  /*  286 */  "countTrailingZerosL_Ex",
  /*  287 */  "repl32",
  /*  288 */  "repl48",
  /*  289 */  "repl56",
  /*  290 */  "CallLeafDirect_mtctr",
  /*  291 */  "tlsLoadP",
  /*  292 */  "loadUB_indirect",
  /*  293 */  "loadUB_indirect_ac",
  /*  294 */  "loadB_indirect_Ex",
  /*  295 */  "loadB_indirect_ac_Ex",
  /*  296 */  "loadUB_indOffset16",
  /*  297 */  "loadUB_indOffset16_ac",
  /*  298 */  "loadB_indOffset16_Ex",
  /*  299 */  "loadB_indOffset16_ac_Ex",
  /*  300 */  "loadUB",
  /*  301 */  "loadUB_ac",
  /*  302 */  "loadUB2L",
  /*  303 */  "loadUB2L_ac",
  /*  304 */  "loadS",
  /*  305 */  "loadS_ac",
  /*  306 */  "loadUS",
  /*  307 */  "loadUS_ac",
  /*  308 */  "loadUS2L",
  /*  309 */  "loadUS2L_ac",
  /*  310 */  "loadI",
  /*  311 */  "loadI_ac",
  /*  312 */  "loadUI2L",
  /*  313 */  "loadI2L",
  /*  314 */  "loadI2L_ac",
  /*  315 */  "loadL",
  /*  316 */  "loadL_ac",
  /*  317 */  "loadL_unaligned",
  /*  318 */  "loadV8",
  /*  319 */  "loadRange",
  /*  320 */  "loadN",
  /*  321 */  "loadN_ac",
  /*  322 */  "loadN2P_unscaled",
  /*  323 */  "loadP",
  /*  324 */  "loadP_ac",
  /*  325 */  "loadNKlass",
  /*  326 */  "loadKlass",
  /*  327 */  "loadF",
  /*  328 */  "loadF_ac",
  /*  329 */  "loadD",
  /*  330 */  "loadD_ac",
  /*  331 */  "loadD_unaligned",
  /*  332 */  "loadToc_hi",
  /*  333 */  "loadConI32_lo16",
  /*  334 */  "loadConL32_lo16",
  /*  335 */  "loadConL",
  /*  336 */  "loadConL_hi",
  /*  337 */  "loadConL_lo",
  /*  338 */  "loadConN_lo",
  /*  339 */  "loadConP_hi",
  /*  340 */  "loadConF",
  /*  341 */  "loadConFComp",
  /*  342 */  "loadConD",
  /*  343 */  "loadConDComp",
  /*  344 */  "prefetchr",
  /*  345 */  "prefetchr_no_offset",
  /*  346 */  "prefetchw",
  /*  347 */  "prefetchw_no_offset",
  /*  348 */  "prefetch_alloc_zero",
  /*  349 */  "prefetch_alloc_zero_no_offset",
  /*  350 */  "prefetch_alloc",
  /*  351 */  "prefetch_alloc_no_offset",
  /*  352 */  "storeB",
  /*  353 */  "storeC",
  /*  354 */  "storeI",
  /*  355 */  "storeI_convL2I",
  /*  356 */  "storeL",
  /*  357 */  "storeA8B",
  /*  358 */  "storeN",
  /*  359 */  "storeNKlass",
  /*  360 */  "storeP",
  /*  361 */  "storeF",
  /*  362 */  "storeD",
  /*  363 */  "storeCM_CMS",
  /*  364 */  "storeCM_CMS_ExEx",
  /*  365 */  "storeCM_G1",
  /*  366 */  "encodeP_shift",
  /*  367 */  "encodeP_sub",
  /*  368 */  "cond_sub_base",
  /*  369 */  "cond_set_0_oop",
  /*  370 */  "encodeP_32GAligned",
  /*  371 */  "encodeP_Ex",
  /*  372 */  "encodeP_not_null_Ex",
  /*  373 */  "encodeP_not_null_base_null",
  /*  374 */  "encodeP_narrow_oop_shift_0",
  /*  375 */  "decodeN_shift",
  /*  376 */  "decodeN_add",
  /*  377 */  "cond_add_base",
  /*  378 */  "cond_set_0_ptr",
  /*  379 */  "decodeN_Ex",
  /*  380 */  "decodeN_nullBase",
  /*  381 */  "decodeN_notNull_addBase_Ex",
  /*  382 */  "decodeN_unscaled",
  /*  383 */  "decodeN2I_unscaled",
  /*  384 */  "encodePKlass_shift",
  /*  385 */  "encodePKlass_sub_base",
  /*  386 */  "encodePKlass_32GAligned",
  /*  387 */  "encodePKlass_not_null_Ex",
  /*  388 */  "encodePKlass_not_null_ExEx",
  /*  389 */  "decodeNKlass_shift",
  /*  390 */  "decodeNKlass_add_base",
  /*  391 */  "decodeNKlass_notNull_addBase_Ex",
  /*  392 */  "decodeNKlass_notNull_addBase_ExEx",
  /*  393 */  "membar_acquire",
  /*  394 */  "unnecessary_membar_acquire",
  /*  395 */  "membar_acquire_lock",
  /*  396 */  "membar_release",
  /*  397 */  "membar_release_0",
  /*  398 */  "membar_storestore",
  /*  399 */  "membar_release_lock",
  /*  400 */  "membar_volatile",
  /*  401 */  "membar_CPUOrder",
  /*  402 */  "cmovI_reg_isel",
  /*  403 */  "cmovI_reg",
  /*  404 */  "cmovI_imm",
  /*  405 */  "cmovL_reg_isel",
  /*  406 */  "cmovL_reg",
  /*  407 */  "cmovL_imm",
  /*  408 */  "cmovN_reg_isel",
  /*  409 */  "cmovN_reg",
  /*  410 */  "cmovN_imm",
  /*  411 */  "cmovP_reg_isel",
  /*  412 */  "cmovP_reg",
  /*  413 */  "cmovP_imm",
  /*  414 */  "cmovF_reg",
  /*  415 */  "cmovD_reg",
  /*  416 */  "loadPLocked",
  /*  417 */  "compareAndSwapI_regP_regI_regI",
  /*  418 */  "compareAndSwapN_regP_regN_regN",
  /*  419 */  "compareAndSwapL_regP_regL_regL",
  /*  420 */  "compareAndSwapP_regP_regP_regP",
  /*  421 */  "getAndAddI",
  /*  422 */  "getAndAddL",
  /*  423 */  "getAndSetI",
  /*  424 */  "getAndSetL",
  /*  425 */  "getAndSetP",
  /*  426 */  "getAndSetN",
  /*  427 */  "addI_reg_reg",
  /*  428 */  "addI_reg_reg_2",
  /*  429 */  "tree_addI_addI_addI_reg_reg_Ex",
  /*  430 */  "tree_addI_addI_addI_reg_reg_Ex_1",
  /*  431 */  "tree_addI_addI_addI_reg_reg_Ex_0",
  /*  432 */  "tree_addI_addI_addI_reg_reg_Ex_2",
  /*  433 */  "addI_reg_imm16",
  /*  434 */  "addI_reg_immhi16",
  /*  435 */  "addL_reg_reg",
  /*  436 */  "addL_reg_reg_2",
  /*  437 */  "tree_addL_addL_addL_reg_reg_Ex",
  /*  438 */  "tree_addL_addL_addL_reg_reg_Ex_1",
  /*  439 */  "tree_addL_addL_addL_reg_reg_Ex_0",
  /*  440 */  "tree_addL_addL_addL_reg_reg_Ex_2",
  /*  441 */  "addI_regL_regL",
  /*  442 */  "addL_reg_imm16",
  /*  443 */  "addL_reg_immhi16",
  /*  444 */  "addP_reg_reg",
  /*  445 */  "addP_reg_imm16",
  /*  446 */  "addP_reg_immhi16",
  /*  447 */  "subI_reg_reg",
  /*  448 */  "subI_reg_imm16",
  /*  449 */  "subI_imm16_reg",
  /*  450 */  "negI_regI",
  /*  451 */  "subL_reg_reg",
  /*  452 */  "subI_regL_regL",
  /*  453 */  "subL_reg_imm16",
  /*  454 */  "negL_reg_reg",
  /*  455 */  "negI_con0_regL",
  /*  456 */  "mulI_reg_reg",
  /*  457 */  "mulI_reg_imm16",
  /*  458 */  "mulL_reg_reg",
  /*  459 */  "mulHighL_reg_reg",
  /*  460 */  "mulL_reg_imm16",
  /*  461 */  "divI_reg_immIvalueMinus1",
  /*  462 */  "divI_reg_regnotMinus1",
  /*  463 */  "cmovI_bne_negI_reg",
  /*  464 */  "divI_reg_reg_Ex",
  /*  465 */  "divL_reg_immLvalueMinus1",
  /*  466 */  "divL_reg_regnotMinus1",
  /*  467 */  "cmovL_bne_negL_reg",
  /*  468 */  "divL_reg_reg_Ex",
  /*  469 */  "modI_reg_reg_Ex",
  /*  470 */  "modL_reg_reg_Ex",
  /*  471 */  "maskI_reg_imm",
  /*  472 */  "lShiftI_reg_reg",
  /*  473 */  "lShiftI_reg_reg_Ex",
  /*  474 */  "lShiftI_reg_imm",
  /*  475 */  "lShiftI_andI_immInegpow2_imm5",
  /*  476 */  "lShiftI_andI_immInegpow2_rShiftI_imm5",
  /*  477 */  "lShiftL_regL_regI",
  /*  478 */  "lShiftL_regL_regI_Ex",
  /*  479 */  "lshiftL_regL_immI",
  /*  480 */  "lShiftL_regI_immGE32",
  /*  481 */  "scaledPositiveI2L_lShiftL_convI2L_reg_imm6",
  /*  482 */  "arShiftI_reg_reg",
  /*  483 */  "arShiftI_reg_reg_Ex",
  /*  484 */  "arShiftI_reg_imm",
  /*  485 */  "arShiftL_regL_regI",
  /*  486 */  "arShiftL_regL_regI_Ex",
  /*  487 */  "arShiftL_regL_immI",
  /*  488 */  "convL2I_arShiftL_regL_immI",
  /*  489 */  "urShiftI_reg_reg",
  /*  490 */  "urShiftI_reg_reg_Ex",
  /*  491 */  "urShiftI_reg_imm",
  /*  492 */  "urShiftL_regL_regI",
  /*  493 */  "urShiftL_regL_regI_Ex",
  /*  494 */  "urShiftL_regL_immI",
  /*  495 */  "convL2I_urShiftL_regL_immI",
  /*  496 */  "shrP_convP2X_reg_imm6",
  /*  497 */  "andI_urShiftI_regI_immI_immIpow2minus1",
  /*  498 */  "andL_urShiftL_regL_immI_immLpow2minus1",
  /*  499 */  "sxtI_reg",
  /*  500 */  "rotlI_reg_immi8",
  /*  501 */  "rotlI_reg_immi8_0",
  /*  502 */  "rotrI_reg_immi8",
  /*  503 */  "rotrI_reg_immi8_0",
  /*  504 */  "addF_reg_reg",
  /*  505 */  "addD_reg_reg",
  /*  506 */  "subF_reg_reg",
  /*  507 */  "subD_reg_reg",
  /*  508 */  "mulF_reg_reg",
  /*  509 */  "mulD_reg_reg",
  /*  510 */  "divF_reg_reg",
  /*  511 */  "divD_reg_reg",
  /*  512 */  "sqrtD_reg",
  /*  513 */  "sqrtF_reg",
  /*  514 */  "andI_reg_reg",
  /*  515 */  "andI_reg_immIhi16",
  /*  516 */  "andI_reg_uimm16",
  /*  517 */  "andI_reg_immInegpow2",
  /*  518 */  "andI_reg_immIpow2minus1",
  /*  519 */  "andI_reg_immIpowerOf2",
  /*  520 */  "andL_reg_reg",
  /*  521 */  "andL_reg_uimm16",
  /*  522 */  "andL_reg_immLnegpow2",
  /*  523 */  "andL_reg_immLpow2minus1",
  /*  524 */  "convL2I_andL_reg_immLpow2minus1",
  /*  525 */  "orI_reg_reg",
  /*  526 */  "orI_reg_reg_2",
  /*  527 */  "tree_orI_orI_orI_reg_reg_Ex",
  /*  528 */  "tree_orI_orI_orI_reg_reg_Ex_1",
  /*  529 */  "tree_orI_orI_orI_reg_reg_Ex_0",
  /*  530 */  "tree_orI_orI_orI_reg_reg_Ex_2",
  /*  531 */  "orI_reg_uimm16",
  /*  532 */  "orL_reg_reg",
  /*  533 */  "orI_regL_regL",
  /*  534 */  "orL_reg_uimm16",
  /*  535 */  "xorI_reg_reg",
  /*  536 */  "xorI_reg_reg_2",
  /*  537 */  "tree_xorI_xorI_xorI_reg_reg_Ex",
  /*  538 */  "tree_xorI_xorI_xorI_reg_reg_Ex_1",
  /*  539 */  "tree_xorI_xorI_xorI_reg_reg_Ex_0",
  /*  540 */  "tree_xorI_xorI_xorI_reg_reg_Ex_2",
  /*  541 */  "xorI_reg_uimm16",
  /*  542 */  "xorL_reg_reg",
  /*  543 */  "xorI_regL_regL",
  /*  544 */  "xorL_reg_uimm16",
  /*  545 */  "notI_reg",
  /*  546 */  "notL_reg",
  /*  547 */  "andcI_reg_reg",
  /*  548 */  "andcI_reg_reg_0",
  /*  549 */  "andcL_reg_reg",
  /*  550 */  "moveF2I_reg_stack",
  /*  551 */  "moveI2F_reg_stack",
  /*  552 */  "moveF2L_reg_stack",
  /*  553 */  "moveD2L_reg_stack",
  /*  554 */  "moveL2D_reg_stack",
  /*  555 */  "convI2Bool_reg__cmove",
  /*  556 */  "xorI_convI2Bool_reg_immIvalue1__cntlz_Ex",
  /*  557 */  "xorI_convI2Bool_reg_immIvalue1__cmove",
  /*  558 */  "convI2Bool_andI_reg_immIpowerOf2",
  /*  559 */  "convP2Bool_reg__cmove",
  /*  560 */  "xorI_convP2Bool_reg__cntlz_Ex",
  /*  561 */  "xorI_convP2Bool_reg_immIvalue1__cmove",
  /*  562 */  "cmpLTMask_reg_reg_Ex",
  /*  563 */  "cmpLTMask_reg_immI0",
  /*  564 */  "convB2I_reg",
  /*  565 */  "convS2I_reg",
  /*  566 */  "sxtI_L2L_reg",
  /*  567 */  "convL2I_reg",
  /*  568 */  "cmovI_bso_stackSlotL",
  /*  569 */  "cmovI_bso_stackSlotL_conLvalue0_Ex",
  /*  570 */  "convD2I_reg_ExEx",
  /*  571 */  "convF2I_regF_ExEx",
  /*  572 */  "convI2L_reg",
  /*  573 */  "zeroExtendL_regI",
  /*  574 */  "zeroExtendL_regL",
  /*  575 */  "cmovL_bso_stackSlotL",
  /*  576 */  "cmovL_bso_stackSlotL_conLvalue0_Ex",
  /*  577 */  "convF2L_reg_ExEx",
  /*  578 */  "convD2L_reg_ExEx",
  /*  579 */  "convD2F_reg",
  /*  580 */  "convI2F_ireg_Ex",
  /*  581 */  "convI2F_ireg_fcfids_Ex",
  /*  582 */  "convL2F_ireg_fcfids_Ex",
  /*  583 */  "convI2D_reg_Ex",
  /*  584 */  "convL2D_reg_Ex",
  /*  585 */  "convF2D_reg",
  /*  586 */  "cmpL3_reg_reg_ExEx",
  /*  587 */  "rangeCheck_iReg_uimm15",
  /*  588 */  "rangeCheck_iReg_iReg",
  /*  589 */  "rangeCheck_uimm15_iReg",
  /*  590 */  "zeroCheckN_iReg_imm0",
  /*  591 */  "zeroCheckP_reg_imm0",
  /*  592 */  "cmpF3_reg_reg_ExEx",
  /*  593 */  "cmpD3_reg_reg_ExEx",
  /*  594 */  "branch",
  /*  595 */  "branchCon",
  /*  596 */  "branchConFar",
  /*  597 */  "branchConSched",
  /*  598 */  "branchLoopEnd",
  /*  599 */  "branchLoopEndFar",
  /*  600 */  "branchLoopEndSched",
  /*  601 */  "partialSubtypeCheck",
  /*  602 */  "align_addr",
  /*  603 */  "array_size",
  /*  604 */  "inlineCallClearArray",
  /*  605 */  "string_indexOf_imm1_char",
  /*  606 */  "string_indexOf_imm1",
  /*  607 */  "string_indexOf_imm",
  /*  608 */  "string_indexOf",
  /*  609 */  "string_equals_imm",
  /*  610 */  "string_equals",
  /*  611 */  "string_compare",
  /*  612 */  "minI_reg_reg_Ex",
  /*  613 */  "maxI_reg_reg_Ex",
  /*  614 */  "insrwi_a",
  /*  615 */  "insrwi",
  /*  616 */  "bytes_reverse_int_Ex",
  /*  617 */  "repl8B_reg_Ex",
  /*  618 */  "repl8B_immI0",
  /*  619 */  "repl8B_immIminus1",
  /*  620 */  "repl4S_reg_Ex",
  /*  621 */  "repl4S_immI0",
  /*  622 */  "repl4S_immIminus1",
  /*  623 */  "repl2I_reg_Ex",
  /*  624 */  "repl2I_immI0",
  /*  625 */  "repl2I_immIminus1",
  /*  626 */  "repl2F_reg_Ex",
  /*  627 */  "repl2F_immF_Ex",
  /*  628 */  "repl2F_immF0",
  /*  629 */  "safePoint_poll",
  /*  630 */  "safePoint_poll_conPollAddr",
  /*  631 */  "CallStaticJavaDirect",
  /*  632 */  "CallStaticJavaDirectHandle",
  /*  633 */  "CallDynamicJavaDirectSched",
  /*  634 */  "CallDynamicJavaDirectSched_Ex",
  /*  635 */  "CallDynamicJavaDirect",
  /*  636 */  "CallRuntimeDirect",
  /*  637 */  "CallLeafDirect",
  /*  638 */  "CallLeafDirect_Ex",
  /*  639 */  "CallLeafNoFPDirect_Ex",
  /*  640 */  "TailCalljmpInd",
  /*  641 */  "Ret",
  /*  642 */  "tailjmpInd",
  /*  643 */  "CreateException",
  /*  644 */  "RethrowException",
  /*  645 */  "ShouldNotReachHere",
  /*  646 */  "endGroup",
  /*  647 */  "fxNop",
  /*  648 */  "fpNop0",
  /*  649 */  "fpNop1",
  /*  650 */  "brNop0",
  /*  651 */  "brNop1",
  /*  652 */  "brNop2",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  false,
  /*   49 */  false,
  /*   50 */  false,
  /*   51 */  false,
  /*   52 */  false,
  /*   53 */  false,
  /*   54 */  false,
  /*   55 */  false,
  /*   56 */  false,
  /*   57 */  false,
  /*   58 */  false,
  /*   59 */  false,
  /*   60 */  false,
  /*   61 */  false,
  /*   62 */  false,
  /*   63 */  false,
  /*   64 */  false,
  /*   65 */  false,
  /*   66 */  false,
  /*   67 */  false,
  /*   68 */  false,
  /*   69 */  false,
  /*   70 */  false,
  /*   71 */  false,
  /*   72 */  false,
  /*   73 */  false,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  true,
  // last operand
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  // last operand class
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  false,
  /*  110 */  false,
  /*  111 */  false,
  /*  112 */  false,
  /*  113 */  false,
  /*  114 */  false,
  /*  115 */  false,
  /*  116 */  false,
  /*  117 */  false,
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  // last internally defined operand
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // RegFlags: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // _last_machine_leaf: 13
  0, // AbsD: 14
  0, // AbsF: 15
  0, // AbsI: 16
  0, // AddD: 17
  0, // AddF: 18
  0, // AddI: 19
  0, // AddL: 20
  0, // AddP: 21
  0, // Allocate: 22
  0, // AllocateArray: 23
  0, // AndI: 24
  0, // AndL: 25
  0, // AryEq: 26
  0, // AtanD: 27
  1, // Binary: 28
  1, // Bool: 29
  0, // BoxLock: 30
  0, // ReverseBytesI: 31
  0, // ReverseBytesL: 32
  0, // ReverseBytesUS: 33
  0, // ReverseBytesS: 34
  0, // CProj: 35
  0, // CallDynamicJava: 36
  0, // CallJava: 37
  0, // CallLeaf: 38
  0, // CallLeafNoFP: 39
  0, // CallRuntime: 40
  0, // CallStaticJava: 41
  0, // CastII: 42
  0, // CastX2P: 43
  0, // CastP2X: 44
  0, // CastPP: 45
  0, // Catch: 46
  0, // CatchProj: 47
  0, // CheckCastPP: 48
  0, // ClearArray: 49
  0, // ConstraintCast: 50
  0, // CMoveD: 51
  0, // CMoveF: 52
  0, // CMoveI: 53
  0, // CMoveL: 54
  0, // CMoveP: 55
  0, // CMoveN: 56
  1, // CmpN: 57
  1, // CmpD: 58
  0, // CmpD3: 59
  1, // CmpF: 60
  0, // CmpF3: 61
  1, // CmpI: 62
  1, // CmpL: 63
  0, // CmpL3: 64
  0, // CmpLTMask: 65
  1, // CmpP: 66
  1, // CmpU: 67
  1, // CmpUL: 68
  0, // CompareAndSwapI: 69
  0, // CompareAndSwapL: 70
  0, // CompareAndSwapP: 71
  0, // CompareAndSwapN: 72
  0, // GetAndAddI: 73
  0, // GetAndAddL: 74
  0, // GetAndSetI: 75
  0, // GetAndSetL: 76
  0, // GetAndSetP: 77
  0, // GetAndSetN: 78
  0, // Con: 79
  0, // ConN: 80
  0, // ConNKlass: 81
  0, // ConD: 82
  0, // ConF: 83
  0, // ConI: 84
  0, // ConL: 85
  0, // ConP: 86
  0, // Conv2B: 87
  0, // ConvD2F: 88
  0, // ConvD2I: 89
  0, // ConvD2L: 90
  0, // ConvF2D: 91
  0, // ConvF2I: 92
  0, // ConvF2L: 93
  0, // ConvI2D: 94
  0, // ConvI2F: 95
  0, // ConvI2L: 96
  0, // ConvL2D: 97
  0, // ConvL2F: 98
  0, // ConvL2I: 99
  0, // CosD: 100
  0, // CountedLoop: 101
  0, // CountedLoopEnd: 102
  0, // CountLeadingZerosI: 103
  0, // CountLeadingZerosL: 104
  0, // CountTrailingZerosI: 105
  0, // CountTrailingZerosL: 106
  0, // CreateEx: 107
  0, // DecodeN: 108
  0, // DecodeNKlass: 109
  0, // DivD: 110
  0, // DivF: 111
  0, // DivI: 112
  0, // DivL: 113
  0, // DivMod: 114
  0, // DivModI: 115
  0, // DivModL: 116
  0, // EncodeISOArray: 117
  0, // EncodeP: 118
  0, // EncodePKlass: 119
  0, // ExpD: 120
  1, // FastLock: 121
  1, // FastUnlock: 122
  0, // Goto: 123
  0, // Halt: 124
  0, // If: 125
  0, // IfFalse: 126
  0, // IfTrue: 127
  0, // Initialize: 128
  0, // JProj: 129
  0, // Jump: 130
  0, // JumpProj: 131
  0, // LShiftI: 132
  0, // LShiftL: 133
  0, // LoadB: 134
  0, // LoadUB: 135
  0, // LoadUS: 136
  0, // LoadD: 137
  0, // LoadD_unaligned: 138
  0, // LoadF: 139
  0, // LoadI: 140
  0, // LoadKlass: 141
  0, // LoadNKlass: 142
  0, // LoadL: 143
  0, // LoadL_unaligned: 144
  0, // LoadPLocked: 145
  0, // LoadP: 146
  0, // LoadN: 147
  0, // LoadRange: 148
  0, // LoadS: 149
  0, // Lock: 150
  0, // LogD: 151
  0, // Log10D: 152
  0, // Loop: 153
  0, // LoopLimit: 154
  0, // Mach: 155
  0, // MachProj: 156
  0, // MaxI: 157
  0, // MemBarAcquire: 158
  0, // LoadFence: 159
  0, // MemBarAcquireLock: 160
  0, // MemBarCPUOrder: 161
  0, // MemBarRelease: 162
  0, // StoreFence: 163
  0, // MemBarReleaseLock: 164
  0, // MemBarVolatile: 165
  0, // MemBarStoreStore: 166
  0, // MergeMem: 167
  0, // MinI: 168
  0, // ModD: 169
  0, // ModF: 170
  0, // ModI: 171
  0, // ModL: 172
  0, // MoveI2F: 173
  0, // MoveF2I: 174
  0, // MoveL2D: 175
  0, // MoveD2L: 176
  0, // MulD: 177
  0, // MulF: 178
  0, // MulHiL: 179
  0, // MulI: 180
  0, // MulL: 181
  0, // Multi: 182
  0, // NegD: 183
  0, // NegF: 184
  0, // NeverBranch: 185
  0, // Opaque1: 186
  0, // Opaque2: 187
  0, // Opaque3: 188
  0, // ProfileBoolean: 189
  0, // OrI: 190
  0, // OrL: 191
  1, // OverflowAddI: 192
  1, // OverflowSubI: 193
  1, // OverflowMulI: 194
  1, // OverflowAddL: 195
  1, // OverflowSubL: 196
  1, // OverflowMulL: 197
  0, // PCTable: 198
  0, // Parm: 199
  0, // PartialSubtypeCheck: 200
  0, // Phi: 201
  0, // PopCountI: 202
  0, // PopCountL: 203
  0, // PowD: 204
  0, // PrefetchAllocation: 205
  0, // PrefetchRead: 206
  0, // PrefetchWrite: 207
  0, // Proj: 208
  0, // RShiftI: 209
  0, // RShiftL: 210
  0, // Region: 211
  0, // Rethrow: 212
  0, // Return: 213
  0, // Root: 214
  0, // RoundDouble: 215
  0, // RoundFloat: 216
  0, // SafePoint: 217
  0, // SafePointScalarObject: 218
  0, // SCMemProj: 219
  0, // SinD: 220
  0, // SqrtD: 221
  0, // Start: 222
  0, // StartOSR: 223
  0, // StoreB: 224
  0, // StoreC: 225
  0, // StoreCM: 226
  0, // StorePConditional: 227
  0, // StoreIConditional: 228
  0, // StoreLConditional: 229
  0, // StoreD: 230
  0, // StoreF: 231
  0, // StoreI: 232
  0, // StoreL: 233
  0, // StoreP: 234
  0, // StoreN: 235
  0, // StoreNKlass: 236
  0, // StrComp: 237
  0, // StrEquals: 238
  0, // StrIndexOf: 239
  0, // SubD: 240
  0, // SubF: 241
  0, // SubI: 242
  0, // SubL: 243
  0, // TailCall: 244
  0, // TailJump: 245
  0, // TanD: 246
  0, // ThreadLocal: 247
  0, // Unlock: 248
  0, // URShiftI: 249
  0, // URShiftL: 250
  0, // XorI: 251
  0, // XorL: 252
  0, // Vector: 253
  0, // AddVB: 254
  0, // AddVS: 255
  0, // AddVI: 256
  0, // AddVL: 257
  0, // AddVF: 258
  0, // AddVD: 259
  0, // SubVB: 260
  0, // SubVS: 261
  0, // SubVI: 262
  0, // SubVL: 263
  0, // SubVF: 264
  0, // SubVD: 265
  0, // MulVS: 266
  0, // MulVI: 267
  0, // MulVF: 268
  0, // MulVD: 269
  0, // DivVF: 270
  0, // DivVD: 271
  0, // LShiftCntV: 272
  0, // RShiftCntV: 273
  0, // LShiftVB: 274
  0, // LShiftVS: 275
  0, // LShiftVI: 276
  0, // LShiftVL: 277
  0, // RShiftVB: 278
  0, // RShiftVS: 279
  0, // RShiftVI: 280
  0, // RShiftVL: 281
  0, // URShiftVB: 282
  0, // URShiftVS: 283
  0, // URShiftVI: 284
  0, // URShiftVL: 285
  0, // AndV: 286
  0, // OrV: 287
  0, // XorV: 288
  0, // LoadVector: 289
  0, // StoreVector: 290
  0, // Pack: 291
  0, // PackB: 292
  0, // PackS: 293
  0, // PackI: 294
  0, // PackL: 295
  0, // PackF: 296
  0, // PackD: 297
  0, // Pack2L: 298
  0, // Pack2D: 299
  0, // ReplicateB: 300
  0, // ReplicateS: 301
  0, // ReplicateI: 302
  0, // ReplicateL: 303
  0, // ReplicateF: 304
  0, // ReplicateD: 305
  0, // Extract: 306
  0, // ExtractB: 307
  0, // ExtractUB: 308
  0, // ExtractC: 309
  0, // ExtractS: 310
  0, // ExtractI: 311
  0, // ExtractL: 312
  0, // ExtractF: 313
  0 // no trailing comma // ExtractD: 314
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R14",
  "R14_H",
  "R15",
  "R15_H",
  "R17",
  "R17_H",
  "R18",
  "R18_H",
  "R19",
  "R19_H",
  "R20",
  "R20_H",
  "R21",
  "R21_H",
  "R22",
  "R22_H",
  "R23",
  "R23_H",
  "R24",
  "R24_H",
  "R25",
  "R25_H",
  "R26",
  "R26_H",
  "R27",
  "R27_H",
  "R28",
  "R28_H",
  "R29",
  "R29_H",
  "R30",
  "R30_H",
  "R31",
  "R31_H",
  "R11",
  "R11_H",
  "R12",
  "R12_H",
  "R10",
  "R10_H",
  "R9",
  "R9_H",
  "R8",
  "R8_H",
  "R7",
  "R7_H",
  "R6",
  "R6_H",
  "R5",
  "R5_H",
  "R4",
  "R4_H",
  "R3",
  "R3_H",
  "R16",
  "R16_H",
  "R13",
  "R13_H",
  "R2",
  "R2_H",
  "R1",
  "R1_H",
  "R0",
  "R0_H",
  "F0",
  "F0_H",
  "F13",
  "F13_H",
  "F12",
  "F12_H",
  "F11",
  "F11_H",
  "F10",
  "F10_H",
  "F9",
  "F9_H",
  "F8",
  "F8_H",
  "F7",
  "F7_H",
  "F6",
  "F6_H",
  "F5",
  "F5_H",
  "F4",
  "F4_H",
  "F3",
  "F3_H",
  "F2",
  "F2_H",
  "F1",
  "F1_H",
  "F14",
  "F14_H",
  "F15",
  "F15_H",
  "F16",
  "F16_H",
  "F17",
  "F17_H",
  "F18",
  "F18_H",
  "F19",
  "F19_H",
  "F20",
  "F20_H",
  "F21",
  "F21_H",
  "F22",
  "F22_H",
  "F23",
  "F23_H",
  "F24",
  "F24_H",
  "F25",
  "F25_H",
  "F26",
  "F26_H",
  "F27",
  "F27_H",
  "F28",
  "F28_H",
  "F29",
  "F29_H",
  "F30",
  "F30_H",
  "F31",
  "F31_H",
  "CCR0",
  "CCR1",
  "CCR2",
  "CCR3",
  "CCR4",
  "CCR5",
  "CCR6",
  "CCR7",
  "SR_XER",
  "SR_LR",
  "SR_CTR",
  "SR_VRSAVE",
  "SR_SPEFSCR",
  "SR_PPR" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	R14->as_VMReg()        ,
	R14->as_VMReg()->next(),
	R15->as_VMReg()        ,
	R15->as_VMReg()->next(),
	R17->as_VMReg()        ,
	R17->as_VMReg()->next(),
	R18->as_VMReg()        ,
	R18->as_VMReg()->next(),
	R19->as_VMReg()        ,
	R19->as_VMReg()->next(),
	R20->as_VMReg()        ,
	R20->as_VMReg()->next(),
	R21->as_VMReg()        ,
	R21->as_VMReg()->next(),
	R22->as_VMReg()        ,
	R22->as_VMReg()->next(),
	R23->as_VMReg()        ,
	R23->as_VMReg()->next(),
	R24->as_VMReg()        ,
	R24->as_VMReg()->next(),
	R25->as_VMReg()        ,
	R25->as_VMReg()->next(),
	R26->as_VMReg()        ,
	R26->as_VMReg()->next(),
	R27->as_VMReg()        ,
	R27->as_VMReg()->next(),
	R28->as_VMReg()        ,
	R28->as_VMReg()->next(),
	R29->as_VMReg()        ,
	R29->as_VMReg()->next(),
	R30->as_VMReg()        ,
	R30->as_VMReg()->next(),
	R31->as_VMReg()        ,
	R31->as_VMReg()->next(),
	R11->as_VMReg()        ,
	R11->as_VMReg()->next(),
	R12->as_VMReg()        ,
	R12->as_VMReg()->next(),
	R10->as_VMReg()        ,
	R10->as_VMReg()->next(),
	R9->as_VMReg()         ,
	R9->as_VMReg()->next() ,
	R8->as_VMReg()         ,
	R8->as_VMReg()->next() ,
	R7->as_VMReg()         ,
	R7->as_VMReg()->next() ,
	R6->as_VMReg()         ,
	R6->as_VMReg()->next() ,
	R5->as_VMReg()         ,
	R5->as_VMReg()->next() ,
	R4->as_VMReg()         ,
	R4->as_VMReg()->next() ,
	R3->as_VMReg()         ,
	R3->as_VMReg()->next() ,
	R16->as_VMReg()        ,
	R16->as_VMReg()->next(),
	R13->as_VMReg()        ,
	R13->as_VMReg()->next(),
	R2->as_VMReg()         ,
	R2->as_VMReg()->next() ,
	R1->as_VMReg()         ,
	R1->as_VMReg()->next() ,
	R0->as_VMReg()         ,
	R0->as_VMReg()->next() ,
	F0->as_VMReg()         ,
	F0->as_VMReg()->next() ,
	F13->as_VMReg()        ,
	F13->as_VMReg()->next(),
	F12->as_VMReg()        ,
	F12->as_VMReg()->next(),
	F11->as_VMReg()        ,
	F11->as_VMReg()->next(),
	F10->as_VMReg()        ,
	F10->as_VMReg()->next(),
	F9->as_VMReg()         ,
	F9->as_VMReg()->next() ,
	F8->as_VMReg()         ,
	F8->as_VMReg()->next() ,
	F7->as_VMReg()         ,
	F7->as_VMReg()->next() ,
	F6->as_VMReg()         ,
	F6->as_VMReg()->next() ,
	F5->as_VMReg()         ,
	F5->as_VMReg()->next() ,
	F4->as_VMReg()         ,
	F4->as_VMReg()->next() ,
	F3->as_VMReg()         ,
	F3->as_VMReg()->next() ,
	F2->as_VMReg()         ,
	F2->as_VMReg()->next() ,
	F1->as_VMReg()         ,
	F1->as_VMReg()->next() ,
	F14->as_VMReg()        ,
	F14->as_VMReg()->next(),
	F15->as_VMReg()        ,
	F15->as_VMReg()->next(),
	F16->as_VMReg()        ,
	F16->as_VMReg()->next(),
	F17->as_VMReg()        ,
	F17->as_VMReg()->next(),
	F18->as_VMReg()        ,
	F18->as_VMReg()->next(),
	F19->as_VMReg()        ,
	F19->as_VMReg()->next(),
	F20->as_VMReg()        ,
	F20->as_VMReg()->next(),
	F21->as_VMReg()        ,
	F21->as_VMReg()->next(),
	F22->as_VMReg()        ,
	F22->as_VMReg()->next(),
	F23->as_VMReg()        ,
	F23->as_VMReg()->next(),
	F24->as_VMReg()        ,
	F24->as_VMReg()->next(),
	F25->as_VMReg()        ,
	F25->as_VMReg()->next(),
	F26->as_VMReg()        ,
	F26->as_VMReg()->next(),
	F27->as_VMReg()        ,
	F27->as_VMReg()->next(),
	F28->as_VMReg()        ,
	F28->as_VMReg()->next(),
	F29->as_VMReg()        ,
	F29->as_VMReg()->next(),
	F30->as_VMReg()        ,
	F30->as_VMReg()->next(),
	F31->as_VMReg()        ,
	F31->as_VMReg()->next(),
	CCR0->as_VMReg(),
	CCR1->as_VMReg(),
	CCR2->as_VMReg(),
	CCR3->as_VMReg(),
	CCR4->as_VMReg(),
	CCR5->as_VMReg(),
	CCR6->as_VMReg(),
	CCR7->as_VMReg(),
	SR_XER->as_VMReg(),
	SR_LR->as_VMReg(),
	SR_CTR->as_VMReg(),
	SR_VRSAVE->as_VMReg(),
	SR_SPEFSCR->as_VMReg(),
	SR_PPR->as_VMReg() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\xE',  // R14
  (unsigned char)'\x63',  // R14_H
  (unsigned char)'\xF',  // R15
  (unsigned char)'\x63',  // R15_H
  (unsigned char)'\x11',  // R17
  (unsigned char)'\x63',  // R17_H
  (unsigned char)'\x12',  // R18
  (unsigned char)'\x63',  // R18_H
  (unsigned char)'\x13',  // R19
  (unsigned char)'\x63',  // R19_H
  (unsigned char)'\x14',  // R20
  (unsigned char)'\x63',  // R20_H
  (unsigned char)'\x15',  // R21
  (unsigned char)'\x63',  // R21_H
  (unsigned char)'\x16',  // R22
  (unsigned char)'\x63',  // R22_H
  (unsigned char)'\x17',  // R23
  (unsigned char)'\x63',  // R23_H
  (unsigned char)'\x18',  // R24
  (unsigned char)'\x63',  // R24_H
  (unsigned char)'\x19',  // R25
  (unsigned char)'\x63',  // R25_H
  (unsigned char)'\x1A',  // R26
  (unsigned char)'\x63',  // R26_H
  (unsigned char)'\x1B',  // R27
  (unsigned char)'\x63',  // R27_H
  (unsigned char)'\x1C',  // R28
  (unsigned char)'\x63',  // R28_H
  (unsigned char)'\x1D',  // R29
  (unsigned char)'\x63',  // R29_H
  (unsigned char)'\x1E',  // R30
  (unsigned char)'\x63',  // R30_H
  (unsigned char)'\x1F',  // R31
  (unsigned char)'\x63',  // R31_H
  (unsigned char)'\xB',  // R11
  (unsigned char)'\x63',  // R11_H
  (unsigned char)'\xC',  // R12
  (unsigned char)'\x63',  // R12_H
  (unsigned char)'\xA',  // R10
  (unsigned char)'\x63',  // R10_H
  (unsigned char)'\x9',  // R9
  (unsigned char)'\x63',  // R9_H
  (unsigned char)'\x8',  // R8
  (unsigned char)'\x63',  // R8_H
  (unsigned char)'\x7',  // R7
  (unsigned char)'\x63',  // R7_H
  (unsigned char)'\x6',  // R6
  (unsigned char)'\x63',  // R6_H
  (unsigned char)'\x5',  // R5
  (unsigned char)'\x63',  // R5_H
  (unsigned char)'\x4',  // R4
  (unsigned char)'\x63',  // R4_H
  (unsigned char)'\x3',  // R3
  (unsigned char)'\x63',  // R3_H
  (unsigned char)'\x10',  // R16
  (unsigned char)'\x63',  // R16_H
  (unsigned char)'\xD',  // R13
  (unsigned char)'\x63',  // R13_H
  (unsigned char)'\x2',  // R2
  (unsigned char)'\x63',  // R2_H
  (unsigned char)'\x1',  // R1
  (unsigned char)'\x63',  // R1_H
  (unsigned char)'\x0',  // R0
  (unsigned char)'\x63',  // R0_H
  (unsigned char)'\x0',  // F0
  (unsigned char)'\x63',  // F0_H
  (unsigned char)'\xD',  // F13
  (unsigned char)'\x63',  // F13_H
  (unsigned char)'\xC',  // F12
  (unsigned char)'\x63',  // F12_H
  (unsigned char)'\xB',  // F11
  (unsigned char)'\x63',  // F11_H
  (unsigned char)'\xA',  // F10
  (unsigned char)'\x63',  // F10_H
  (unsigned char)'\x9',  // F9
  (unsigned char)'\x63',  // F9_H
  (unsigned char)'\x8',  // F8
  (unsigned char)'\x63',  // F8_H
  (unsigned char)'\x7',  // F7
  (unsigned char)'\x63',  // F7_H
  (unsigned char)'\x6',  // F6
  (unsigned char)'\x63',  // F6_H
  (unsigned char)'\x5',  // F5
  (unsigned char)'\x63',  // F5_H
  (unsigned char)'\x4',  // F4
  (unsigned char)'\x63',  // F4_H
  (unsigned char)'\x3',  // F3
  (unsigned char)'\x63',  // F3_H
  (unsigned char)'\x2',  // F2
  (unsigned char)'\x63',  // F2_H
  (unsigned char)'\x1',  // F1
  (unsigned char)'\x63',  // F1_H
  (unsigned char)'\xE',  // F14
  (unsigned char)'\x63',  // F14_H
  (unsigned char)'\xF',  // F15
  (unsigned char)'\x63',  // F15_H
  (unsigned char)'\x10',  // F16
  (unsigned char)'\x63',  // F16_H
  (unsigned char)'\x11',  // F17
  (unsigned char)'\x63',  // F17_H
  (unsigned char)'\x12',  // F18
  (unsigned char)'\x63',  // F18_H
  (unsigned char)'\x13',  // F19
  (unsigned char)'\x63',  // F19_H
  (unsigned char)'\x14',  // F20
  (unsigned char)'\x63',  // F20_H
  (unsigned char)'\x15',  // F21
  (unsigned char)'\x63',  // F21_H
  (unsigned char)'\x16',  // F22
  (unsigned char)'\x63',  // F22_H
  (unsigned char)'\x17',  // F23
  (unsigned char)'\x63',  // F23_H
  (unsigned char)'\x18',  // F24
  (unsigned char)'\x63',  // F24_H
  (unsigned char)'\x19',  // F25
  (unsigned char)'\x63',  // F25_H
  (unsigned char)'\x1A',  // F26
  (unsigned char)'\x63',  // F26_H
  (unsigned char)'\x1B',  // F27
  (unsigned char)'\x63',  // F27_H
  (unsigned char)'\x1C',  // F28
  (unsigned char)'\x63',  // F28_H
  (unsigned char)'\x1D',  // F29
  (unsigned char)'\x63',  // F29_H
  (unsigned char)'\x1E',  // F30
  (unsigned char)'\x63',  // F30_H
  (unsigned char)'\x1F',  // F31
  (unsigned char)'\x63',  // F31_H
  (unsigned char)'\x0',  // CCR0
  (unsigned char)'\x1',  // CCR1
  (unsigned char)'\x2',  // CCR2
  (unsigned char)'\x3',  // CCR3
  (unsigned char)'\x4',  // CCR4
  (unsigned char)'\x5',  // CCR5
  (unsigned char)'\x6',  // CCR6
  (unsigned char)'\x7',  // CCR7
  (unsigned char)'\x0',  // SR_XER
  (unsigned char)'\x1',  // SR_LR
  (unsigned char)'\x2',  // SR_CTR
  (unsigned char)'\x3',  // SR_VRSAVE
  (unsigned char)'\x4',  // SR_SPEFSCR
  (unsigned char)'\x5' // no trailing comma  // SR_PPR
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone(Compile* C) const {
  return  new (C) labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone(Compile* C) const {
  return  new (C) methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIdstOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RW_mask();
}

const RegMask *iRegIsrcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *rscratch1RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH1_BITS32_REG_mask();
}

const RegMask *rscratch2RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH2_BITS32_REG_mask();
}

const RegMask *rarg1RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG1_BITS32_REG_mask();
}

const RegMask *rarg2RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG2_BITS32_REG_mask();
}

const RegMask *rarg3RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG3_BITS32_REG_mask();
}

const RegMask *rarg4RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG4_BITS32_REG_mask();
}

const RegMask *rarg1RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG1_BITS64_REG_mask();
}

const RegMask *rarg2RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG2_BITS64_REG_mask();
}

const RegMask *rarg3RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG3_BITS64_REG_mask();
}

const RegMask *rarg4RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG4_BITS64_REG_mask();
}

const RegMask *iRegPdstOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RW_mask();
}

const RegMask *iRegPdstNoScratchOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_LEAF_CALL_mask();
}

const RegMask *iRegPsrcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *threadRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &THREAD_BITS64_REG_mask();
}

const RegMask *rscratch1RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH1_BITS64_REG_mask();
}

const RegMask *rscratch2RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH2_BITS64_REG_mask();
}

const RegMask *rarg1RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG1_BITS64_REG_mask();
}

const RegMask *rarg2RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG2_BITS64_REG_mask();
}

const RegMask *rarg3RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG3_BITS64_REG_mask();
}

const RegMask *rarg4RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RARG4_BITS64_REG_mask();
}

const RegMask *iRegNsrcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *iRegNdstOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RW_mask();
}

const RegMask *iRegLdstOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RW_mask();
}

const RegMask *iRegLsrcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *iRegL2IsrcOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *rscratch1RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH1_BITS64_REG_mask();
}

const RegMask *rscratch2RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH2_BITS64_REG_mask();
}

const RegMask *flagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegCR0Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_CR0_mask();
}

const RegMask *flagsRegCR1Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_CR1_mask();
}

const RegMask *flagsRegCR6Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_CR6_mask();
}

const RegMask *regCTROper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &CTR_REG_mask();
}

const RegMask *regDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DBL_REG_mask();
}

const RegMask *regFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLT_REG_mask();
}

const RegMask *inline_cache_regPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R19_BITS64_REG_mask();
}

const RegMask *compiler_method_oop_regPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RSCRATCH1_BITS64_REG_mask();
}

const RegMask *interpreter_method_oop_regPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R19_BITS64_REG_mask();
}

const RegMask *iRegP2NOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *iRegN2POper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *indOffset16Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *indOffset16Alg4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS64_REG_RO_mask();
}

const RegMask *indirectNarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *indOffset16NarrowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *indOffset16NarrowAlg4Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &BITS32_REG_RO_mask();
}

const RegMask *stackSlotIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *stackSlotDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

//------------------Define members for classes derived from MachNode----------

// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode( MachNode* node, Compile* C) const {
  // This architecture does not have cisc or short branch instructions
  ShouldNotCallThis();
}

void rangeCheck_iReg_uimm15Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void rangeCheck_iReg_uimm15Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void rangeCheck_iReg_iRegNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void rangeCheck_iReg_iRegNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void rangeCheck_uimm15_iRegNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void rangeCheck_uimm15_iRegNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void zeroCheckN_iReg_imm0Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void zeroCheckN_iReg_imm0Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void zeroCheckP_reg_imm0Node::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void zeroCheckP_reg_imm0Node::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(4));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConFarNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConFarNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConSchedNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConSchedNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndFarNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndFarNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndSchedNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndSchedNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallStaticJavaDirectHandleNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectSchedNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectSched_ExNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirect_ExNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirect_ExNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadUB_indirectNode::reloc() const {
  return 1;
}

int loadUB_indirect_acNode::reloc() const {
  return 1;
}

int loadB_indirect_ExNode::reloc() const {
  return 1;
}

int loadB_indirect_ac_ExNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB_acNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadUB2L_acNode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS_acNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS_acNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadUS2L_acNode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI_acNode::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadI2L_acNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadL_acNode::reloc() const {
  return 1;
}

int loadL_unalignedNode::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadNNode::reloc() const {
  return 1;
}

int loadN_acNode::reloc() const {
  return 1;
}

int loadN2P_unscaledNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadP_acNode::reloc() const {
  return 1;
}

int loadP2XNode::reloc() const {
  return 1;
}

int loadNKlassNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadF_acNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadD_acNode::reloc() const {
  return 1;
}

int loadD_unalignedNode::reloc() const {
  return 1;
}

int loadConP0or1Node::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConP_loNode::reloc() const {
  return 1;
}

int loadConP_ExNode::reloc() const {
  return 1;
}

int loadConFNode::reloc() const {
  return 1;
}

int loadConFCompNode::reloc() const {
  return 1;
}

int loadConF_ExNode::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 1;
}

int loadConDCompNode::reloc() const {
  return 1;
}

int loadConD_ExNode::reloc() const {
  return 2;
}

int prefetchrNode::reloc() const {
  return 1;
}

int prefetchr_no_offsetNode::reloc() const {
  return 1;
}

int prefetchwNode::reloc() const {
  return 1;
}

int prefetchw_no_offsetNode::reloc() const {
  return 1;
}

int prefetch_alloc_zeroNode::reloc() const {
  return 1;
}

int prefetch_alloc_zero_no_offsetNode::reloc() const {
  return 1;
}

int prefetch_allocNode::reloc() const {
  return 1;
}

int prefetch_alloc_no_offsetNode::reloc() const {
  return 1;
}

int storeBNode::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 2;
}

int storeI_convL2INode::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeA8BNode::reloc() const {
  return 2;
}

int storeNNode::reloc() const {
  return 3;
}

int storeNKlassNode::reloc() const {
  return 3;
}

int storePNode::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeCM_CMSNode::reloc() const {
  return 2;
}

int storeCM_CMS_ExExNode::reloc() const {
  return 2;
}

int storeCM_G1Node::reloc() const {
  return 2;
}

int cmovP_regNode::reloc() const {
  return 1;
}

int cmovP_immNode::reloc() const {
  return 1;
}

int loadPLockedNode::reloc() const {
  return 1;
}

int addI_reg_regNode::reloc() const {
  return 2;
}

int addP_reg_regNode::reloc() const {
  return 1;
}

int addP_reg_imm16Node::reloc() const {
  return 1;
}

int addP_reg_immhi16Node::reloc() const {
  return 1;
}

int shrP_convP2X_reg_imm6Node::reloc() const {
  return 1;
}

int castP2XNode::reloc() const {
  return 1;
}

int convP2Bool_reg__cntlz_ExNode::reloc() const {
  return 1;
}

int convP2Bool_reg__cmoveNode::reloc() const {
  return 1;
}

int xorI_convP2Bool_reg__cntlz_ExNode::reloc() const {
  return 1;
}

int xorI_convP2Bool_reg_immIvalue1__cmoveNode::reloc() const {
  return 1;
}

int zeroCheckP_reg_imm0Node::reloc() const {
  return 2;
}

int cmpP_reg_regNode::reloc() const {
  return 2;
}

int cmpP_reg_nullNode::reloc() const {
  return 2;
}

int partialSubtypeCheckNode::reloc() const {
  return 2;
}

int string_indexOf_imm1_charNode::reloc() const {
  return 1;
}

int repl2F_immF_ExNode::reloc() const {
  return 1;
}

int repl2F_immF0Node::reloc() const {
  return 1;
}

int safePoint_pollNode::reloc() const {
  return 1;
}

int safePoint_poll_conPollAddrNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectHandleNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectSchedNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectSched_ExNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafDirect_ExNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirect_ExNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int tailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}


void convB2I_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5197 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsb);
    __ extsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 7046 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convB2I_reg_2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB_indirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2459 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lbz);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7069 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB_indirectNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB_indirect_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2467 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7094 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB_indirect_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUB_indOffset16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2459 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lbz);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7117 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB_indOffset16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB_indOffset16_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2467 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7142 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB_indOffset16_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2459 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lbz);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7165 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2467 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7190 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2459 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lbz);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7213 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB2L_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2467 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lbz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7238 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUB2L_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5355 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lha);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lha(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7261 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadSNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadS_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5372 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lha(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7286 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadS_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2476 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lhz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lhz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7310 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUSNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUS_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2485 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lhz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7336 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUS_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2476 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lhz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lhz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7360 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUS2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUS2L_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2485 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lhz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7386 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUS2L_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7410 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2504 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7436 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadI_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7461 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadUI2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5479 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwa);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwa(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7484 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadI2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2L_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5496 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwa);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwa(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7509 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadI2L_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7534 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadL_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2524 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7561 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadL_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadL_unalignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7586 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadL_unalignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7611 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadV8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7635 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadRangeNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7659 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadNNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadN_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2504 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7685 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadN_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadN2P_unscaledNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7709 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadN2P_unscaledNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7734 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadP_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2524 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 7761 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadP_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7786 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadP2XNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7810 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadNKlassNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7835 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadKlassNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5672 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfs);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lfs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7858 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadF_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5691 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    Label next;
    __ lfs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ fcmpu(CCR0, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
    __ bne(CCR0, next);
    __ bind(next);
    __ isync();
  
#line 7886 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadF_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2535 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lfd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7909 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadD_acNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    MacroAssembler _masm(&cbuf);

#line 5727 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    Label next;
    __ lfd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ fcmpu(CCR0, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
    __ bne(CCR0, next);
    __ bind(next);
    __ isync();
  
#line 7937 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadD_acNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void loadD_unalignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2535 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lfd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 7960 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadD_unalignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadToc_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 5762 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ calculate_address_from_global_toc_hi16only(opnd_array(0)->as_Register(ra_,this)/* dst */, __ method_toc());
  
#line 7982 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadToc_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadToc_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5776 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    __ calculate_address_from_global_toc_lo16only(opnd_array(0)->as_Register(ra_,this)/* dst */, __ method_toc());
  
#line 8004 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadToc_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5789 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 8026 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConI16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConIhi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5803 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    // Lis sign extends 16-bit src then shifts it 16 bit to the left.
    __ lis(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)((opnd_array(1)->constant()& 0xFFFF0000) >> 16)));
  
#line 8049 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConIhi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConI32_lo16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5820 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0xFFFF);
  
#line 8072 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConI32_lo16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConL16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short) (opnd_array(1)->constantL()& 0xFFFF)));
  
#line 8094 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConL16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConL32hi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5862 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ lis(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)((opnd_array(1)->constantL()& 0xFFFF0000) >> 16)));
  
#line 8116 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConL32hi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConL32_lo16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 5878 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constantL()) & 0xFFFF);
  
#line 8139 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConL32_lo16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {

#line 2542 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);

    MacroAssembler _masm(&cbuf);
    int toc_offset = 0;

    if (!ra_->C->in_scratch_emit_size()) {
      address const_toc_addr;
      // Create a non-oop constant, no relocation needed.
      // If it is an IC, it has a virtual_call_Relocation.
      const_toc_addr = __ long_constant((jlong)opnd_array(1)->constantL());

      // Get the constant's TOC offset.
      toc_offset = __ offset_to_method_toc(const_toc_addr);

      // Keep the current instruction offset in mind.
      ((loadConLNode*)this)->_cbuf_insts_offset = __ offset();
    }

    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, toc_offset, opnd_array(2)->as_Register(ra_,this,idx2)/* toc */);
  
#line 8178 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConL_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {

#line 2564 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);

    MacroAssembler _masm(&cbuf);

    if (!ra_->C->in_scratch_emit_size()) {
      address const_toc_addr;
      // Create a non-oop constant, no relocation needed.
      // If it is an IC, it has a virtual_call_Relocation.
      const_toc_addr = __ long_constant((jlong)opnd_array(1)->constantL());

      // Get the constant's TOC offset.
      const int toc_offset = __ offset_to_method_toc(const_toc_addr);
      // Store the toc offset of the constant.
      ((loadConL_hiNode*)this)->_const_toc_offset = toc_offset;

      // Also keep the current instruction offset in mind.
      ((loadConL_hiNode*)this)->_cbuf_insts_offset = __ offset();
    }

    __ addis(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* toc */, MacroAssembler::largeoffset_si16_si16_hi(_const_toc_offset));
  
#line 8218 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConL_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConL_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 5958 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    int offset = ra_->C->in_scratch_emit_size() ? 0 : _const_toc_offset_hi_node->_const_toc_offset;
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, MacroAssembler::largeoffset_si16_si16_lo(offset), opnd_array(2)->as_Register(ra_,this,idx2)/* base */);
  
#line 8242 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConL_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  loadConL_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegLdst, 	dst
  unsigned idx_src   = idx1; 	// immL, 	src
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_toc     = lookup(idx_toc);
  iRegLdstOper *op_dst = (iRegLdstOper *)opnd_array(0);
  immLOper *op_src = (immLOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 2671 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // Create new nodes.
    loadConLNodesTuple loadConLNodes =
      loadConLNodesTuple_create(C, ra_, n_toc, op_src,
                                ra_->get_reg_second(this), ra_->get_reg_first(this));

    // Push new nodes.
    if (loadConLNodes._large_hi) nodes->push(loadConLNodes._large_hi);
    if (loadConLNodes._last)     nodes->push(loadConLNodes._last);

    // some asserts
    assert(nodes->length() >= 1, "must have created at least 1 node");
    assert(loadConLNodes._last->bottom_type()->isa_long(), "must be long");
  
#line 8282 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConL_ExNode::eval_constant(Compile* C) {
  // User did not define an encode section.
}
void loadConN0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5985 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, 0);
  
#line 8302 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConN0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConN_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 5999 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ lis(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)(short)((opnd_array(1)->constant()>> 16) & 0xffff));
  
#line 8324 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConN_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConN_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 6013 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    assert(__ oop_recorder() != NULL, "this assembler needs an OopRecorder");
    int oop_index = __ oop_recorder()->find_index((jobject)opnd_array(2)->constant());
    RelocationHolder rspec = oop_Relocation::spec(oop_index);
    __ relocate(rspec, 1);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant()& 0xffff);
  
#line 8351 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConN_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void clearMs32bNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6034 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0x20);
  
#line 8373 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint clearMs32bNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  loadConN_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegNdst, 	dst
  unsigned idx_src   = idx1; 	// immN, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  iRegNdstOper *op_dst = (iRegNdstOper *)opnd_array(0);
  immNOper *op_src = (immNOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 6049 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    MachNode *m1 = new (C) loadConN_hiNode();
    MachNode *m2 = new (C) loadConN_loNode();
    MachNode *m3 = new (C) clearMs32bNode();
    m1->add_req(NULL);
    m2->add_req(NULL, m1);
    m3->add_req(NULL, m2);
    m1->_opnds[0] = op_dst;
    m1->_opnds[1] = op_src;
    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_dst;
    m2->_opnds[2] = op_src;
    m3->_opnds[0] = op_dst;
    m3->_opnds[1] = op_dst;
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(m3->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    nodes->push(m1);
    nodes->push(m2);
    nodes->push(m3);
  
#line 8418 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConNKlass_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6082 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    intptr_t Csrc = Klass::encode_klass((Klass *)opnd_array(1)->constant());
    __ lis(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)(short)((Csrc >> 16) & 0xffff));
  
#line 8436 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConNKlass_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConNKlass_maskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 6098 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, 0x20);
  
#line 8459 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConNKlass_maskNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConNKlass_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 6114 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    intptr_t Csrc = Klass::encode_klass((Klass *)opnd_array(1)->constant());
    assert(__ oop_recorder() != NULL, "this assembler needs an OopRecorder");
    int klass_index = __ oop_recorder()->find_index((Klass *)opnd_array(1)->constant());
    RelocationHolder rspec = metadata_Relocation::spec(klass_index);

    __ relocate(rspec, 1);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, Csrc & 0xffff);
  
#line 8488 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConNKlass_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  loadConNKlass_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegNdst, 	dst
  unsigned idx_src   = idx1; 	// immNKlass, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  iRegNdstOper *op_dst = (iRegNdstOper *)opnd_array(0);
  immNKlassOper *op_src = (immNKlassOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 6134 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // Load high bits into register. Sign extended.
    MachNode *m1 = new (C) loadConNKlass_hiNode();
    m1->add_req(NULL);
    m1->_opnds[0] = op_dst;
    m1->_opnds[1] = op_src;
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    nodes->push(m1);

    MachNode *m2 = m1;
    if (!Assembler::is_uimm((jlong)Klass::encode_klass((Klass *)op_src->constant()), 31)) {
      // Value might be 1-extended. Mask out these bits.
      m2 = new (C) loadConNKlass_maskNode();
      m2->add_req(NULL, m1);
      m2->_opnds[0] = op_dst;
      m2->_opnds[1] = op_src;
      m2->_opnds[2] = op_dst;
      ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      nodes->push(m2);
    }

    MachNode *m3 = new (C) loadConNKlass_loNode();
    m3->add_req(NULL, m2);
    m3->_opnds[0] = op_dst;
    m3->_opnds[1] = op_src;
    m3->_opnds[2] = op_dst;
    ra_->set_pair(m3->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    nodes->push(m3);
  
#line 8541 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConP0or1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6172 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 8558 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConP0or1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {

#line 2686 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);

    MacroAssembler _masm(&cbuf);
    int toc_offset = 0;

    if (!ra_->C->in_scratch_emit_size()) {
      intptr_t val = opnd_array(1)->constant();
      relocInfo::relocType constant_reloc = opnd_array(1)->constant_reloc();  // src
      address const_toc_addr;
      if (constant_reloc == relocInfo::oop_type) {
        // Create an oop constant and a corresponding relocation.
        AddressLiteral a = __ allocate_oop_address((jobject)val);
        const_toc_addr = __ address_constant((address)a.value(), RelocationHolder::none);
        __ relocate(a.rspec());
      } else if (constant_reloc == relocInfo::metadata_type) {
        AddressLiteral a = __ allocate_metadata_address((Metadata *)val);
        const_toc_addr = __ address_constant((address)a.value(), RelocationHolder::none);
        __ relocate(a.rspec());
      } else {
        // Create a non-oop constant, no relocation needed.
        const_toc_addr = __ long_constant((jlong)opnd_array(1)->constant());
      }

      // Get the constant's TOC offset.
      toc_offset = __ offset_to_method_toc(const_toc_addr);
    }

    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, toc_offset, opnd_array(2)->as_Register(ra_,this,idx2)/* toc */);
  
#line 8606 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConP_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {

#line 2717 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);

    MacroAssembler _masm(&cbuf);
    if (!ra_->C->in_scratch_emit_size()) {
      intptr_t val = opnd_array(1)->constant();
      relocInfo::relocType constant_reloc = opnd_array(1)->constant_reloc();  // src
      address const_toc_addr;
      if (constant_reloc == relocInfo::oop_type) {
        // Create an oop constant and a corresponding relocation.
        AddressLiteral a = __ allocate_oop_address((jobject)val);
        const_toc_addr = __ address_constant((address)a.value(), RelocationHolder::none);
        __ relocate(a.rspec());
      } else if (constant_reloc == relocInfo::metadata_type) {
        AddressLiteral a = __ allocate_metadata_address((Metadata *)val);
        const_toc_addr = __ address_constant((address)a.value(), RelocationHolder::none);
        __ relocate(a.rspec());
      } else {  // non-oop pointers, e.g. card mark base, heap top
        // Create a non-oop constant, no relocation needed.
        const_toc_addr = __ long_constant((jlong)opnd_array(1)->constant());
      }

      // Get the constant's TOC offset.
      const int toc_offset = __ offset_to_method_toc(const_toc_addr);
      // Store the toc offset of the constant.
      ((loadConP_hiNode*)this)->_const_toc_offset = toc_offset;
    }

    __ addis(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* toc */, MacroAssembler::largeoffset_si16_si16_hi(_const_toc_offset));
  
#line 8654 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConP_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConP_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 6220 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    int offset = ra_->C->in_scratch_emit_size() ? 0 : _const_toc_offset_hi_node->_const_toc_offset;
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, MacroAssembler::largeoffset_si16_si16_lo(offset), opnd_array(2)->as_Register(ra_,this,idx2)/* base */);
  
#line 8678 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConP_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  loadConP_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegPdst, 	dst
  unsigned idx_src   = idx1; 	// immP, 	src
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_toc     = lookup(idx_toc);
  iRegPdstOper *op_dst = (iRegPdstOper *)opnd_array(0);
  immPOper *op_src = (immPOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 2751 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    const bool large_constant_pool = true; // TODO: PPC port C->cfg()->_consts_size > 4000;
    if (large_constant_pool) {
      // Create new nodes.
      loadConP_hiNode *m1 = new (C) loadConP_hiNode();
      loadConP_loNode *m2 = new (C) loadConP_loNode();

      // inputs for new nodes
      m1->add_req(NULL, n_toc);
      m2->add_req(NULL, m1);

      // operands for new nodes
      m1->_opnds[0] = new (C) iRegPdstOper(); // dst
      m1->_opnds[1] = op_src;                 // src
      m1->_opnds[2] = new (C) iRegPdstOper(); // toc
      m2->_opnds[0] = new (C) iRegPdstOper(); // dst
      m2->_opnds[1] = op_src;                 // src
      m2->_opnds[2] = new (C) iRegLdstOper(); // base

      // Initialize ins_attrib TOC fields.
      m1->_const_toc_offset = -1;
      m2->_const_toc_offset_hi_node = m1;

      // Register allocation for new nodes.
      ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(m1);
      nodes->push(m2);
      assert(m2->bottom_type()->isa_ptr(), "must be ptr");
    } else {
      loadConPNode *m2 = new (C) loadConPNode();

      // inputs for new nodes
      m2->add_req(NULL, n_toc);

      // operands for new nodes
      m2->_opnds[0] = new (C) iRegPdstOper(); // dst
      m2->_opnds[1] = op_src;                 // src
      m2->_opnds[2] = new (C) iRegPdstOper(); // toc

      // Register allocation for new nodes.
      ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(m2);
      assert(m2->bottom_type()->isa_ptr(), "must be ptr");
    }
  
#line 8752 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConP_ExNode::eval_constant(Compile* C) {
  // User did not define an encode section.
}
void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {
    MacroAssembler _masm(&cbuf);

#line 6257 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfs);
    address float_address = __ float_constant(opnd_array(1)->constantF());
    __ lfs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, __ offset_to_method_toc(float_address), opnd_array(2)->as_Register(ra_,this,idx2)/* toc */);
  
#line 8774 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConFCompNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {
    MacroAssembler _masm(&cbuf);

#line 6276 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    FloatRegister Rdst    = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    Register Rtoc         = opnd_array(2)->as_Register(ra_,this,idx2)/* toc */;
    address float_address = __ float_constant(opnd_array(1)->constantF());
    int offset            = __ offset_to_method_toc(float_address);
    int hi = (offset + (1<<15))>>16;
    int lo = offset - hi * (1<<16);

    __ addis(Rtoc, Rtoc, hi);
    __ lfs(Rdst, lo, Rtoc);
    __ addis(Rtoc, Rtoc, -hi);
  
#line 8806 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConFCompNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void  loadConF_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// regF, 	dst
  unsigned idx_src   = idx1; 	// immF, 	src
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_toc     = lookup(idx_toc);
  regFOper *op_dst = (regFOper *)opnd_array(0);
  immFOper *op_src = (immFOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 2802 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    bool large_constant_pool = true; // TODO: PPC port C->cfg()->_consts_size > 4000;

    MachNode *m2;
    if (large_constant_pool) {
      m2 = new (C) loadConFCompNode();
    } else {
      m2 = new (C) loadConFNode();
    }
    // inputs for new nodes
    m2->add_req(NULL, n_toc);

    // operands for new nodes
    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_src;
    m2->_opnds[2] = new (C) iRegPdstOper(); // constanttablebase

    // register allocation for new nodes
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    nodes->push(m2);
  
#line 8853 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConF_ExNode::eval_constant(Compile* C) {
  // User did not define an encode section.
}
void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {
    MacroAssembler _masm(&cbuf);

#line 6313 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfd);
    int offset =  __ offset_to_method_toc(__ double_constant(opnd_array(1)->constantD()));
    __ lfd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, offset, opnd_array(2)->as_Register(ra_,this,idx2)/* toc */);
  
#line 8875 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConDCompNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// toc
  {
    MacroAssembler _masm(&cbuf);

#line 6332 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    FloatRegister Rdst    = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    Register      Rtoc    = opnd_array(2)->as_Register(ra_,this,idx2)/* toc */;
    address float_address = __ double_constant(opnd_array(1)->constantD());
    int offset            = __ offset_to_method_toc(float_address);
    int hi = (offset + (1<<15))>>16;
    int lo = offset - hi * (1<<16);

    __ addis(Rtoc, Rtoc, hi);
    __ lfd(Rdst, lo, Rtoc);
    __ addis(Rtoc, Rtoc, -hi);
  
#line 8907 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadConDCompNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void  loadConD_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// regD, 	dst
  unsigned idx_src   = idx1; 	// immD, 	src
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_toc     = lookup(idx_toc);
  regDOper *op_dst = (regDOper *)opnd_array(0);
  immDOper *op_src = (immDOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 2826 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    bool large_constant_pool = true; // TODO: PPC port C->cfg()->_consts_size > 4000;

    MachNode *m2;
    if (large_constant_pool) {
      m2 = new (C) loadConDCompNode();
    } else {
      m2 = new (C) loadConDNode();
    }
    // inputs for new nodes
    m2->add_req(NULL, n_toc);

    // operands for new nodes
    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_src;
    m2->_opnds[2] = new (C) iRegPdstOper(); // constanttablebase

    // register allocation for new nodes
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    nodes->push(m2);
  
#line 8954 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadConD_ExNode::eval_constant(Compile* C) {
  // User did not define an encode section.
}
void prefetchrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6369 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbt);
    __ dcbt(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 8975 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetchrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetchr_no_offsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6382 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbt);
    __ dcbt(as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 8997 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetchr_no_offsetNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetchwNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6395 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbtst(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9020 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetchwNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetchw_no_offsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6408 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbtst(as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9042 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetchw_no_offsetNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetch_alloc_zeroNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6423 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbz(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9065 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetch_alloc_zeroNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetch_alloc_zero_no_offsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6437 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbz(as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9087 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetch_alloc_zero_no_offsetNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetch_allocNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6451 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbtst(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9110 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetch_allocNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetch_alloc_no_offsetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 6465 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_dcbtst);
    __ dcbtst(as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9132 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint prefetch_alloc_no_offsetNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6481 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stb);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stb(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9156 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6496 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sth);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ sth(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9180 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeCNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stw(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9204 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeI_convL2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stw(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9228 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeI_convL2INode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2855 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_std);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ std(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9254 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeA8BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2855 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_std);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ std(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9280 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeA8BNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stw(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9304 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeNNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeNKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stw(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9328 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeNKlassNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// dst
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2855 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_std);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ std(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9354 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storePNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2864 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stfs);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stfs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9378 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 2871 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ stfd(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9402 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeCM_CMSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// releaseFieldAddr
  {

#line 2880 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    // FIXME: Implement this as a cmove and use a fixed condition code
    // register which is written on every transition to compiled code,
    // e.g. in call-stub and when returning from runtime stubs.
    //
    // Proposed code sequence for the cmove implementation:
    //
    // Label skip_release;
    // __ beq(CCRfixed, skip_release);
    // __ release();
    // __ bind(skip_release);
    // __ stb(card mark);

    MacroAssembler _masm(&cbuf);
    Label skip_storestore;

#if 0 // TODO: PPC port
    // Check CMSCollectorCardTableModRefBSExt::_requires_release and do the
    // StoreStore barrier conditionally.
    __ lwz(R0, 0, opnd_array(2)->as_Register(ra_,this,idx2)/* releaseFieldAddr */);
    __ cmpwi(CCR0, R0, 0);
    __ beq_predict_taken(CCR0, skip_storestore);
#endif
    __ li(R0, 0);
    __ membar(Assembler::StoreStore);
#if 0 // TODO: PPC port
    __ bind(skip_storestore);
#endif

    // Do the store.
    if (opnd_array(1)->index(ra_,this,idx1) == 0) {
      __ stb(R0, opnd_array(1)->disp(ra_,this,idx1), as_Register(opnd_array(1)->base(ra_,this,idx1)));
    } else {
      assert(0 == opnd_array(1)->disp(ra_,this,idx1), "no displacement possible with indexed load/stores on ppc");
      __ stbx(R0, as_Register(opnd_array(1)->base(ra_,this,idx1)), as_Register(opnd_array(1)->index(ra_,this,idx1)));
    }
  
#line 9458 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void storeCM_G1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 6653 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ li(R0, 0);
    //__ release(); // G1: oops are allowed to get visible after dirty marking
    guarantee(as_Register(opnd_array(1)->base(ra_,this,idx1))!= R1_SP, "use frame_slots_bias");
    __ stb(R0, opnd_array(1)->disp(ra_,this,idx1), as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 9479 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint storeCM_G1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void encodeP_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6675 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_oop_shift() & 0x3f);
  
#line 9501 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodeP_shiftNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void encodeP_subNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6690 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, R30, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 9523 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodeP_subNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cond_sub_baseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 6709 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);
    Label done;
    __ beq(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, R30, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 9550 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cond_sub_baseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void cond_set_0_oopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 6728 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description exists.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ isel_0(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, Assembler::equal, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */);
  
#line 9574 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cond_set_0_oopNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void encodeP_32GAlignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6744 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ rldicl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 64-Universe::narrow_oop_shift(), 32);
  
#line 9596 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodeP_32GAlignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  encodeP_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegNdst, 	dst
  unsigned idx_src   = idx1; 	// iRegPdst, 	src
  unsigned idx_crx   = idx2; 	// flagsReg, 	crx
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_crx     = lookup(idx_crx);
  iRegNdstOper *op_dst = (iRegNdstOper *)opnd_array(0);
  iRegPdstOper *op_src = (iRegPdstOper *)opnd_array(1);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 2919 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


    if (VM_Version::has_isel()) {
      // use isel instruction with Power 7
      cmpP_reg_imm16Node *n_compare  = new (C) cmpP_reg_imm16Node();
      encodeP_subNode    *n_sub_base = new (C) encodeP_subNode();
      encodeP_shiftNode  *n_shift    = new (C) encodeP_shiftNode();
      cond_set_0_oopNode *n_cond_set = new (C) cond_set_0_oopNode();

      n_compare->add_req(n_region, n_src);
      n_compare->_opnds[0] = op_crx;
      n_compare->_opnds[1] = op_src;
      n_compare->_opnds[2] = new (C) immL16Oper(0);

      n_sub_base->add_req(n_region, n_src);
      n_sub_base->_opnds[0] = op_dst;
      n_sub_base->_opnds[1] = op_src;
      n_sub_base->_bottom_type = _bottom_type;

      n_shift->add_req(n_region, n_sub_base);
      n_shift->_opnds[0] = op_dst;
      n_shift->_opnds[1] = op_dst;
      n_shift->_bottom_type = _bottom_type;

      n_cond_set->add_req(n_region, n_compare, n_shift);
      n_cond_set->_opnds[0] = op_dst;
      n_cond_set->_opnds[1] = op_crx;
      n_cond_set->_opnds[2] = op_dst;
      n_cond_set->_bottom_type = _bottom_type;

      ra_->set_pair(n_compare->_idx, ra_->get_reg_second(n_crx), ra_->get_reg_first(n_crx));
      ra_->set_pair(n_sub_base->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_shift->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_cond_set->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(n_compare);
      nodes->push(n_sub_base);
      nodes->push(n_shift);
      nodes->push(n_cond_set);

    } else {
      // before Power 7
      moveRegNode        *n_move     = new (C) moveRegNode();
      cmpP_reg_imm16Node *n_compare  = new (C) cmpP_reg_imm16Node();
      encodeP_shiftNode  *n_shift    = new (C) encodeP_shiftNode();
      cond_sub_baseNode  *n_sub_base = new (C) cond_sub_baseNode();

      n_move->add_req(n_region, n_src);
      n_move->_opnds[0] = op_dst;
      n_move->_opnds[1] = op_src;
      ra_->set_oop(n_move, true); // Until here, 'n_move' still produces an oop.

      n_compare->add_req(n_region, n_src);
      n_compare->add_prec(n_move);

      n_compare->_opnds[0] = op_crx;
      n_compare->_opnds[1] = op_src;
      n_compare->_opnds[2] = new (C) immL16Oper(0);

      n_sub_base->add_req(n_region, n_compare, n_src);
      n_sub_base->_opnds[0] = op_dst;
      n_sub_base->_opnds[1] = op_crx;
      n_sub_base->_opnds[2] = op_src;
      n_sub_base->_bottom_type = _bottom_type;

      n_shift->add_req(n_region, n_sub_base);
      n_shift->_opnds[0] = op_dst;
      n_shift->_opnds[1] = op_dst;
      n_shift->_bottom_type = _bottom_type;

      ra_->set_pair(n_shift->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_compare->_idx, ra_->get_reg_second(n_crx), ra_->get_reg_first(n_crx));
      ra_->set_pair(n_sub_base->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_move->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(n_move);
      nodes->push(n_compare);
      nodes->push(n_sub_base);
      nodes->push(n_shift);
    }

    assert(!(ra_->is_oop(this)), "sanity"); // This is not supposed to be GC'ed.
  
#line 9707 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void  encodeP_not_null_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegNdst, 	dst
  unsigned idx_src   = idx1; 	// iRegPdst, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  iRegNdstOper *op_dst = (iRegNdstOper *)opnd_array(0);
  iRegPdstOper *op_src = (iRegPdstOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3003 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


    encodeP_subNode *n1 = new (C) encodeP_subNode();
    n1->add_req(n_region, n_src);
    n1->_opnds[0] = op_dst;
    n1->_opnds[1] = op_src;
    n1->_bottom_type = _bottom_type;

    encodeP_shiftNode *n2 = new (C) encodeP_shiftNode();
    n2->add_req(n_region, n1);
    n2->_opnds[0] = op_dst;
    n2->_opnds[1] = op_dst;
    n2->_bottom_type = _bottom_type;
    ra_->set_pair(n1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(n2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

    nodes->push(n1);
    nodes->push(n2);
    assert(!(ra_->is_oop(this)), "sanity"); // This is not supposed to be GC'ed.
  
#line 9746 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void encodeP_not_null_base_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6783 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_oop_shift() & 0x3f);
  
#line 9763 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodeP_not_null_base_nullNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void encodeP_narrow_oop_shift_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6798 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 9785 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void decodeN_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6815 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ sldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_oop_shift());
  
#line 9802 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint decodeN_shiftNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void decodeN_addNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6830 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, R30);
  
#line 9824 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint decodeN_addNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cond_add_baseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 6852 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);
    Label done;
    __ beq(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, R30);
    // TODO PPC port  __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 9851 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cond_add_baseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling()) */? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling()) */? 12 : 8);
}

void cond_set_0_ptrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  {
    MacroAssembler _masm(&cbuf);

#line 6873 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description exists.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ isel_0(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, Assembler::equal, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */);
  
#line 9875 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cond_set_0_ptrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  decodeN_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegPdst, 	dst
  unsigned idx_src   = idx1; 	// iRegNsrc, 	src
  unsigned idx_crx   = idx2; 	// flagsReg, 	crx
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_crx     = lookup(idx_crx);
  iRegPdstOper *op_dst = (iRegPdstOper *)opnd_array(0);
  iRegNsrcOper *op_src = (iRegNsrcOper *)opnd_array(1);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 3024 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    decodeN_shiftNode *n_shift    = new (C) decodeN_shiftNode();
    cmpN_reg_imm0Node *n_compare  = new (C) cmpN_reg_imm0Node();

    n_compare->add_req(n_region, n_src);
    n_compare->_opnds[0] = op_crx;
    n_compare->_opnds[1] = op_src;
    n_compare->_opnds[2] = new (C) immN_0Oper(TypeNarrowOop::NULL_PTR);

    n_shift->add_req(n_region, n_src);
    n_shift->_opnds[0] = op_dst;
    n_shift->_opnds[1] = op_src;
    n_shift->_bottom_type = _bottom_type;

    if (VM_Version::has_isel()) {
      // use isel instruction with Power 7

      decodeN_addNode *n_add_base = new (C) decodeN_addNode();
      n_add_base->add_req(n_region, n_shift);
      n_add_base->_opnds[0] = op_dst;
      n_add_base->_opnds[1] = op_dst;
      n_add_base->_bottom_type = _bottom_type;

      cond_set_0_ptrNode *n_cond_set = new (C) cond_set_0_ptrNode();
      n_cond_set->add_req(n_region, n_compare, n_add_base);
      n_cond_set->_opnds[0] = op_dst;
      n_cond_set->_opnds[1] = op_crx;
      n_cond_set->_opnds[2] = op_dst;
      n_cond_set->_bottom_type = _bottom_type;

      assert(ra_->is_oop(this) == true, "A decodeN node must produce an oop!");
      ra_->set_oop(n_cond_set, true);

      ra_->set_pair(n_shift->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_compare->_idx, ra_->get_reg_second(n_crx), ra_->get_reg_first(n_crx));
      ra_->set_pair(n_add_base->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_cond_set->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(n_compare);
      nodes->push(n_shift);
      nodes->push(n_add_base);
      nodes->push(n_cond_set);

    } else {
      // before Power 7
      cond_add_baseNode *n_add_base = new (C) cond_add_baseNode();

      n_add_base->add_req(n_region, n_compare, n_shift);
      n_add_base->_opnds[0] = op_dst;
      n_add_base->_opnds[1] = op_crx;
      n_add_base->_opnds[2] = op_dst;
      n_add_base->_bottom_type = _bottom_type;

      assert(ra_->is_oop(this) == true, "A decodeN node must produce an oop!");
      ra_->set_oop(n_add_base, true);

      ra_->set_pair(n_shift->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
      ra_->set_pair(n_compare->_idx, ra_->get_reg_second(n_crx), ra_->get_reg_first(n_crx));
      ra_->set_pair(n_add_base->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

      nodes->push(n_compare);
      nodes->push(n_shift);
      nodes->push(n_add_base);
    }
  
#line 9968 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void decodeN_nullBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6902 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ sldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_oop_shift());
  
#line 9985 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint decodeN_nullBaseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  decodeN_notNull_addBase_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegPdst, 	dst
  unsigned idx_src   = idx1; 	// iRegNsrc, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  iRegPdstOper *op_dst = (iRegPdstOper *)opnd_array(0);
  iRegNsrcOper *op_src = (iRegNsrcOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3090 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    decodeN_shiftNode *n1 = new (C) decodeN_shiftNode();
    n1->add_req(n_region, n_src);
    n1->_opnds[0] = op_dst;
    n1->_opnds[1] = op_src;
    n1->_bottom_type = _bottom_type;

    decodeN_addNode *n2 = new (C) decodeN_addNode();
    n2->add_req(n_region, n1);
    n2->_opnds[0] = op_dst;
    n2->_opnds[1] = op_dst;
    n2->_bottom_type = _bottom_type;
    ra_->set_pair(n1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(n2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

    assert(ra_->is_oop(this) == true, "A decodeN node must produce an oop!");
    ra_->set_oop(n2, true);

    nodes->push(n1);
    nodes->push(n2);
  
#line 10030 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void decodeN_unscaledNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6929 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 10047 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void decodeN2I_unscaledNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6944 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 10064 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void encodePKlass_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6963 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_klass_shift());
  
#line 10081 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodePKlass_shiftNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void encodePKlass_sub_baseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// base
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6978 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* base */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 10104 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodePKlass_sub_baseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void encodePKlass_32GAlignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 6993 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ rldicl(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 64-Universe::narrow_klass_shift(), 32);
  
#line 10126 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint encodePKlass_32GAlignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  encodePKlass_not_null_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// base
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegNdst, 	dst
  unsigned idx_base  = idx1; 	// iRegLsrc, 	base
  unsigned idx_src   = idx2; 	// iRegPsrc, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_base    = lookup(idx_base);
  Node    *n_src     = lookup(idx_src);
  iRegNdstOper *op_dst = (iRegNdstOper *)opnd_array(0);
  iRegLsrcOper *op_base = (iRegLsrcOper *)opnd_array(1);
  iRegPsrcOper *op_src = (iRegPsrcOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 7006 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    encodePKlass_sub_baseNode *n1 = new (C) encodePKlass_sub_baseNode();
    n1->add_req(n_region, n_base, n_src);
    n1->_opnds[0] = op_dst;
    n1->_opnds[1] = op_base;
    n1->_opnds[2] = op_src;
    n1->_bottom_type = _bottom_type;

    encodePKlass_shiftNode *n2 = new (C) encodePKlass_shiftNode();
    n2->add_req(n_region, n1);
    n2->_opnds[0] = op_dst;
    n2->_opnds[1] = op_dst;
    n2->_bottom_type = _bottom_type;
    ra_->set_pair(n1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(n2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

    nodes->push(n1);
    nodes->push(n2);
  
#line 10173 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void decodeNKlass_shiftNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7053 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ sldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Universe::narrow_klass_shift());
  
#line 10190 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint decodeNKlass_shiftNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void decodeNKlass_add_baseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// base
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7069 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* base */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
  
#line 10213 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint decodeNKlass_add_baseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  decodeNKlass_notNull_addBase_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// base
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegPdst, 	dst
  unsigned idx_base  = idx1; 	// iRegLsrc, 	base
  unsigned idx_src   = idx2; 	// iRegNsrc, 	src
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_base    = lookup(idx_base);
  Node    *n_src     = lookup(idx_src);
  iRegPdstOper *op_dst = (iRegPdstOper *)opnd_array(0);
  iRegLsrcOper *op_base = (iRegLsrcOper *)opnd_array(1);
  iRegNsrcOper *op_src = (iRegNsrcOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 7083 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    decodeNKlass_add_baseNode *n1 = new (C) decodeNKlass_add_baseNode();
    n1->add_req(n_region, n_base, n_src);
    n1->_opnds[0] = op_dst;
    n1->_opnds[1] = op_base;
    n1->_opnds[2] = op_src;
    n1->_bottom_type = _bottom_type;

    decodeNKlass_shiftNode *n2 = new (C) decodeNKlass_shiftNode();
    n2->add_req(n_region, n1);
    n2->_opnds[0] = op_dst;
    n2->_opnds[1] = op_dst;
    n2->_bottom_type = _bottom_type;

    ra_->set_pair(n1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));
    ra_->set_pair(n2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this));

    nodes->push(n1);
    nodes->push(n2);
  
#line 10261 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7133 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwsync);
    __ acquire();
  
#line 10278 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint membar_acquireNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void unnecessary_membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint unnecessary_membar_acquireNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquire_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7167 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwsync);
    __ release();
  
#line 10326 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint membar_releaseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_release_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7167 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwsync);
    __ release();
  
#line 10348 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint membar_release_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7180 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwsync);
    __ membar(Assembler::StoreStore);
  
#line 10370 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint membar_storestoreNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_release_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 7203 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sync);
    __ fence();
  
#line 10405 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint membar_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_CPUOrderNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_CPUOrderNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void cmovI_reg_iselNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7260 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description
    // exists. Anyways, the scheduler should be off on Power7.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int cc        = opnd_array(1)->ccode();
    __ isel(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */,
            (Assembler::Condition)(cc & 3), /*invert*/((~cc) & 8), opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
  
#line 10447 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_reg_iselNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int cc        = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(cc), cc_to_biint(cc, flags_reg), done);
    __ mr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10481 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3127 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ li(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant());
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10513 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovL_reg_iselNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7306 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description
    // exists. Anyways, the scheduler should be off on Power7.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int cc        = opnd_array(1)->ccode();
    __ isel(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */,
            (Assembler::Condition)(cc & 3), /*invert*/((~cc) & 8), opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
  
#line 10542 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovL_reg_iselNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int cc        = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(cc), cc_to_biint(cc, flags_reg), done);
    __ mr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10576 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovL_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovL_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3127 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ li(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL());
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10608 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovL_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovN_reg_iselNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7352 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description
    // exists. Anyways, the scheduler should be off on Power7.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int cc        = opnd_array(1)->ccode();
    __ isel(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */,
            (Assembler::Condition)(cc & 3), /*invert*/((~cc) & 8), opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
  
#line 10637 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovN_reg_iselNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovN_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int cc        = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(cc), cc_to_biint(cc, flags_reg), done);
    __ mr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10671 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovN_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovN_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3127 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ li(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant());
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10703 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovN_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovP_reg_iselNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7399 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is a Power7 instruction for which no machine description
    // exists. Anyways, the scheduler should be off on Power7.
    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    int cc        = opnd_array(1)->ccode();
    __ isel(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */,
            (Assembler::Condition)(cc & 3), /*invert*/((~cc) & 8), opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
  
#line 10732 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovP_reg_iselNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3112 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int cc        = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(cc), cc_to_biint(cc, flags_reg), done);
    __ mr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10766 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovP_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {

#line 3127 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ li(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant());
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10798 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovP_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void cmovF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7446 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmovef);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ fmr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10829 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void cmovD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7468 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmovef);
    Label done;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    // Branch if not (cmp crx).
    __ bc(cc_to_inverse_boint(opnd_array(1)->ccode()), cc_to_biint(opnd_array(1)->ccode(), opnd_array(2)->reg(ra_,this,idx2)/* crx */), done);
    __ fmr(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 10860 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void storeLConditional_regP_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldVal
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newVal
  {
    MacroAssembler _masm(&cbuf);

#line 7495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ cmpxchgd(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* oldVal */, opnd_array(3)->as_Register(ra_,this,idx3)/* newVal */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarNone, MacroAssembler::cmpxchgx_hint_atomic_update(),
                noreg, NULL, true);
  
#line 10886 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void storePConditional_regP_regP_regPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldVal
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newVal
  {
    MacroAssembler _masm(&cbuf);

#line 7513 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ cmpxchgd(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* oldVal */, opnd_array(3)->as_Register(ra_,this,idx3)/* newVal */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarNone, MacroAssembler::cmpxchgx_hint_atomic_update(),
                noreg, NULL, true);
  
#line 10907 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void loadPLockedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {

#line 2524 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
    __ twi_0(opnd_array(0)->as_Register(ra_,this)/* dst */);
    __ isync();
  
#line 10929 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint loadPLockedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void compareAndSwapI_regP_regI_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7547 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    // CmpxchgX sets CCR0 to cmpX(src1, src2) and Rres to 'true'/'false'.
    __ cmpxchgw(CCR0, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarFenceAfter, MacroAssembler::cmpxchgx_hint_atomic_update(),
                opnd_array(0)->as_Register(ra_,this)/* res */, true);
  
#line 10956 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void compareAndSwapN_regP_regN_regNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7561 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    // CmpxchgX sets CCR0 to cmpX(src1, src2) and Rres to 'true'/'false'.
    __ cmpxchgw(CCR0, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarFenceAfter, MacroAssembler::cmpxchgx_hint_atomic_update(),
                opnd_array(0)->as_Register(ra_,this)/* res */, true);
  
#line 10978 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void compareAndSwapL_regP_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7575 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    // CmpxchgX sets CCR0 to cmpX(src1, src2) and Rres to 'true'/'false'.
    __ cmpxchgd(CCR0, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarFenceAfter, MacroAssembler::cmpxchgx_hint_atomic_update(),
                opnd_array(0)->as_Register(ra_,this)/* res */, NULL, true);
  
#line 11000 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void compareAndSwapP_regP_regP_regPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7589 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    // CmpxchgX sets CCR0 to cmpX(src1, src2) and Rres to 'true'/'false'.
    __ cmpxchgd(CCR0, R0, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */,
                MacroAssembler::MemBarFenceAfter, MacroAssembler::cmpxchgx_hint_atomic_update(),
                opnd_array(0)->as_Register(ra_,this)/* res */, NULL, true);
  
#line 11022 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndAddINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3141 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ lwarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ add(Rtmp, Rsrc, Rold);
    __ stwcx_(Rtmp, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ subf(Rres, Rsrc, Rtmp);
    __ fence();
  
#line 11059 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndAddLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3166 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ ldarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ add(Rtmp, Rsrc, Rold);
    __ stdcx_(Rtmp, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ subf(Rres, Rsrc, Rtmp);
    __ fence();
  
#line 11096 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndSetINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3191 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ lwarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ stwcx_(Rsrc, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ mr(Rres, Rtmp);
    __ fence();
  
#line 11132 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndSetLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3215 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ ldarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ stdcx_(Rsrc, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ mr(Rres, Rtmp);
    __ fence();
  
#line 11168 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndSetPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3215 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ ldarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ stdcx_(Rsrc, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ mr(Rres, Rtmp);
    __ fence();
  
#line 11204 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void getAndSetNNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3191 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    Register Rtmp   = R0;
    Register Rres   = opnd_array(0)->as_Register(ra_,this)/* res */;
    Register Rsrc   = opnd_array(2)->as_Register(ra_,this,idx2)/* src */;
    Register Rptr   = opnd_array(1)->as_Register(ra_,this,idx1)/* mem_ptr */;
    bool RegCollision = (Rres == Rsrc) || (Rres == Rptr);
    Register Rold   = RegCollision ? Rtmp : Rres;

    Label Lretry;
    __ bind(Lretry);
    __ lwarx(Rold, Rptr, MacroAssembler::cmpxchgx_hint_atomic_update());
    __ stwcx_(Rsrc, Rptr);
    if (UseStaticBranchPredictionInCompareAndSwapPPC64) {
      __ bne_predict_not_taken(CCR0, Lretry);
    } else {
      __ bne(                  CCR0, Lretry);
    }
    if (RegCollision) __ mr(Rres, Rtmp);
    __ fence();
  
#line 11240 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7655 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11258 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addI_reg_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7668 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11281 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addI_reg_reg_2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addI_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7694 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ addi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 11304 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addI_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addI_reg_immhi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7706 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ addis(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant())>>16);
  
#line 11327 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addI_reg_immhi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7718 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11350 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addL_reg_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7731 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11373 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addL_reg_reg_2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addI_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7758 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11396 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addI_regL_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addL_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7771 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ addi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 11419 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addL_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addL_reg_immhi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7785 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ addis(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constantL())>>16);
  
#line 11442 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addL_reg_immhi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7797 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_add);
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11465 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addP_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addP_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7811 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ addi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 11488 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addP_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addP_reg_immhi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7825 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addis);
    __ addis(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constantL())>>16);
  
#line 11511 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addP_reg_immhi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7840 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 11534 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7854 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ addi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) * (-1));
  
#line 11557 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subI_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_imm16_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7867 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subfic);
    __ subfic(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->constant());
  
#line 11580 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subI_imm16_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void signmask32I_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7883 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srawi);
    __ srawi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0x1f);
  
#line 11602 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint signmask32I_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negI_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7907 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_neg);
    __ neg(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11625 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negI_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7919 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 11648 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7932 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 11671 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subI_regL_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subL_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7948 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ addi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constantL()) * (-1));
  
#line 11694 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subL_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void signmask64I_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7964 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sradi);
    __ sradi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0x3f);
  
#line 11716 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint signmask64I_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void signmask64L_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 7980 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sradi);
    __ sradi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0x3f);
  
#line 11738 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint signmask64L_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 7992 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_neg);
    __ neg(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11761 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negI_con0_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8005 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_neg);
    __ neg(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11784 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negI_con0_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8022 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mullw);
    __ mullw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11807 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulI_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8036 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mulli);
    __ mulli(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 11830 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulI_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8049 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mulld);
    __ mulld(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11853 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulHighL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8063 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mulhd);
    __ mulhd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11876 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulHighL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulL_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8077 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mulli);
    __ mulli(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 11899 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulL_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divI_reg_immIvalueMinus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8091 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_neg);
    __ neg(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 11922 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divI_reg_immIvalueMinus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divI_reg_regnotMinus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8108 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_divw);
    __ divw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11945 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divI_reg_regnotMinus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_bne_negI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8124 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);
    Label done;
    __ bne(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, done);
    __ neg(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 11973 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_bne_negI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void divL_reg_immLvalueMinus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8156 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_neg);
    __ neg(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 11996 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divL_reg_immLvalueMinus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divL_reg_regnotMinus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8171 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_divd);
    __ divd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12019 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divL_reg_regnotMinus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovL_bne_negL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 8187 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);
    Label done;
    __ bne(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, done);
    __ neg(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */);
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 12047 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovL_bne_negL_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT (InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void maskI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 8261 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->constant());
  
#line 12070 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint maskI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8275 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_slw);
    __ slw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12093 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8299 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ slwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x1f);
  
#line 12116 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftI_andI_immInegpow2_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 8313 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm); // FIXME: assert that rlwinm is equal to addi
    long src2      = opnd_array(2)->constant();
    long src3      = opnd_array(3)->constant();
    long maskbits  = src3 + log2_long((jlong) (julong) (juint) -src2);
    if (maskbits >= 32) {
      __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, 0); // addi
    } else {
      __ rlwinm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, src3 & 0x1f, 0, (31-maskbits) & 0x1f);
    }
  
#line 12147 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftI_andI_immInegpow2_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftI_andI_immInegpow2_rShiftI_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8334 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm); // FIXME: assert that rlwinm is equal to addi
    long src2      = opnd_array(3)->constant();
    long src3      = opnd_array(2)->constant();
    long maskbits  = src3 + log2_long((jlong) (julong) (juint) -src2);
    if (maskbits >= 32) {
      __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, 0); // addi
    } else {
      __ rlwinm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 0, 0, (31-maskbits) & 0x1f);
    }
  
#line 12178 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftI_andI_immInegpow2_rShiftI_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftL_regL_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8355 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sld);
    __ sld(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12201 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftL_regL_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lshiftL_regL_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8379 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ sldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12224 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lshiftL_regL_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void lShiftL_regI_immGE32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8393 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ sldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12247 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint lShiftL_regI_immGE32Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void scaledPositiveI2L_lShiftL_convI2L_reg_imm6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8408 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldic);
    __ clrlsldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 0x20, opnd_array(2)->constant());
  
#line 12270 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint scaledPositiveI2L_lShiftL_convI2L_reg_imm6Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void arShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8422 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sraw);
    __ sraw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12293 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint arShiftI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void arShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8447 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srawi);
    __ srawi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x1f);
  
#line 12316 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint arShiftI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void arShiftL_regL_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8461 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srad);
    __ srad(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12339 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint arShiftL_regL_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void arShiftL_regL_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8487 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sradi);
    __ sradi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12362 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint arShiftL_regL_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2I_arShiftL_regL_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8500 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_sradi);
    __ sradi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12385 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convL2I_arShiftL_regL_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void urShiftI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srw);
    __ srw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12408 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint urShiftI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void urShiftI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8540 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ srwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x1f);
  
#line 12431 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint urShiftI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void urShiftL_regL_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8554 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srd);
    __ srd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12454 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint urShiftL_regL_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void urShiftL_regL_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8580 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12477 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint urShiftL_regL_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2I_urShiftL_regL_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8593 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12500 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convL2I_urShiftL_regL_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrP_convP2X_reg_imm6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8606 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ srdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0x3f);
  
#line 12523 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint shrP_convP2X_reg_imm6Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_urShiftI_regI_immI_immIpow2minus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 8619 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    int rshift = (opnd_array(2)->constant()) & 0x1f;
    int length = log2_long(((jlong) opnd_array(3)->constant()) + 1);
    if (rshift + length > 32) {
      // if necessary, adjust mask to omit rotated bits.
      length = 32 - rshift;
    }
    __ extrdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, length, 64 - (rshift + length));
  
#line 12553 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_urShiftI_regI_immI_immIpow2minus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_urShiftL_regL_immI_immLpow2minus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    MacroAssembler _masm(&cbuf);

#line 8638 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    int rshift  = (opnd_array(2)->constant()) & 0x3f;
    int length = log2_long(((jlong) opnd_array(3)->constantL()) + 1);
    if (rshift + length > 64) {
      // if necessary, adjust mask to omit rotated bits.
      length = 64 - rshift;
    }
    __ extrdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, length, 64 - (rshift + length));
  
#line 12583 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andL_urShiftL_regL_immI_immLpow2minus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sxtI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8656 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsw);
    __ extsw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 12605 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint sxtI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rotlI_reg_immi8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 8672 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rotlwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->constant());
  
#line 12629 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rotlI_reg_immi8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rotlI_reg_immi8_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 8672 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rotlwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(3)->constant());
  
#line 12653 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rotlI_reg_immi8_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rotrI_reg_immi8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// rshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// lshift
  {
    MacroAssembler _masm(&cbuf);

#line 8686 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rotrwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(2)->constant());
  
#line 12677 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rotrI_reg_immi8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rotrI_reg_immi8_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lshift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// rshift
  {
    MacroAssembler _masm(&cbuf);

#line 8686 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rotrwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(3)->constant());
  
#line 12701 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rotrI_reg_immi8_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8701 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fadds);
    __ fadds(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12724 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8714 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fadd);
    __ fadd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12747 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint addD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8727 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fsubs);
    __ fsubs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12770 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8739 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fsub);
    __ fsub(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12793 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint subD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8751 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmuls);
    __ fmuls(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12816 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8763 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmul);
    __ fmul(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12839 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint mulD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8775 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fdivs);
    __ fdivs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12862 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8787 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fdiv);
    __ fdiv(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 12885 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint divD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8799 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fabs);
    __ fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 12907 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint absF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8811 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fabs);
    __ fabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 12929 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint absD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8822 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fneg);
    __ fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 12951 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8833 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fneg);
    __ fneg(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 12973 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negF_absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8845 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fnabs);
    __ fnabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 12995 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negF_absF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negD_absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8857 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fnabs);
    __ fnabs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13017 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint negD_absD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sqrtD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8870 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fsqrt);
    __ fsqrt(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13039 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint sqrtD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sqrtF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 8885 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fsqrts);
    __ fsqrts(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13061 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint sqrtF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void roundDouble_nopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint roundDouble_nopNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void roundFloat_nopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint roundFloat_nopNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8923 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_and);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13110 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_immIhi16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8936 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andis_);
    __ andis_(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (int)((unsigned short)((opnd_array(2)->constant()& 0xFFFF0000) >> 16)));
  
#line 13133 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_immIhi16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8950 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andi_);
    // FIXME: avoid andi_ ?
    __ andi_(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 13157 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_immInegpow2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8963 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ clrrdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, log2_long((jlong)(julong)(juint)-(opnd_array(2)->constant())));
  
#line 13180 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_immInegpow2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_immIpow2minus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8974 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 64-log2_long((((jlong) opnd_array(2)->constant())+1)));
  
#line 13203 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_immIpow2minus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_immIpowerOf2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 8986 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rlwinm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 0,
              (31-log2_long((jlong) opnd_array(2)->constant())) & 0x1f, (31-log2_long((jlong) opnd_array(2)->constant())) & 0x1f);
  
#line 13227 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andI_reg_immIpowerOf2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9001 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_and);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13250 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9016 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andi_);
    // FIXME: avoid andi_ ?
    __ andi_(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 13274 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andL_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_reg_immLnegpow2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9029 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ clrrdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, log2_long((jlong)-opnd_array(2)->constantL()));
  
#line 13297 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andL_reg_immLnegpow2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_reg_immLpow2minus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9040 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 64-log2_long((((jlong) opnd_array(2)->constantL())+1)));
  
#line 13320 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andL_reg_immLpow2minus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2I_andL_reg_immLpow2minus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9054 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 64-log2_long((((jlong) opnd_array(2)->constantL())+1)));
  
#line 13343 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convL2I_andL_reg_immLpow2minus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9068 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ or_unchecked(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13366 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orI_reg_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9081 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ or_unchecked(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13389 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orI_reg_reg_2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orI_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9107 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constant()) & 0xFFFF);
  
#line 13412 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orI_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9121 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ or_unchecked(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13435 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orI_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9135 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ or_unchecked(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13458 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orI_regL_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orL_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    MacroAssembler _masm(&cbuf);

#line 9149 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ori);
    __ ori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (opnd_array(2)->constantL()) & 0xFFFF);
  
#line 13481 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint orL_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9163 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xor);
    __ xorr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13504 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorI_reg_reg_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9176 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xor);
    __ xorr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13527 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_reg_reg_2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorI_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9202 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xori);
    __ xori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 13550 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9216 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xor);
    __ xorr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13573 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorI_regL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9230 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xor);
    __ xorr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13596 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_regL_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorL_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9244 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_xori);
    __ xori(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 13619 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorL_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void notI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9257 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_nor);
    __ nor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 13642 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint notI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void notL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9270 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_nor);
    __ nor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 13665 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint notL_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andcI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {

#line 3241 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andc);
    MacroAssembler _masm(&cbuf);
    __ andc(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
  
#line 13689 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andcI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andcI_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {

#line 3241 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andc);
    MacroAssembler _masm(&cbuf);
    __ andc(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */);
  
#line 13713 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andcI_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andcL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9296 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andc);
    __ andc(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13736 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint andcL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void stkI_to_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 13760 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint stkI_to_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void regI_to_stkINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    __ stw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13783 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint regI_to_stkINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void stkL_to_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 13808 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint stkL_to_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void regL_to_stkLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2855 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_std);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ std(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13833 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint regL_to_stkLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveF2I_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2495 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lwz);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lwz(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 13857 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveF2I_stack_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveF2I_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2864 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stfs);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    __ stfs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13880 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveF2I_reg_stackNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveI2F_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9396 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfs);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1)+ frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lfs(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 13903 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveI2F_stack_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveI2F_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2848 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stw);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    __ stw(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13926 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveI2F_reg_stackNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveF2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2871 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    __ stfd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13949 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveF2L_reg_stackNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveD2L_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2514 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 13974 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveD2L_stack_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveD2L_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2871 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_stfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    __ stfd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 13997 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveD2L_reg_stackNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveL2D_stack_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2535 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_lfd);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(1)->disp(ra_,this,idx1) + frame_slots_bias(opnd_array(1)->base(ra_,this,idx1), ra_);
    __ lfd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Idisp, as_Register(opnd_array(1)->base(ra_,this,idx1)));
  
#line 14020 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveL2D_stack_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveL2D_reg_stackNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 2855 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_std);
    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(0)->disp(ra_,this,0) + frame_slots_bias(opnd_array(0)->base(ra_,this,idx0), ra_);
    // Operand 'ds' requires 4-alignment.
    assert((Idisp & 0x3) == 0, "unaligned offset");
    __ std(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, Idisp, as_Register(opnd_array(0)->base(ra_,this,idx0)));
  
#line 14045 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint moveL2D_reg_stackNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void moveRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9484 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14067 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9499 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14084 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9512 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14101 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint castIINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void convI2Bool_reg__cmoveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  {

#line 3247 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);

    Label done;
    __ cmpwi(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x0));
    __ beq(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x1));
    __ bind(done);
  
#line 14165 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convI2Bool_reg__cmoveNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void xorI_convI2Bool_reg_immIvalue1__cmoveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// crx
  {

#line 3247 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);

    Label done;
    __ cmpwi(opnd_array(3)->as_ConditionRegister(ra_,this,idx3)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x1));
    __ beq(opnd_array(3)->as_ConditionRegister(ra_,this,idx3)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x0));
    __ bind(done);
  
#line 14196 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_convI2Bool_reg_immIvalue1__cmoveNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void convI2Bool_andI_reg_immIpowerOf2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 9627 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwinm);
    __ rlwinm(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, (32-log2_long((jlong)opnd_array(2)->constant())) & 0x1f, 31, 31);
  
#line 14219 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convI2Bool_andI_reg_immIpowerOf2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convP2Bool_reg__cmoveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// crx
  {

#line 3260 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);

    Label done;
    __ cmpdi(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x0));
    __ beq(opnd_array(2)->as_ConditionRegister(ra_,this,idx2)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x1));
    __ bind(done);
  
#line 14249 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convP2Bool_reg__cmoveNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void xorI_convP2Bool_reg_immIvalue1__cmoveNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// crx
  {

#line 3260 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);

    Label done;
    __ cmpdi(opnd_array(3)->as_ConditionRegister(ra_,this,idx3)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 0);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x1));
    __ beq(opnd_array(3)->as_ConditionRegister(ra_,this,idx3)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (0x0));
    __ bind(done);
  
#line 14280 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint xorI_convP2Bool_reg_immIvalue1__cmoveNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void cmpLTMask_reg_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 9729 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_srawi);
    __ srawi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, 0x1f);
  
#line 14303 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpLTMask_reg_immI0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convB2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// amount
  {
    MacroAssembler _masm(&cbuf);

#line 9747 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsb);
    __ extsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14326 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convB2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convS2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// amount
  {
    MacroAssembler _masm(&cbuf);

#line 9759 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsh);
    __ extsh(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14349 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convS2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sxtI_L2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9772 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsw);
    __ extsw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14371 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint sxtI_L2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9783 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_or);
    __ mr_if_needed(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14393 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void convD2IRaw_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9797 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fctiwz);;
    __ fctiwz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14410 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convD2IRaw_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_bso_stackSlotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3273 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(2)->disp(ra_,this,idx2) + frame_slots_bias(opnd_array(2)->base(ra_,this,idx2), ra_);
    Label done;
    __ bso(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(2)->base(ra_,this,idx2)));
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 14439 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_bso_stackSlotLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT(InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT(InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 12 : 8);
}

void  cmovI_bso_stackSlotL_conLvalue0_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegIdst, 	dst
  unsigned idx_crx   = idx1; 	// flagsReg, 	crx
  unsigned idx_mem   = idx2; 	// stackSlotL, 	mem
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_crx     = lookup(idx_crx);
  Node    *n_mem     = lookup(idx_mem);
  iRegIdstOper *op_dst = (iRegIdstOper *)opnd_array(0);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(1);
  stackSlotLOper *op_mem = (stackSlotLOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 9824 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    //
    // replaces
    //
    //   region  dst  crx  mem
    //    \       |    |   /
    //     dst=cmovI_bso_stackSlotL_conLvalue0
    //
    // with
    //
    //   region  dst
    //    \       /
    //     dst=loadConI16(0)
    //      |
    //      ^  region  dst  crx  mem
    //      |   \       |    |    /
    //      dst=cmovI_bso_stackSlotL
    //

    // Create new nodes.
    MachNode *m1 = new (C) loadConI16Node();
    MachNode *m2 = new (C) cmovI_bso_stackSlotLNode();

    // inputs for new nodes
    m1->add_req(n_region);
    m2->add_req(n_region, n_crx, n_mem);

    // precedences for new nodes
    m2->add_prec(m1);

    // operands for new nodes
    m1->_opnds[0] = op_dst;
    m1->_opnds[1] = new (C) immI16Oper(0);

    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_crx;
    m2->_opnds[2] = op_mem;

    // registers for new nodes
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst

    // Insert new nodes.
    nodes->push(m1);
    nodes->push(m2);
  
#line 14513 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void convF2IRaw_regFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9895 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fctiwz);
    __ fctiwz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14530 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convF2IRaw_regFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convI2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9924 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_extsw);
    __ extsw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 14552 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convI2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void zeroExtendL_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 9938 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 32);
  
#line 14575 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint zeroExtendL_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void zeroExtendL_regLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 9952 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicl);
    __ clrldi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, 32);
  
#line 14598 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint zeroExtendL_regLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convF2LRaw_regFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 9966 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fctiwz);
    __ fctidz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14620 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convF2LRaw_regFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovL_bso_stackSlotLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {

#line 3273 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);

    MacroAssembler _masm(&cbuf);
    int Idisp = opnd_array(2)->disp(ra_,this,idx2) + frame_slots_bias(opnd_array(2)->base(ra_,this,idx2), ra_);
    Label done;
    __ bso(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ ld(opnd_array(0)->as_Register(ra_,this)/* dst */, Idisp, as_Register(opnd_array(2)->base(ra_,this,idx2)));
    // TODO PPC port __ endgroup_if_needed(_size == 12);
    __ bind(done);
  
#line 14649 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovL_bso_stackSlotLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT Compile::current()->do_hb_scheduling()*/ ? 12 : 8);
}

void  cmovL_bso_stackSlotL_conLvalue0_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mem
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegLdst, 	dst
  unsigned idx_crx   = idx1; 	// flagsReg, 	crx
  unsigned idx_mem   = idx2; 	// stackSlotL, 	mem
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_crx     = lookup(idx_crx);
  Node    *n_mem     = lookup(idx_mem);
  iRegLdstOper *op_dst = (iRegLdstOper *)opnd_array(0);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(1);
  stackSlotLOper *op_mem = (stackSlotLOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 9993 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    //
    // replaces
    //
    //   region  dst  crx  mem
    //    \       |    |   /
    //     dst=cmovL_bso_stackSlotL_conLvalue0
    //
    // with
    //
    //   region  dst
    //    \       /
    //     dst=loadConL16(0)
    //      |
    //      ^  region  dst  crx  mem
    //      |   \       |    |    /
    //      dst=cmovL_bso_stackSlotL
    //

    // Create new nodes.
    MachNode *m1 = new (C) loadConL16Node();
    MachNode *m2 = new (C) cmovL_bso_stackSlotLNode();

    // inputs for new nodes
    m1->add_req(n_region);
    m2->add_req(n_region, n_crx, n_mem);
    m2->add_prec(m1);

    // operands for new nodes
    m1->_opnds[0] = op_dst;
    m1->_opnds[1] = new (C) immL16Oper(0);
    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_crx;
    m2->_opnds[2] = op_mem;

    // registers for new nodes
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst

    // Insert new nodes.
    nodes->push(m1);
    nodes->push(m2);
  
#line 14720 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void convD2LRaw_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10061 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fctiwz);
    __ fctidz(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14737 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convD2LRaw_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2DRaw_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10094 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fcfid);
    __ fcfid(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14759 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convL2DRaw_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10106 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_frsp);
    __ frsp(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14781 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convD2F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2FRaw_regFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10139 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fcfid);
    __ fcfids(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14803 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint convL2FRaw_regFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 10215 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmr);
    __ fmr_if_needed(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 14825 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void cmpI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10230 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmp);
    __ cmpw(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 14843 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpI_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10241 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpi);
    __ cmpwi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 14866 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpI_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10254 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andi_);
    // FIXME: avoid andi_ ?
    __ andi_(R0, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 14891 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint testI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10266 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmp);
    __ cmpd(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 14914 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpL_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10277 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpi);
    __ cmpdi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 14937 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpL_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpUL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10289 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpl);
    __ cmpld(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 14960 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpUL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpUL_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10300 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpli);
    __ cmpldi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 14983 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpUL_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10312 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_and_);
    __ and_(R0, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 15007 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint testL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testL_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 10324 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_andi_);
    // FIXME: avoid andi_ ?
    __ andi_(R0, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 15032 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint testL_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_conIvalueMinus1_conIvalue1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  {
    MacroAssembler _masm(&cbuf);

#line 10342 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmove);
    Label done;
    // li(Rdst, 0);              // equal -> 0
    __ beq(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, 1);    // greater -> +1
    __ bgt(opnd_array(1)->as_ConditionRegister(ra_,this,idx1)/* crx */, done);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, -1);   // unordered or less -> -1
    // TODO: PPC port__ endgroup_if_needed(_size == 20);
    __ bind(done);
  
#line 15061 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmovI_conIvalueMinus1_conIvalue1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORTInsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 20 : 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORTInsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 20 : 16);
}

void  cmovI_conIvalueMinus1_conIvalue0_conIvalue1_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegIdst, 	dst
  unsigned idx_crx   = idx1; 	// flagsReg, 	crx
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_crx     = lookup(idx_crx);
  iRegIdstOper *op_dst = (iRegIdstOper *)opnd_array(0);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 10362 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    //
    // replaces
    //
    //   region  crx
    //    \       |
    //     dst=cmovI_conIvalueMinus1_conIvalue0_conIvalue1
    //
    // with
    //
    //   region
    //    \
    //     dst=loadConI16(0)
    //      |
    //      ^  region  crx
    //      |   \       |
    //      dst=cmovI_conIvalueMinus1_conIvalue1
    //

    // Create new nodes.
    MachNode *m1 = new (C) loadConI16Node();
    MachNode *m2 = new (C) cmovI_conIvalueMinus1_conIvalue1Node();

    // inputs for new nodes
    m1->add_req(n_region);
    m2->add_req(n_region, n_crx);
    m2->add_prec(m1);

    // operands for new nodes
    m1->_opnds[0] = op_dst;
    m1->_opnds[1] = new (C) immI16Oper(0);
    m2->_opnds[0] = op_dst;
    m2->_opnds[1] = op_crx;

    // registers for new nodes
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // dst

    // Insert new nodes.
    nodes->push(m1);
    nodes->push(m2);
  
#line 15127 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void rangeCheck_iReg_uimm15Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src_length
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// index
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10438 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_twi);
    if (opnd_array(1)->ccode()== 0x1 /* less_equal */) {
      __ trap_range_check_le(opnd_array(2)->as_Register(ra_,this,idx2)/* src_length */, opnd_array(3)->constant());
    } else {
      // Both successors are uncommon traps, probability is 0.
      // Node got flipped during fixup flow.
      assert(opnd_array(1)->ccode()== 0x9, "must be greater");
      __ trap_range_check_g(opnd_array(2)->as_Register(ra_,this,idx2)/* src_length */, opnd_array(3)->constant());
    }
  
#line 15154 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rangeCheck_iReg_uimm15Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rangeCheck_iReg_iRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src_index
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src_length
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10465 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_tw);
    if (opnd_array(1)->ccode()== 0x0 /* greater_equal */) {
      __ trap_range_check_ge(opnd_array(2)->as_Register(ra_,this,idx2)/* src_index */, opnd_array(3)->as_Register(ra_,this,idx3)/* src_length */);
    } else {
      // Both successors are uncommon traps, probability is 0.
      // Node got flipped during fixup flow.
      assert(opnd_array(1)->ccode()== 0x8, "must be less");
      __ trap_range_check_l(opnd_array(2)->as_Register(ra_,this,idx2)/* src_index */, opnd_array(3)->as_Register(ra_,this,idx3)/* src_length */);
    }
  
#line 15186 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rangeCheck_iReg_iRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rangeCheck_uimm15_iRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src_index
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// length
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10492 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_twi);
    if (opnd_array(1)->ccode()== 0x0 /* greater_equal */) {
      __ trap_range_check_ge(opnd_array(2)->as_Register(ra_,this,idx2)/* src_index */, opnd_array(3)->constant());
    } else {
      // Both successors are uncommon traps, probability is 0.
      // Node got flipped during fixup flow.
      assert(opnd_array(1)->ccode()== 0x8, "must be less");
      __ trap_range_check_l(opnd_array(2)->as_Register(ra_,this,idx2)/* src_index */, opnd_array(3)->constant());
    }
  
#line 15218 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint rangeCheck_uimm15_iRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compU_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10510 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpl);
    __ cmplw(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 15241 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint compU_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compU_reg_uimm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10521 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpli);
    __ cmplwi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 15264 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint compU_reg_uimm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void zeroCheckN_iReg_imm0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// value
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10543 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_tdi);
    if (opnd_array(1)->ccode()== 0xA) {
      __ trap_null_check(opnd_array(2)->as_Register(ra_,this,idx2)/* value */);
    } else {
      // Both successors are uncommon traps, probability is 0.
      // Node got flipped during fixup flow.
      assert(opnd_array(1)->ccode()== 0x2 , "must be equal(0xA) or notEqual(0x2)");
      __ trap_null_check(opnd_array(2)->as_Register(ra_,this,idx2)/* value */, Assembler::traptoGreaterThanUnsigned);
    }
  
#line 15296 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint zeroCheckN_iReg_imm0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpN_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10564 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpl);
    __ cmplw(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 15319 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpN_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpN_reg_imm0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10578 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpli);
    __ cmplwi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 15342 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpN_reg_imm0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void zeroCheckP_reg_imm0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// value
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// zero
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// labl
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10599 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_tdi);
    if (opnd_array(1)->ccode()== 0xA) {
      __ trap_null_check(opnd_array(2)->as_Register(ra_,this,idx2)/* value */);
    } else {
      // Both successors are uncommon traps, probability is 0.
      // Node got flipped during fixup flow.
      assert(opnd_array(1)->ccode()== 0x2 , "must be equal(0xA) or notEqual(0x2)");
      __ trap_null_check(opnd_array(2)->as_Register(ra_,this,idx2)/* value */, Assembler::traptoGreaterThanUnsigned);
    }
  
#line 15374 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint zeroCheckP_reg_imm0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10618 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpl);
    __ cmpld(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 15397 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpP_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpP_reg_nullNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10629 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpl);
    __ cmpldi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, (int)((short)(opnd_array(2)->constant()& 0xFFFF)));
  
#line 15420 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpP_reg_nullNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpP_reg_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10646 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmpi);
    __ cmpdi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
  
#line 15443 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpP_reg_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpFUnordered_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10662 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fcmpu);
    __ fcmpu(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 15466 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpFUnordered_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmov_bns_lessNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10679 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cmovecr);
    Label done;
    __ bns(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, done);        // not unordered -> keep crx
    __ li(R0, 0);
    __ cmpwi(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, R0, 1);     // unordered -> set crx to 'less'
    // TODO PPC port __ endgroup_if_needed(_size == 16);
    __ bind(done);
  
#line 15493 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmov_bns_lessNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= false /* TODO: PPC PORT(InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 16 : 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : false /* TODO: PPC PORT(InsertEndGroupPPC64 && Compile::current()->do_hb_scheduling())*/ ? 16 : 12);
}

void  cmpF_reg_reg_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  // Access to ins and operands for postalloc expand.
  unsigned idx_crx   = idx0; 	// flagsReg, 	crx
  unsigned idx_src1  = idx1; 	// regF, 	src1
  unsigned idx_src2  = idx2; 	// regF, 	src2
  Node    *n_region  = lookup(0);
  Node    *n_crx     = lookup(idx_crx);
  Node    *n_src1    = lookup(idx_src1);
  Node    *n_src2    = lookup(idx_src2);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(0);
  regFOper *op_src1 = (regFOper *)opnd_array(1);
  regFOper *op_src2 = (regFOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 10708 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    //
    // replaces
    //
    //   region  src1  src2
    //    \       |     |
    //     crx=cmpF_reg_reg
    //
    // with
    //
    //   region  src1  src2
    //    \       |     |
    //     crx=cmpFUnordered_reg_reg
    //      |
    //      ^  region
    //      |   \
    //      crx=cmov_bns_less
    //

    // Create new nodes.
    MachNode *m1 = new (C) cmpFUnordered_reg_regNode();
    MachNode *m2 = new (C) cmov_bns_lessNode();

    // inputs for new nodes
    m1->add_req(n_region, n_src1, n_src2);
    m2->add_req(n_region);
    m2->add_prec(m1);

    // operands for new nodes
    m1->_opnds[0] = op_crx;
    m1->_opnds[1] = op_src1;
    m1->_opnds[2] = op_src2;
    m2->_opnds[0] = op_crx;

    // registers for new nodes
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // crx
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // crx

    // Insert new nodes.
    nodes->push(m1);
    nodes->push(m2);
  
#line 15563 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void cmpDUnordered_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    MacroAssembler _masm(&cbuf);

#line 10771 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fcmpu);
    __ fcmpu(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 15581 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint cmpDUnordered_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  cmpD_reg_reg_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  // Access to ins and operands for postalloc expand.
  unsigned idx_crx   = idx0; 	// flagsReg, 	crx
  unsigned idx_src1  = idx1; 	// regD, 	src1
  unsigned idx_src2  = idx2; 	// regD, 	src2
  Node    *n_region  = lookup(0);
  Node    *n_crx     = lookup(idx_crx);
  Node    *n_src1    = lookup(idx_src1);
  Node    *n_src2    = lookup(idx_src2);
  flagsRegOper *op_crx = (flagsRegOper *)opnd_array(0);
  regDOper *op_src1 = (regDOper *)opnd_array(1);
  regDOper *op_src2 = (regDOper *)opnd_array(2);
  Compile *C = ra_->C;
  {
#line 10783 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    //
    // replaces
    //
    //   region  src1  src2
    //    \       |     |
    //     crx=cmpD_reg_reg
    //
    // with
    //
    //   region  src1  src2
    //    \       |     |
    //     crx=cmpDUnordered_reg_reg
    //      |
    //      ^  region
    //      |   \
    //      crx=cmov_bns_less
    //

    // create new nodes
    MachNode *m1 = new (C) cmpDUnordered_reg_regNode();
    MachNode *m2 = new (C) cmov_bns_lessNode();

    // inputs for new nodes
    m1->add_req(n_region, n_src1, n_src2);
    m2->add_req(n_region);
    m2->add_prec(m1);

    // operands for new nodes
    m1->_opnds[0] = op_crx;
    m1->_opnds[1] = op_src1;
    m1->_opnds[2] = op_src2;
    m2->_opnds[0] = op_crx;

    // registers for new nodes
    ra_->set_pair(m1->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // crx
    ra_->set_pair(m2->_idx, ra_->get_reg_second(this), ra_->get_reg_first(this)); // crx

    // Insert new nodes.
    nodes->push(m1);
    nodes->push(m2);
  
#line 15651 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 10850 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_b);
     Label d;    // dummy
     __ bind(d);
     Label* p = opnd_array(1)->label();
     // `p' is `NULL' when this encoding class is used only to
     // determine the size of the encoded instruction.
     Label& l = (NULL == p)? d : *(p);
     __ b(l);
  
#line 15674 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3285 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;   // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

    __ bc(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
          cc_to_biint(cc, flags_reg),
          l);
  
#line 15720 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchConNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConFarNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3313 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // The scheduler doesn't know about branch shortening, so we set the opcode
    // to ppc64Opcode_bc in order to hide this detail from the scheduler.
    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;    // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

    // Tell the conditional far branch to optimize itself when being relocated.
    __ bc_far(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                  cc_to_biint(cc, flags_reg),
                  l,
                  MacroAssembler::bc_far_optimize_on_relocate);
  
#line 15769 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchConFarNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void branchConSchedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// lbl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3345 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // The scheduler doesn't know about branch shortening, so we set the opcode
    // to ppc64Opcode_bc in order to hide this detail from the scheduler.
    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;   // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

#if 0 // TODO: PPC port
    if (_size == 8) {
      // Tell the conditional far branch to optimize itself when being relocated.
      __ bc_far(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                    cc_to_biint(cc, flags_reg),
                    l,
                    MacroAssembler::bc_far_optimize_on_relocate);
    } else {
      __ bc    (Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                    cc_to_biint(cc, flags_reg),
                    l);
    }
#endif
    Unimplemented();
  
#line 15827 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchConSchedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3285 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;   // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    assert((Assembler::bcondCRbiIs1 & ~Assembler::bcondCRbiIs0) == 8, "check encoding");
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

    __ bc(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
          cc_to_biint(cc, flags_reg),
          l);
  
#line 15873 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchLoopEndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchLoopEndFarNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3313 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // The scheduler doesn't know about branch shortening, so we set the opcode
    // to ppc64Opcode_bc in order to hide this detail from the scheduler.
    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;    // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

    // Tell the conditional far branch to optimize itself when being relocated.
    __ bc_far(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                  cc_to_biint(cc, flags_reg),
                  l,
                  MacroAssembler::bc_far_optimize_on_relocate);
  
#line 15922 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchLoopEndFarNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void branchLoopEndSchedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// crx
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {

#line 3345 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // The scheduler doesn't know about branch shortening, so we set the opcode
    // to ppc64Opcode_bc in order to hide this detail from the scheduler.
    // TODO: PPC port $archOpcode(ppc64Opcode_bc);

    MacroAssembler _masm(&cbuf);
    Label d;   // dummy
    __ bind(d);
    Label* p = (opnd_array(3)->label());
    // `p' is `NULL' when this encoding class is used only to
    // determine the size of the encoded instruction.
    Label& l = (NULL == p)? d : *(p);
    int cc = opnd_array(1)->ccode();
    int flags_reg = opnd_array(2)->reg(ra_,this,idx2)/* crx */;
    int bhint = Assembler::bhintNoHint;

    if (UseStaticBranchPredictionForUncommonPathsPPC64) {
      if (_prob <= PROB_NEVER) {
        bhint = Assembler::bhintIsNotTaken;
      } else if (_prob >= PROB_ALWAYS) {
        bhint = Assembler::bhintIsTaken;
      }
    }

#if 0 // TODO: PPC port
    if (_size == 8) {
      // Tell the conditional far branch to optimize itself when being relocated.
      __ bc_far(Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                    cc_to_biint(cc, flags_reg),
                    l,
                    MacroAssembler::bc_far_optimize_on_relocate);
    } else {
      __ bc    (Assembler::add_bhint_to_boint(bhint, cc_to_boint(cc)),
                    cc_to_biint(cc, flags_reg),
                    l);
    }
#endif
    Unimplemented();
  
#line 15980 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint branchLoopEndSchedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// subklass
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// superklass
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// result
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp_klass
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp_arrayptr
  {
    MacroAssembler _masm(&cbuf);

#line 10990 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ check_klass_subtype_slow_path(opnd_array(1)->as_Register(ra_,this,idx1)/* subklass */, opnd_array(2)->as_Register(ra_,this,idx2)/* superklass */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp_arrayptr */,
                                     opnd_array(4)->as_Register(ra_,this,idx4)/* tmp_klass */, NULL, opnd_array(3)->as_Register(ra_,this,idx3)/* result */);
  
#line 16007 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    MacroAssembler _masm(&cbuf);

#line 11006 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ compiler_fast_lock_object(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* oop */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */,
                                 opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    // If locking was successfull, crx should indicate 'EQ'.
    // The compiler generates a branch to the runtime call to
    // _complete_monitor_locking_Java for the case where crx is 'NE'.
  
#line 16032 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp3
  {
    MacroAssembler _masm(&cbuf);

#line 11022 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ compiler_fast_unlock_object(opnd_array(0)->as_ConditionRegister(ra_,this)/* crx */, opnd_array(1)->as_Register(ra_,this,idx1)/* oop */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */,
                                   opnd_array(5)->as_Register(ra_,this,idx5)/* tmp3 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */);
    // If unlocking was successfull, crx should indicate 'EQ'.
    // The compiler generates a branch to the runtime call to
    // _complete_monitor_unlocking_Java for the case where crx is 'NE'.
  
#line 16057 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void align_addrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    MacroAssembler _masm(&cbuf);

#line 11039 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldicr);
    __ clrrdi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, log2_long((jlong)-opnd_array(2)->constantL()));
  
#line 16075 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint align_addrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void array_sizeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// end
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// start
  {
    MacroAssembler _masm(&cbuf);

#line 11052 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_subf);
    __ subf(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* start */, opnd_array(1)->as_Register(ra_,this,idx1)/* end */);
  
#line 16098 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint array_sizeNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void inlineCallClearArrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  {
    MacroAssembler _masm(&cbuf);

#line 11068 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ clear_memory_doubleword(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */); // kills cnt, base, R0
  
#line 16121 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_indexOf_imm1_charNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// haystack
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// haycnt
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// needleImm
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// offsetImm
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// needlecntImm
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// result
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp1
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 11104 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    immPOper *needleOper = (immPOper *)opnd_array(3);
    const TypeOopPtr *t = needleOper->type()->isa_oopptr();
    ciTypeArray* needle_values = t->const_oop()->as_type_array();  // Pointer to live char *

    __ string_indexof_1(opnd_array(6)->as_Register(ra_,this,idx6)/* result */,
                        opnd_array(1)->as_Register(ra_,this,idx1)/* haystack */, opnd_array(2)->as_Register(ra_,this,idx2)/* haycnt */,
                        R0, needle_values->char_at(0),
                        opnd_array(7)->as_Register(ra_,this,idx7)/* tmp1 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp2 */);
  
#line 16152 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_indexOf_imm1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// haystack
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// haycnt
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// needle
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// needlecntImm
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// result
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp1
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 11145 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    Node *ndl = in(operand_index(opnd_array(3)));  // The node that defines needle.
    ciTypeArray* needle_values = ndl->bottom_type()->is_aryptr()->const_oop()->as_type_array();
    guarantee(needle_values, "sanity");
    if (needle_values != NULL) {
      __ string_indexof_1(opnd_array(5)->as_Register(ra_,this,idx5)/* result */,
                          opnd_array(1)->as_Register(ra_,this,idx1)/* haystack */, opnd_array(2)->as_Register(ra_,this,idx2)/* haycnt */,
                          R0, needle_values->char_at(0),
                          opnd_array(6)->as_Register(ra_,this,idx6)/* tmp1 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp2 */);
    } else {
      __ string_indexof_1(opnd_array(5)->as_Register(ra_,this,idx5)/* result */,
                          opnd_array(1)->as_Register(ra_,this,idx1)/* haystack */, opnd_array(2)->as_Register(ra_,this,idx2)/* haycnt */,
                          opnd_array(3)->as_Register(ra_,this,idx3)/* needle */, 0,
                          opnd_array(6)->as_Register(ra_,this,idx6)/* tmp1 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp2 */);
    }
  
#line 16188 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_indexOf_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// haystack
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// haycnt
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// needle
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// needlecntImm
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// result
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp1
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp2
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp3
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp4
  unsigned idx10 = idx9 + opnd_array(9)->num_edges(); 	// tmp5
  {
    MacroAssembler _masm(&cbuf);

#line 11192 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    Node *ndl = in(operand_index(opnd_array(3)));  // The node that defines needle.
    ciTypeArray* needle_values = ndl->bottom_type()->is_aryptr()->const_oop()->as_type_array();

    __ string_indexof(opnd_array(5)->as_Register(ra_,this,idx5)/* result */,
                      opnd_array(1)->as_Register(ra_,this,idx1)/* haystack */, opnd_array(2)->as_Register(ra_,this,idx2)/* haycnt */,
                      opnd_array(3)->as_Register(ra_,this,idx3)/* needle */, needle_values, opnd_array(10)->as_Register(ra_,this,idx10)/* tmp5 */, opnd_array(4)->constant(),
                      opnd_array(6)->as_Register(ra_,this,idx6)/* tmp1 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp2 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp3 */, opnd_array(9)->as_Register(ra_,this,idx9)/* tmp4 */);
  
#line 16220 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_indexOfNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// haystack
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// haycnt
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// needle
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// needlecnt
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// result
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp1
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp2
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp3
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp4
  {
    MacroAssembler _masm(&cbuf);

#line 11224 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ string_indexof(opnd_array(5)->as_Register(ra_,this,idx5)/* result */,
                      opnd_array(1)->as_Register(ra_,this,idx1)/* haystack */, opnd_array(2)->as_Register(ra_,this,idx2)/* haycnt */,
                      opnd_array(3)->as_Register(ra_,this,idx3)/* needle */, NULL, opnd_array(4)->as_Register(ra_,this,idx4)/* needlecnt */, 0,  // needlecnt not constant.
                      opnd_array(6)->as_Register(ra_,this,idx6)/* tmp1 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp2 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp3 */, opnd_array(9)->as_Register(ra_,this,idx9)/* tmp4 */);
  
#line 16248 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_equals_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cntImm
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// result
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  {
    MacroAssembler _masm(&cbuf);

#line 11248 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ char_arrays_equalsImm(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */, opnd_array(3)->constant(),
                             opnd_array(4)->as_Register(ra_,this,idx4)/* result */, opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */);
  
#line 16271 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_equalsNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// str2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// cnt
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// result
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp1
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp2
  unsigned idx7 = idx6 + opnd_array(6)->num_edges(); 	// tmp3
  unsigned idx8 = idx7 + opnd_array(7)->num_edges(); 	// tmp4
  unsigned idx9 = idx8 + opnd_array(8)->num_edges(); 	// tmp5
  {
    MacroAssembler _masm(&cbuf);

#line 11271 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ char_arrays_equals(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* str2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* cnt */, opnd_array(4)->as_Register(ra_,this,idx4)/* result */,
                          opnd_array(5)->as_Register(ra_,this,idx5)/* tmp1 */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp2 */, opnd_array(7)->as_Register(ra_,this,idx7)/* tmp3 */, opnd_array(8)->as_Register(ra_,this,idx8)/* tmp4 */, opnd_array(9)->as_Register(ra_,this,idx9)/* tmp5 */);
  
#line 16297 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void string_compareNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// str1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// str2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// cnt2
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// result
  unsigned idx6 = idx5 + opnd_array(5)->num_edges(); 	// tmp
  {
    MacroAssembler _masm(&cbuf);

#line 11292 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ string_compare(opnd_array(1)->as_Register(ra_,this,idx1)/* str1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* str2 */, opnd_array(2)->as_Register(ra_,this,idx2)/* cnt1 */, opnd_array(4)->as_Register(ra_,this,idx4)/* cnt2 */,
                      opnd_array(5)->as_Register(ra_,this,idx5)/* result */, opnd_array(6)->as_Register(ra_,this,idx6)/* tmp */);
  
#line 16320 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11352 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_popcntb);
    __ popcntw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16337 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint popCountINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11367 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_popcntb);
    __ popcntd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16359 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint popCountLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11381 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cntlzw);
    __ cntlzw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16381 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint countLeadingZerosINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11395 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cntlzd);
    __ cntlzd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16403 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint countLeadingZerosLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void countLeadingZerosPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11409 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_cntlzd);
    __ cntlzd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16425 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint countLeadingZerosPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void insrwi_aNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pos
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  {
    MacroAssembler _masm(&cbuf);

#line 11460 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwimi);
    __ insrwi(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(3)->constant(), opnd_array(2)->constant());
  
#line 16449 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint insrwi_aNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void insrwiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pos
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// shift
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11474 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rlwimi);
    __ insrwi(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */, opnd_array(4)->constant(), opnd_array(3)->constant());
  
#line 16474 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint insrwiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl32Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11516 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldimi);
    __ insrdi(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 32, 0);
  
#line 16496 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl32Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl48Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11530 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldimi);
    __ insrdi(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 48, 0);
  
#line 16518 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl48Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl56Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11544 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_rldimi);
    __ insrdi(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 56, 0);
  
#line 16540 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl56Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl8B_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 11567 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16562 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl8B_immI0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl8B_immIminus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11579 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16584 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl8B_immIminus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl4S_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 11601 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16606 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl4S_immI0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl4S_immIminus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11613 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16628 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl4S_immIminus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl2I_immI0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 11635 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16650 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl2I_immI0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void repl2I_immIminus1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    MacroAssembler _masm(&cbuf);

#line 11647 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, (int)((short)(opnd_array(1)->constant()& 0xFFFF)));
  
#line 16672 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint repl2I_immIminus1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  repl2F_immF_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  // Access to ins and operands for postalloc expand.
  unsigned idx_dst   = idx0; 	// iRegLdst, 	dst
  unsigned idx_src   = idx1; 	// immF, 	src
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_dst     = lookup(idx_dst);
  Node    *n_src     = lookup(idx_src);
  Node    *n_toc     = lookup(idx_toc);
  iRegLdstOper *op_dst = (iRegLdstOper *)opnd_array(0);
  immFOper *op_src = (immFOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3389 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // Create new nodes.

    // Make an operand with the bit pattern to load as float.
    immLOper *op_repl = new (C) immLOper((jlong)replicate_immF(op_src->constantF()));

    loadConLNodesTuple loadConLNodes =
      loadConLNodesTuple_create(C, ra_, n_toc, op_repl,
                                ra_->get_reg_second(this), ra_->get_reg_first(this));

    // Push new nodes.
    if (loadConLNodes._large_hi) nodes->push(loadConLNodes._large_hi);
    if (loadConLNodes._last)     nodes->push(loadConLNodes._last);

    assert(nodes->length() >= 1, "must have created at least 1 node");
    assert(loadConLNodes._last->bottom_type()->isa_long(), "must be long");
  
#line 16715 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void repl2F_immF_ExNode::eval_constant(Compile* C) {
  // User did not define an encode section.
}
void repl2F_immF0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  {
    MacroAssembler _masm(&cbuf);

#line 11685 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_addi);
    __ li(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x0);
  
#line 16735 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void safePoint_pollNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3409 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    // Fake operand dst needed for PPC scheduler.
    assert((0x0) == 0x0, "dst must be 0x0");

    MacroAssembler _masm(&cbuf);
    // Mark the code position where the load from the safepoint
    // polling page was emitted as relocInfo::poll_type.
    __ relocate(relocInfo::poll_type);
    __ load_from_polling_page(opnd_array(1)->as_Register(ra_,this,idx1)/* poll */);
  
#line 16758 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint safePoint_pollNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void safePoint_poll_conPollAddrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {

#line 3409 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_ld);
    // Fake operand dst needed for PPC scheduler.
    assert((0x0) == 0x0, "dst must be 0x0");

    MacroAssembler _masm(&cbuf);
    // Mark the code position where the load from the safepoint
    // polling page was emitted as relocInfo::poll_type.
    __ relocate(relocInfo::poll_type);
    __ load_from_polling_page(opnd_array(1)->as_Register(ra_,this,idx1)/* poll */);
  
#line 16786 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3467 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_bl);

    MacroAssembler _masm(&cbuf);
    address entry_point = (address)opnd_array(1)->method();

    if (!_method) {
      // A call to a runtime wrapper, e.g. new, new_typeArray_Java, uncommon_trap.
      emit_call_with_trampoline_stub(_masm, entry_point, relocInfo::runtime_call_type);
    } else {
      // Remember the offset not the address.
      const int start_offset = __ offset();
      // The trampoline stub.
      if (!Compile::current()->in_scratch_emit_size()) {
        // No entry point given, use the current pc.
        // Make sure branch fits into
        if (entry_point == 0) entry_point = __ pc();

        // Put the entry point as a constant into the constant pool.
        const address entry_point_toc_addr   = __ address_constant(entry_point, RelocationHolder::none);
        const int     entry_point_toc_offset = __ offset_to_method_toc(entry_point_toc_addr);

        // Emit the trampoline stub which will be related to the branch-and-link below.
        CallStubImpl::emit_trampoline_stub(_masm, entry_point_toc_offset, start_offset);
        if (ciEnv::current()->failing()) { return; } // Code cache may be full.
        __ relocate(_optimized_virtual ?
                    relocInfo::opt_virtual_call_type : relocInfo::static_call_type);
      }

      // The real call.
      // Note: At this point we do not have the address of the trampoline
      // stub, and the entry point might be too far away for bl, so __ pc()
      // serves as dummy and the bl will be patched later.
      cbuf.set_insts_mark();
      __ bl(__ pc());  // Emits a relocation.

      // The stub for call to interpreter.
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full"); 
        return;
      }
    }
  
#line 16842 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint CallStaticJavaDirectNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void CallStaticJavaDirectHandleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3519 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    address entry_point = (address)opnd_array(1)->method();

    // Remember the offset not the address.
    const int start_offset = __ offset();
    // The trampoline stub.
    if (!ra_->C->in_scratch_emit_size()) {
      // No entry point given, use the current pc.
      // Make sure branch fits into
      if (entry_point == 0) entry_point = __ pc();

      // Put the entry point as a constant into the constant pool.
      const address entry_point_toc_addr   = __ address_constant(entry_point, RelocationHolder::none);
      const int     entry_point_toc_offset = __ offset_to_method_toc(entry_point_toc_addr);

      // Emit the trampoline stub which will be related to the branch-and-link below.
      CallStubImpl::emit_trampoline_stub(_masm, entry_point_toc_offset, start_offset);
      if (ra_->C->env()->failing()) { return; } // Code cache may be full.
      assert(_optimized_virtual, "methodHandle call should be a virtual call");
      __ relocate(relocInfo::opt_virtual_call_type);
    }

    // The real call.
    // Note: At this point we do not have the address of the trampoline
    // stub, and the entry point might be too far away for bl, so __ pc()
    // serves as dummy and the bl will be patched later.
    cbuf.set_insts_mark();
    __ bl(__ pc());  // Emits a relocation.

    assert(_method, "execute next statement conditionally");
    // The stub for call to interpreter.
    address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
    if (stub == NULL) {
      ciEnv::current()->record_failure("CodeCache is full"); 
      return;
    }

    // Restore original sp.
    __ ld(R11_scratch1, 0, R1_SP); // Load caller sp.
    const long framesize = ra_->C->frame_slots() << LogBytesPerInt;
    unsigned int bytes = (unsigned int)framesize;
    long offset = Assembler::align_addr(bytes, frame::alignment_in_bytes);
    if (Assembler::is_simm(-offset, 16)) {
      __ addi(R1_SP, R11_scratch1, -offset);
    } else {
      __ load_const_optimized(R12_scratch2, -offset);
      __ add(R1_SP, R11_scratch1, R12_scratch2);
    }
#ifdef ASSERT
  __ ld(R12_scratch2, 0, R1_SP); // Load from unextended_sp.
  __ cmpd(CCR0, R11_scratch1, R12_scratch2);
  __ asm_assert_eq("backlink changed", 0x8000);
#endif
    // If fails should store backlink before unextending.

    if (ra_->C->env()->failing()) {
      return;
    }
  
#line 16921 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void CallDynamicJavaDirectSchedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3583 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_bl);

    MacroAssembler _masm(&cbuf);

    if (!ra_->C->in_scratch_emit_size()) {
      // Create a call trampoline stub for the given method.
      const address entry_point = !(opnd_array(1)->method()) ? 0 : (address)opnd_array(1)->method();
      const address entry_point_const = __ address_constant(entry_point, RelocationHolder::none);
      const int entry_point_const_toc_offset = __ offset_to_method_toc(entry_point_const);
      CallStubImpl::emit_trampoline_stub(_masm, entry_point_const_toc_offset, __ offset());
      if (ra_->C->env()->failing()) { return; } // Code cache may be full.

      // Build relocation at call site with ic position as data.
      assert((_load_ic_hi_node != NULL && _load_ic_node == NULL) ||
             (_load_ic_hi_node == NULL && _load_ic_node != NULL),
             "must have one, but can't have both");
      assert((_load_ic_hi_node != NULL && _load_ic_hi_node->_cbuf_insts_offset != -1) ||
             (_load_ic_node != NULL    && _load_ic_node->_cbuf_insts_offset != -1),
             "must contain instruction offset");
      const int virtual_call_oop_addr_offset = _load_ic_hi_node != NULL
        ? _load_ic_hi_node->_cbuf_insts_offset
        : _load_ic_node->_cbuf_insts_offset;
      const address virtual_call_oop_addr = __ addr_at(virtual_call_oop_addr_offset);
      assert(MacroAssembler::is_load_const_from_method_toc_at(virtual_call_oop_addr),
             "should be load from TOC");

      __ relocate(virtual_call_Relocation::spec(virtual_call_oop_addr));
    }

    // At this point I do not have the address of the trampoline stub,
    // and the entry point might be too far away for bl. Pc() serves
    // as dummy and bl will be patched later.
    __ bl((address) __ pc());
  
#line 16968 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint CallDynamicJavaDirectSchedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  CallDynamicJavaDirectSched_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // Access to ins and operands for postalloc expand.
  unsigned idx_meth  = idx1; 	// method, 	meth
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_meth    = lookup(idx_meth);
  Node    *n_toc     = lookup(idx_toc);
  methodOper *op_meth = (methodOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3620 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"


    // Create the nodes for loading the IC from the TOC.
    loadConLNodesTuple loadConLNodes_IC =
      loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper((jlong)Universe::non_oop_word()),
                                OptoReg::Name(R19_H_num), OptoReg::Name(R19_num));

    // Create the call node.
    CallDynamicJavaDirectSchedNode *call = new (C) CallDynamicJavaDirectSchedNode();
    call->_method_handle_invoke = _method_handle_invoke;
    call->_vtable_index      = _vtable_index;
    call->_method            = _method;
    call->_bci               = _bci;
    call->_optimized_virtual = _optimized_virtual;
    call->_tf                = _tf;
    call->_entry_point       = _entry_point;
    call->_cnt               = _cnt;
    call->_argsize           = _argsize;
    call->_oop_map           = _oop_map;
    call->_jvms              = _jvms;
    call->_jvmadj            = _jvmadj;
    call->_in_rms            = _in_rms;
    call->_nesting           = _nesting;

    // New call needs all inputs of old call.
    // Req...
    for (uint i = 0; i < req(); ++i) {
      // The expanded node does not need toc any more.
      // Add the inline cache constant here instead. This expresses the
      // register of the inline cache must be live at the call.
      // Else we would have to adapt JVMState by -1.
      if (i == mach_constant_base_node_input()) {
        call->add_req(loadConLNodes_IC._last);
      } else {
        call->add_req(in(i));
      }
    }
    // ...as well as prec
    for (uint i = req(); i < len(); ++i) {
      call->add_prec(in(i));
    }

    // Remember nodes loading the inline cache into r19.
    call->_load_ic_hi_node = loadConLNodes_IC._large_hi;
    call->_load_ic_node    = loadConLNodes_IC._small;

    // Operands for new nodes.
    call->_opnds[0] = _opnds[0];
    call->_opnds[1] = _opnds[1];

    // Only the inline cache is associated with a register.
    assert(Matcher::inline_cache_reg() == OptoReg::Name(R19_num), "ic reg should be R19");

    // Push new nodes.
    if (loadConLNodes_IC._large_hi) nodes->push(loadConLNodes_IC._large_hi);
    if (loadConLNodes_IC._last)     nodes->push(loadConLNodes_IC._last);
    nodes->push(call);
  
#line 17049 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3682 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    MacroAssembler _masm(&cbuf);
    int start_offset = __ offset();

    Register Rtoc = (ra_) ? as_Register(ra_->get_encode(in(mach_constant_base_node_input()))) : R2_TOC;
#if 0
    int vtable_index = this->_vtable_index;
    if (_vtable_index < 0) {
      // Must be invalid_vtable_index, not nonvirtual_vtable_index.
      assert(_vtable_index == Method::invalid_vtable_index, "correct sentinel value");
      Register ic_reg = as_Register(Matcher::inline_cache_reg_encode());

      // Virtual call relocation will point to ic load.
      address virtual_call_meta_addr = __ pc();
      // Load a clear inline cache.
      AddressLiteral empty_ic((address) Universe::non_oop_word());
      __ load_const_from_method_toc(ic_reg, empty_ic, Rtoc);
      // CALL to fixup routine.  Fixup routine uses ScopeDesc info
      // to determine who we intended to call.
      __ relocate(virtual_call_Relocation::spec(virtual_call_meta_addr));
      emit_call_with_trampoline_stub(_masm, (address)opnd_array(1)->method(), relocInfo::none);
      assert(((MachCallDynamicJavaNode*)this)->ret_addr_offset() == __ offset() - start_offset,
             "Fix constant in ret_addr_offset()");
    } else {
      assert(!UseInlineCaches, "expect vtable calls only if not using ICs");
      // Go thru the vtable. Get receiver klass. Receiver already
      // checked for non-null. If we'll go thru a C2I adapter, the
      // interpreter expects method in R19_method.

      __ load_klass(R11_scratch1, R3);

      int entry_offset = InstanceKlass::vtable_start_offset() + _vtable_index * vtableEntry::size();
      int v_off = entry_offset * wordSize + vtableEntry::method_offset_in_bytes();
      __ li(R19_method, v_off);
      __ ldx(R19_method/*method oop*/, R19_method/*method offset*/, R11_scratch1/*class*/);
      // NOTE: for vtable dispatches, the vtable entry will never be
      // null. However it may very well end up in handle_wrong_method
      // if the method is abstract for the particular class.
      __ ld(R11_scratch1, in_bytes(Method::from_compiled_offset()), R19_method);
      // Call target. Either compiled code or C2I adapter.
      __ mtctr(R11_scratch1);
      __ bctrl();
      if (((MachCallDynamicJavaNode*)this)->ret_addr_offset() != __ offset() - start_offset) {
        tty->print(" %d, %d\n", ((MachCallDynamicJavaNode*)this)->ret_addr_offset(),__ offset() - start_offset);
      }
      assert(((MachCallDynamicJavaNode*)this)->ret_addr_offset() == __ offset() - start_offset,
             "Fix constant in ret_addr_offset()");
    }
#endif
    Unimplemented();  // ret_addr_offset not yet fixed. Depends on compressed oops (load klass!).
  
#line 17113 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 3736 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);

    MacroAssembler _masm(&cbuf);
    const address start_pc = __ pc();

#if defined(ABI_ELFv2)
    address entry= !(opnd_array(1)->method()) ? NULL : (address)opnd_array(1)->method();
    __ call_c(entry, relocInfo::runtime_call_type);
#else
    // The function we're going to call.
    FunctionDescriptor fdtemp;
    const FunctionDescriptor* fd = !(opnd_array(1)->method()) ? &fdtemp : (FunctionDescriptor*)opnd_array(1)->method();

    Register Rtoc = R12_scratch2;
    // Calculate the method's TOC.
    __ calculate_address_from_global_toc(Rtoc, __ method_toc());
    // Put entry, env, toc into the constant pool, this needs up to 3 constant
    // pool entries; call_c_using_toc will optimize the call.
    __ call_c_using_toc(fd, relocInfo::runtime_call_type, Rtoc);
#endif

    // Check the ret_addr_offset.
    assert(((MachCallRuntimeNode*)this)->ret_addr_offset() ==  __ last_calls_return_pc() - start_pc,
           "Fix constant in ret_addr_offset()");
  
#line 17151 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void CallLeafDirect_mtctrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {

#line 3766 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mtctr);
    MacroAssembler _masm(&cbuf);
    __ mtctr(opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17168 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint CallLeafDirect_mtctrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11856 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_bctrl);
    __ bctrl();
  
#line 17190 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint CallLeafDirectNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void  CallLeafDirect_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // Access to ins and operands for postalloc expand.
  unsigned idx_meth  = idx1; 	// method, 	meth
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_meth    = lookup(idx_meth);
  Node    *n_toc     = lookup(idx_toc);
  methodOper *op_meth = (methodOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3773 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    loadConLNodesTuple loadConLNodes_Entry;
#if defined(ABI_ELFv2)
    jlong entry_address = (jlong) this->entry_point();
    assert(entry_address, "need address here");
    loadConLNodes_Entry = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper(entry_address),
                                                    OptoReg::Name(R12_H_num), OptoReg::Name(R12_num));
#else
    // Get the struct that describes the function we are about to call.
    FunctionDescriptor* fd = (FunctionDescriptor*) this->entry_point();
    assert(fd, "need fd here");
    jlong entry_address = (jlong) fd->entry();
    // new nodes
    loadConLNodesTuple loadConLNodes_Env;
    loadConLNodesTuple loadConLNodes_Toc;

    // Create nodes and operands for loading the entry point.
    loadConLNodes_Entry = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper(entry_address),
                                                    OptoReg::Name(R12_H_num), OptoReg::Name(R12_num));


    // Create nodes and operands for loading the env pointer.
    if (fd->env() != NULL) {
      loadConLNodes_Env = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper((jlong) fd->env()),
                                                    OptoReg::Name(R11_H_num), OptoReg::Name(R11_num));
    } else {
      loadConLNodes_Env._large_hi = NULL;
      loadConLNodes_Env._large_lo = NULL;
      loadConLNodes_Env._small    = NULL;
      loadConLNodes_Env._last = new (C) loadConL16Node();
      loadConLNodes_Env._last->_opnds[0] = new (C) iRegLdstOper();
      loadConLNodes_Env._last->_opnds[1] = new (C) immL16Oper(0);
      ra_->set_pair(loadConLNodes_Env._last->_idx, OptoReg::Name(R11_H_num), OptoReg::Name(R11_num));
    }

    // Create nodes and operands for loading the Toc point.
    loadConLNodes_Toc = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper((jlong) fd->toc()),
                                                  OptoReg::Name(R2_H_num), OptoReg::Name(R2_num));
#endif // ABI_ELFv2
    // mtctr node
    MachNode *mtctr = new (C) CallLeafDirect_mtctrNode();

    assert(loadConLNodes_Entry._last != NULL, "entry must exist");
    mtctr->add_req(0, loadConLNodes_Entry._last);

    mtctr->_opnds[0] = new (C) iRegLdstOper();
    mtctr->_opnds[1] = new (C) iRegLdstOper();

    // call node
    MachCallLeafNode *call = new (C) CallLeafDirectNode();

    call->_opnds[0] = _opnds[0];
    call->_opnds[1] = new (C) methodOper((intptr_t) entry_address); // May get set later.

    // Make the new call node look like the old one.
    call->_name        = _name;
    call->_tf          = _tf;
    call->_entry_point = _entry_point;
    call->_cnt         = _cnt;
    call->_argsize     = _argsize;
    call->_oop_map     = _oop_map;
    guarantee(!_jvms, "You must clone the jvms and adapt the offsets by fix_jvms().");
    call->_jvms        = NULL;
    call->_jvmadj      = _jvmadj;
    call->_in_rms      = _in_rms;
    call->_nesting     = _nesting;


    // New call needs all inputs of old call.
    // Req...
    for (uint i = 0; i < req(); ++i) {
      if (i != mach_constant_base_node_input()) {
        call->add_req(in(i));
      }
    }

    // These must be reqired edges, as the registers are live up to
    // the call. Else the constants are handled as kills.
    call->add_req(mtctr);
#if !defined(ABI_ELFv2)
    call->add_req(loadConLNodes_Env._last);
    call->add_req(loadConLNodes_Toc._last);
#endif

    // ...as well as prec
    for (uint i = req(); i < len(); ++i) {
      call->add_prec(in(i));
    }

    // registers
    ra_->set1(mtctr->_idx, OptoReg::Name(SR_CTR_num));

    // Insert the new nodes.
    if (loadConLNodes_Entry._large_hi) nodes->push(loadConLNodes_Entry._large_hi);
    if (loadConLNodes_Entry._last)     nodes->push(loadConLNodes_Entry._last);
#if !defined(ABI_ELFv2)
    if (loadConLNodes_Env._large_hi)   nodes->push(loadConLNodes_Env._large_hi);
    if (loadConLNodes_Env._last)       nodes->push(loadConLNodes_Env._last);
    if (loadConLNodes_Toc._large_hi)   nodes->push(loadConLNodes_Toc._large_hi);
    if (loadConLNodes_Toc._last)       nodes->push(loadConLNodes_Toc._last);
#endif
    nodes->push(mtctr);
    nodes->push(call);
  
#line 17317 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void  CallLeafNoFPDirect_ExNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // Access to ins and operands for postalloc expand.
  unsigned idx_meth  = idx1; 	// method, 	meth
  unsigned idx_toc   = mach_constant_base_node_input(); 	// iRegLdst, 	constanttablebase
  Node    *n_region  = lookup(0);
  Node    *n_meth    = lookup(idx_meth);
  Node    *n_toc     = lookup(idx_toc);
  methodOper *op_meth = (methodOper *)opnd_array(1);
  Compile *C = ra_->C;
  {
#line 3773 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    loadConLNodesTuple loadConLNodes_Entry;
#if defined(ABI_ELFv2)
    jlong entry_address = (jlong) this->entry_point();
    assert(entry_address, "need address here");
    loadConLNodes_Entry = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper(entry_address),
                                                    OptoReg::Name(R12_H_num), OptoReg::Name(R12_num));
#else
    // Get the struct that describes the function we are about to call.
    FunctionDescriptor* fd = (FunctionDescriptor*) this->entry_point();
    assert(fd, "need fd here");
    jlong entry_address = (jlong) fd->entry();
    // new nodes
    loadConLNodesTuple loadConLNodes_Env;
    loadConLNodesTuple loadConLNodes_Toc;

    // Create nodes and operands for loading the entry point.
    loadConLNodes_Entry = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper(entry_address),
                                                    OptoReg::Name(R12_H_num), OptoReg::Name(R12_num));


    // Create nodes and operands for loading the env pointer.
    if (fd->env() != NULL) {
      loadConLNodes_Env = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper((jlong) fd->env()),
                                                    OptoReg::Name(R11_H_num), OptoReg::Name(R11_num));
    } else {
      loadConLNodes_Env._large_hi = NULL;
      loadConLNodes_Env._large_lo = NULL;
      loadConLNodes_Env._small    = NULL;
      loadConLNodes_Env._last = new (C) loadConL16Node();
      loadConLNodes_Env._last->_opnds[0] = new (C) iRegLdstOper();
      loadConLNodes_Env._last->_opnds[1] = new (C) immL16Oper(0);
      ra_->set_pair(loadConLNodes_Env._last->_idx, OptoReg::Name(R11_H_num), OptoReg::Name(R11_num));
    }

    // Create nodes and operands for loading the Toc point.
    loadConLNodes_Toc = loadConLNodesTuple_create(C, ra_, n_toc, new (C) immLOper((jlong) fd->toc()),
                                                  OptoReg::Name(R2_H_num), OptoReg::Name(R2_num));
#endif // ABI_ELFv2
    // mtctr node
    MachNode *mtctr = new (C) CallLeafDirect_mtctrNode();

    assert(loadConLNodes_Entry._last != NULL, "entry must exist");
    mtctr->add_req(0, loadConLNodes_Entry._last);

    mtctr->_opnds[0] = new (C) iRegLdstOper();
    mtctr->_opnds[1] = new (C) iRegLdstOper();

    // call node
    MachCallLeafNode *call = new (C) CallLeafDirectNode();

    call->_opnds[0] = _opnds[0];
    call->_opnds[1] = new (C) methodOper((intptr_t) entry_address); // May get set later.

    // Make the new call node look like the old one.
    call->_name        = _name;
    call->_tf          = _tf;
    call->_entry_point = _entry_point;
    call->_cnt         = _cnt;
    call->_argsize     = _argsize;
    call->_oop_map     = _oop_map;
    guarantee(!_jvms, "You must clone the jvms and adapt the offsets by fix_jvms().");
    call->_jvms        = NULL;
    call->_jvmadj      = _jvmadj;
    call->_in_rms      = _in_rms;
    call->_nesting     = _nesting;


    // New call needs all inputs of old call.
    // Req...
    for (uint i = 0; i < req(); ++i) {
      if (i != mach_constant_base_node_input()) {
        call->add_req(in(i));
      }
    }

    // These must be reqired edges, as the registers are live up to
    // the call. Else the constants are handled as kills.
    call->add_req(mtctr);
#if !defined(ABI_ELFv2)
    call->add_req(loadConLNodes_Env._last);
    call->add_req(loadConLNodes_Toc._last);
#endif

    // ...as well as prec
    for (uint i = req(); i < len(); ++i) {
      call->add_prec(in(i));
    }

    // registers
    ra_->set1(mtctr->_idx, OptoReg::Name(SR_CTR_num));

    // Insert the new nodes.
    if (loadConLNodes_Entry._large_hi) nodes->push(loadConLNodes_Entry._large_hi);
    if (loadConLNodes_Entry._last)     nodes->push(loadConLNodes_Entry._last);
#if !defined(ABI_ELFv2)
    if (loadConLNodes_Env._large_hi)   nodes->push(loadConLNodes_Env._large_hi);
    if (loadConLNodes_Env._last)       nodes->push(loadConLNodes_Env._last);
    if (loadConLNodes_Toc._large_hi)   nodes->push(loadConLNodes_Toc._large_hi);
    if (loadConLNodes_Toc._last)       nodes->push(loadConLNodes_Toc._last);
#endif
    nodes->push(mtctr);
    nodes->push(call);
  
#line 17439 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11905 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ mtctr(opnd_array(1)->as_Register(ra_,this,idx1)/* jump_target */);
    __ bctr();
  
#line 17458 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint TailCalljmpIndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11918 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_blr);
    // LR is restored in MachEpilogNode. Just do the RET here.
    __ blr();
  
#line 17481 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint RetNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void tailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11940 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    __ ld(R4_ARG2/* issuing pc */, _abi(lr), R1_SP);
    __ mtctr(opnd_array(1)->as_Register(ra_,this,idx1)/* jump_target */);
    __ bctr();
  
#line 17506 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint tailjmpIndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11969 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_compound);
    cbuf.set_insts_mark();
    __ b64_patchable((address)OptoRuntime::rethrow_stub(), relocInfo::runtime_call_type);
  
#line 17542 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 11984 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_tdi);
    __ trap_should_not_reach_here();
  
#line 17559 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint ShouldNotReachHereNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void endGroupNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12017 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_endgroup);
    __ endgroup();
  
#line 17594 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint endGroupNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void fxNopNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12033 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmr);
    __ nop();
  
#line 17616 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint fxNopNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void fpNop0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12047 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmr);
    __ fpnop0();
  
#line 17638 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint fpNop0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void fpNop1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12061 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_fmr);
    __ fpnop1();
  
#line 17660 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint fpNop1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void brNop0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12072 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mcrf);
    __ brnop0();
  
#line 17682 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint brNop0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void brNop1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12087 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mcrf);
    __ brnop1();
  
#line 17704 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint brNop1Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void brNop2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    MacroAssembler _masm(&cbuf);

#line 12101 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // TODO: PPC port $archOpcode(ppc64Opcode_mcrf);
    __ brnop2();
  
#line 17726 "../generated/adfiles/ad_ppc_64.cpp"
  }
}

uint brNop2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

const MachOper* loadUB_indirectNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_indirect_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_indirect_ExNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_indirect_ac_ExNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_indOffset16Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_indOffset16_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_indOffset16_ExNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB_indOffset16_ac_ExNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_unalignedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadN2P_unscaledNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadP2XNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadF_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_acNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_unalignedNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchrNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchr_no_offsetNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchwNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchw_no_offsetNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetch_alloc_zeroNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetch_alloc_zero_no_offsetNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetch_allocNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetch_alloc_no_offsetNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeI_convL2INode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeA8BNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeNKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCM_CMSNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCM_CMS_ExExNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCM_G1Node::memory_operand() const { return _opnds[1]; }
const TypePtr *membar_acquireNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquireNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *unnecessary_membar_acquireNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* unnecessary_membar_acquireNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_acquire_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_acquire_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_releaseNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_releaseNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_0Node::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_0Node::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_storestoreNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_storestoreNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_release_lockNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_release_lockNode::memory_operand() const { return (MachOper*)-1; }
const TypePtr *membar_volatileNode::adr_type() const { return TypePtr::BOTTOM; }
const MachOper* membar_volatileNode::memory_operand() const { return (MachOper*)-1; }
const MachOper* storeLConditional_regP_regL_regLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePConditional_regP_regP_regPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPLockedNode::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // RegFlags
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    true ,  // AbsI
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // AryEq
    false,  // AtanD
    true ,  // Binary
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    false,  // ReverseBytesL
    false,  // ReverseBytesUS
    false,  // ReverseBytesS
    false,  // CProj
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastII
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    true ,  // CMoveN
    true ,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    true ,  // CmpUL
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    true ,  // CompareAndSwapN
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    true ,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    true ,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    true ,  // ConvL2F
    true ,  // ConvL2I
    false,  // CosD
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    true ,  // CreateEx
    true ,  // DecodeN
    true ,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    false,  // EncodeISOArray
    true ,  // EncodeP
    true ,  // EncodePKlass
    false,  // ExpD
    true ,  // FastLock
    true ,  // FastUnlock
    true ,  // Goto
    true ,  // Halt
    true ,  // If
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    false,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    true ,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    true ,  // LoadNKlass
    true ,  // LoadL
    true ,  // LoadL_unaligned
    true ,  // LoadPLocked
    true ,  // LoadP
    true ,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // LogD
    false,  // Log10D
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachProj
    true ,  // MaxI
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    true ,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    true ,  // MulD
    true ,  // MulF
    true ,  // MulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // Opaque1
    false,  // Opaque2
    false,  // Opaque3
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    false,  // OverflowAddI
    false,  // OverflowSubI
    false,  // OverflowMulI
    false,  // OverflowAddL
    false,  // OverflowSubL
    false,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    true ,  // PartialSubtypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    false,  // PowD
    true ,  // PrefetchAllocation
    true ,  // PrefetchRead
    true ,  // PrefetchWrite
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // Root
    true ,  // RoundDouble
    true ,  // RoundFloat
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // SCMemProj
    false,  // SinD
    true ,  // SqrtD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StorePConditional
    false,  // StoreIConditional
    true ,  // StoreLConditional
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    true ,  // StoreN
    true ,  // StoreNKlass
    true ,  // StrComp
    true ,  // StrEquals
    true ,  // StrIndexOf
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // TanD
    true ,  // ThreadLocal
    false,  // Unlock
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    false,  // AddVB
    false,  // AddVS
    false,  // AddVI
    false,  // AddVL
    false,  // AddVF
    false,  // AddVD
    false,  // SubVB
    false,  // SubVS
    false,  // SubVI
    false,  // SubVL
    false,  // SubVF
    false,  // SubVD
    false,  // MulVS
    false,  // MulVI
    false,  // MulVF
    false,  // MulVD
    false,  // DivVF
    false,  // DivVD
    false,  // LShiftCntV
    false,  // RShiftCntV
    false,  // LShiftVB
    false,  // LShiftVS
    false,  // LShiftVI
    false,  // LShiftVL
    false,  // RShiftVB
    false,  // RShiftVS
    false,  // RShiftVI
    false,  // RShiftVL
    false,  // URShiftVB
    false,  // URShiftVS
    false,  // URShiftVI
    false,  // URShiftVL
    false,  // AndV
    false,  // OrV
    false,  // XorV
    true ,  // LoadVector
    true ,  // StoreVector
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    false,  // ReplicateL
    true ,  // ReplicateF
    false,  // ReplicateD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false   // ExtractD
};


bool Matcher::stack_direction() const { return false; }

int Compile::sync_stack_slots() const { return (frame::jit_monitor_size / VMRegImpl::stack_slot_size); }

uint Matcher::stack_alignment_in_bytes() { return frame::alignment_in_bytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(4); }

uint Compile::in_preserve_stack_slots() { return (frame::jit_in_preserve_size / VMRegImpl::stack_slot_size); }

uint Compile::out_preserve_stack_slots() { return SharedRuntime::out_preserve_stack_slots(); }

uint Compile::varargs_C_out_slots_killed() const { return ((frame::abi_reg_args_size - frame::jit_out_preserve_size) / VMRegImpl::stack_slot_size); }

void Matcher::calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length, bool is_outgoing) {

#line 3956 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // No difference between ingoing/outgoing. Just pass false.
    SharedRuntime::java_calling_convention(sig_bt, regs, length, false);
  
#line 18164 "../generated/adfiles/ad_ppc_64.cpp"

}

void Matcher::c_calling_convention(BasicType *sig_bt, VMRegPair *regs, uint length) {

#line 3968 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    // This is obviously always outgoing.
    // C argument in register AND stack slot.
    (void) SharedRuntime::c_calling_convention(sig_bt, regs, /*regs2=*/NULL, length);
  
#line 18176 "../generated/adfiles/ad_ppc_64.cpp"

}

OptoRegPair Matcher::return_value(int ideal_reg, bool is_outgoing) {

#line 3991 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    assert((ideal_reg >= Op_RegI && ideal_reg <= Op_RegL) ||
            (ideal_reg == Op_RegN && Universe::narrow_oop_base() == NULL && Universe::narrow_oop_shift() == 0),
            "only return normal values");
    // enum names from opcodes.hpp:    Op_Node Op_Set Op_RegN       Op_RegI       Op_RegP       Op_RegF       Op_RegD       Op_RegL
    static int typeToRegLo[Op_RegL+1] = { 0,   0,     R3_num,   R3_num,   R3_num,   F1_num,   F1_num,   R3_num };
    static int typeToRegHi[Op_RegL+1] = { 0,   0,     OptoReg::Bad, R3_H_num, R3_H_num, OptoReg::Bad, F1_H_num, R3_H_num };
    return OptoRegPair(typeToRegHi[ideal_reg], typeToRegLo[ideal_reg]);
  
#line 18192 "../generated/adfiles/ad_ppc_64.cpp"

}

OptoRegPair Matcher::c_return_value(int ideal_reg, bool is_outgoing) {

#line 3980 "/builddir/build/BUILD/java-1.8.0-openjdk-1.8.0.172-12.b11.fc29.ppc64le/openjdk/hotspot/src/cpu/ppc/vm/ppc.ad"

    assert((ideal_reg >= Op_RegI && ideal_reg <= Op_RegL) ||
            (ideal_reg == Op_RegN && Universe::narrow_oop_base() == NULL && Universe::narrow_oop_shift() == 0),
            "only return normal values");
    // enum names from opcodes.hpp:    Op_Node Op_Set Op_RegN       Op_RegI       Op_RegP       Op_RegF       Op_RegD       Op_RegL
    static int typeToRegLo[Op_RegL+1] = { 0,   0,     R3_num,   R3_num,   R3_num,   F1_num,   F1_num,   R3_num };
    static int typeToRegHi[Op_RegL+1] = { 0,   0,     OptoReg::Bad, R3_H_num, R3_H_num, OptoReg::Bad, F1_H_num, R3_H_num };
    return OptoRegPair(typeToRegHi[ideal_reg], typeToRegLo[ideal_reg]);
  
#line 18208 "../generated/adfiles/ad_ppc_64.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R19_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_method_oop_reg() { return OptoReg::Name(R19_num); }

int Matcher::interpreter_method_oop_reg_encode() { return _regEncode[interpreter_method_oop_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Name(R14_num); }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R1_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_clone_jvms() { return true; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DPPC64=1
#ifndef PPC64
#  error "PPC64 must be defined"
#endif // PPC64
// Check adlc -D_LP64=1
#ifndef _LP64
#  error "_LP64 must be defined"
#endif // _LP64
